(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 11.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    741428,      13582]
NotebookOptionsPosition[    740922,      13560]
NotebookOutlinePosition[    741285,      13576]
CellTagsIndexPosition[    741242,      13573]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{"Graph", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"1", "\[DirectedEdge]", "2"}], ",", 
       RowBox[{"2", "\[DirectedEdge]", "3"}], ",", 
       RowBox[{"3", "\[DirectedEdge]", "1"}]}], "}"}], ",", 
     RowBox[{"EdgeShapeFunction", "\[Rule]", 
      RowBox[{"GraphElementData", "[", 
       RowBox[{"ef", ",", 
        RowBox[{"\"\<ArrowSize\>\"", "\[Rule]", "0.1"}]}], "]"}]}], ",", 
     RowBox[{"PlotLabel", "\[Rule]", 
      RowBox[{"Style", "[", 
       RowBox[{"ef", ",", "9"}], "]"}]}]}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"ef", ",", 
     RowBox[{"GraphElementData", "[", 
      RowBox[{"\"\<EdgeShapeFunction\>\"", ",", "\"\<UnfilledArrow\>\""}], 
      "]"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.706029758092434*^9, 3.706029758094149*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"n", "=", "15"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Payoffs", " ", "=", " ", 
     RowBox[{"RandomInteger", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "200"}], "}"}], ",", " ", "n"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"l", "=", "10"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"players", " ", "=", " ", "30"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"panelLabel", "[", "lbl_", "]"}], ":=", 
     RowBox[{"Panel", "[", 
      RowBox[{"lbl", ",", 
       RowBox[{"FrameMargins", "\[Rule]", "0"}], ",", 
       RowBox[{"Background", "\[Rule]", 
        RowBox[{"Lighter", "[", 
         RowBox[{"Gray", ",", "0.7"}], "]"}]}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"ellipseLayout", "[", 
      RowBox[{"n_", ",", 
       RowBox[{"{", 
        RowBox[{"a_", ",", "b_"}], "}"}]}], "]"}], ":=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", " ", 
          RowBox[{"Cos", "[", 
           RowBox[{"2", " ", 
            RowBox[{"Pi", "/", "n"}], " ", "u"}], "]"}]}], ",", 
         RowBox[{"b", " ", 
          RowBox[{"Sin", "[", 
           RowBox[{"2", " ", 
            RowBox[{"Pi", "/", "n"}], " ", "u"}], "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"u", ",", "1", ",", "n"}], "}"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"graphs", "=", 
    RowBox[{"Table", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"x", " ", "=", " ", 
        RowBox[{"RandomInteger", "[", 
         RowBox[{"{", 
          RowBox[{"1", ",", 
           RowBox[{"l", "-", "1"}]}], "}"}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"y", " ", "=", " ", 
        RowBox[{"RandomInteger", "[", 
         RowBox[{"{", 
          RowBox[{"1", ",", 
           RowBox[{"l", "-", "1"}]}], "}"}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"Graph", "[", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"Union", "[", 
          RowBox[{
           RowBox[{"Table", "[", 
            RowBox[{
             RowBox[{"i", " ", "\[Rule]", " ", 
              RowBox[{"Mod", "[", 
               RowBox[{
                RowBox[{"i", " ", "+", "x"}], ",", "n"}], "]"}]}], ",", " ", 
             RowBox[{"{", 
              RowBox[{"i", ",", "0", ",", 
               RowBox[{"n", "-", "1"}]}], "}"}]}], "]"}], ",", 
           RowBox[{"Table", "[", 
            RowBox[{
             RowBox[{"i", " ", "\[Rule]", " ", 
              RowBox[{"Mod", "[", 
               RowBox[{
                RowBox[{"i", " ", "+", "y"}], ",", "n"}], "]"}]}], ",", " ", 
             RowBox[{"{", 
              RowBox[{"i", ",", "0", ",", 
               RowBox[{"n", "-", "1"}]}], "}"}]}], "]"}]}], " ", "]"}], ",", 
         RowBox[{"ImageSize", "\[Rule]", " ", "Large"}], ",", 
         RowBox[{"VertexCoordinates", "\[Rule]", 
          RowBox[{"ellipseLayout", "[", 
           RowBox[{"n", ",", 
            RowBox[{"{", 
             RowBox[{"11", ",", "8.5"}], "}"}]}], "]"}]}], ",", " ", 
         RowBox[{"EdgeShapeFunction", "\[Rule]", 
          RowBox[{"GraphElementData", "[", 
           RowBox[{"\"\<UnfilledArrow\>\"", ",", 
            RowBox[{"\"\<ArrowSize\>\"", "\[Rule]", "0.03"}]}], "]"}]}], ",", 
         " ", 
         RowBox[{"VertexLabels", "\[Rule]", 
          RowBox[{"Table", "[", 
           RowBox[{
            RowBox[{"i", "\[Rule]", " ", 
             RowBox[{"Placed", "[", 
              RowBox[{
               RowBox[{"\"\<Number: \>\"", "<>", " ", 
                RowBox[{"ToString", "[", "i", "]"}], " ", "<>", " ", 
                "\"\<\\nPayoff: \>\"", " ", "<>", " ", 
                RowBox[{"ToString", "[", 
                 RowBox[{"Payoffs", "[", 
                  RowBox[{"[", 
                   RowBox[{"i", "+", "1"}], "]"}], "]"}], "]"}]}], ",", " ", 
               "Center", ",", " ", "panelLabel"}], "]"}]}], ",", " ", 
            RowBox[{"{", 
             RowBox[{"i", ",", "0", ",", 
              RowBox[{"n", "-", "1"}]}], "}"}]}], "]"}]}]}], "]"}]}], ",", 
      " ", "players"}], "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.706023215130807*^9, 3.706023258358231*^9}, {
   3.7060233218797207`*^9, 3.706023353576338*^9}, {3.706023476070095*^9, 
   3.7060237459302807`*^9}, {3.7060238272906933`*^9, 3.706023887325151*^9}, {
   3.706023917709868*^9, 3.7060241526989717`*^9}, {3.7060242022590437`*^9, 
   3.706024252779274*^9}, {3.7060246818935823`*^9, 3.706024841443495*^9}, {
   3.706024896532858*^9, 3.706024899133757*^9}, {3.7060249471385527`*^9, 
   3.706024992716056*^9}, {3.7060250510965967`*^9, 3.706025056591753*^9}, {
   3.7060250870758247`*^9, 3.706025101448835*^9}, {3.706025137744488*^9, 
   3.706025141577519*^9}, 3.706025278266494*^9, {3.706025326238717*^9, 
   3.7060253268723993`*^9}, 3.706025370834772*^9, {3.706025468869794*^9, 
   3.706025594543598*^9}, {3.70602566660266*^9, 3.706025693615923*^9}, {
   3.706025788412155*^9, 3.706025967640306*^9}, {3.7060259986684313`*^9, 
   3.706026053324328*^9}, {3.706026156708612*^9, 3.706026214042584*^9}, {
   3.706026432739588*^9, 3.706026434432847*^9}, {3.706026746562497*^9, 
   3.706026848751081*^9}, {3.706026886566082*^9, 3.7060269161065598`*^9}, {
   3.706026995537922*^9, 3.706027061951448*^9}, {3.7060272066313343`*^9, 
   3.706027268863489*^9}, {3.706027352831724*^9, 3.706027354574171*^9}, {
   3.706027390531413*^9, 3.706027390747615*^9}, {3.7060274420297527`*^9, 
   3.7060274427157183`*^9}, {3.706028331886881*^9, 3.706028418380418*^9}, {
   3.706029055380732*^9, 3.706029093744108*^9}, {3.706029197670985*^9, 
   3.706029256559949*^9}, {3.7060294476827917`*^9, 3.7060294479074383`*^9}, {
   3.706029490486023*^9, 3.706029668595874*^9}, {3.706029778603573*^9, 
   3.706029799230461*^9}, {3.7060298496169147`*^9, 3.706029888721092*^9}, {
   3.706029925532893*^9, 3.706029934904008*^9}, {3.7060301126765413`*^9, 
   3.706030189123994*^9}, {3.7060302612674294`*^9, 3.706030261764592*^9}, {
   3.706030465884869*^9, 3.706030469688843*^9}, {3.706030549829974*^9, 
   3.706030551557609*^9}, {3.70609512248691*^9, 3.706095125242219*^9}, {
   3.706095264094872*^9, 3.7060952689793587`*^9}, {3.706097375176976*^9, 
   3.706097394673194*^9}, 3.706097461597785*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{0, 4, 1, 5, 2, 6, 3, 7, 8, 9, 10, 11, 12, 13, 
        14}, {{{1, 2}, {3, 4}, {5, 6}, {7, 8}, {2, 9}, {4, 10}, {6, 11}, {8, 
         12}, {9, 13}, {10, 14}, {11, 15}, {12, 1}, {13, 3}, {14, 5}, {15, 
         7}}, Null}, {EdgeShapeFunction -> {
           GraphElementData["UnfilledArrow", "ArrowSize" -> 0.03]}, ImageSize -> 
         Large, VertexCoordinates -> {{
           11 Cos[Rational[2, 15] Pi], 3.4572614661443013`}, {
           11 Sin[Rational[7, 30] Pi], 6.316731016557851}, {
           Rational[11, 4] (-1 + 5^Rational[1, 2]), 
            8.083980388508804}, {(-11) Sin[Rational[1, 30] Pi], 
            8.453436110630323}, {
            Rational[-11, 2], 7.361215932167728}, {
           Rational[11, 4] (-1 - 5^Rational[1, 2]), 
            4.996174644486022}, {(-11) Cos[Rational[1, 15] Pi], 
            1.767249371950954}, {(-11) 
            Cos[Rational[1, 15] Pi], -1.767249371950954}, {
           Rational[11, 4] (-1 - 5^Rational[1, 2]), -4.996174644486022}, {
            Rational[-11, 2], -7.361215932167728}, {(-11) 
            Sin[Rational[1, 30] Pi], -8.453436110630323}, {
           Rational[11, 4] (-1 + 5^Rational[1, 2]), -8.083980388508804}, {
           11 Sin[Rational[7, 30] Pi], -6.316731016557851}, {
           11 Cos[Rational[2, 15] Pi], -3.4572614661443013`}, {11, 0.}}, 
         VertexLabels -> {
          6 -> Placed[
            "Number: 6\nPayoff: 196", Center, $CellContext`panelLabel], 3 -> 
           Placed["Number: 3\nPayoff: 94", Center, $CellContext`panelLabel], 
           11 -> Placed[
            "Number: 11\nPayoff: 172", Center, $CellContext`panelLabel], 5 -> 
           Placed["Number: 5\nPayoff: 36", Center, $CellContext`panelLabel], 
           8 -> Placed[
            "Number: 8\nPayoff: 68", Center, $CellContext`panelLabel], 7 -> 
           Placed["Number: 7\nPayoff: 112", Center, $CellContext`panelLabel], 
           14 -> Placed[
            "Number: 14\nPayoff: 113", Center, $CellContext`panelLabel], 10 -> 
           Placed["Number: 10\nPayoff: 4", Center, $CellContext`panelLabel], 
           9 -> Placed[
            "Number: 9\nPayoff: 75", Center, $CellContext`panelLabel], 4 -> 
           Placed["Number: 4\nPayoff: 73", Center, $CellContext`panelLabel], 
           12 -> Placed[
            "Number: 12\nPayoff: 68", Center, $CellContext`panelLabel], 13 -> 
           Placed["Number: 13\nPayoff: 52", Center, $CellContext`panelLabel], 
           2 -> Placed[
            "Number: 2\nPayoff: 136", Center, $CellContext`panelLabel], 1 -> 
           Placed["Number: 1\nPayoff: 68", Center, $CellContext`panelLabel], 
           0 -> Placed[
            "Number: 0\nPayoff: 154", Center, $CellContext`panelLabel]}}]]}, 
      TagBox[GraphicsGroupBox[{
         {Hue[0.6, 0.7, 0.5], Opacity[0.7], 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{10.049000034068609`, 3.4572614661443013`}, {
            7.360436669947441, 6.316731016557851}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{7.360436669947441, 
            6.316731016557851}, {-8.899186938124423, -4.996174644486022}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{3.399186938124422, 
            8.083980388508804}, {-1.1498130959441881`, 
            8.453436110630323}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-1.1498130959441881`, 
            8.453436110630323}, {-5.5, -7.361215932167728}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-5.5, 7.361215932167728}, {-8.899186938124423, 
            4.996174644486022}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-8.899186938124423, 
            4.996174644486022}, {-1.1498130959441881`, -8.453436110630323}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-10.759623608071863`, 
            1.767249371950954}, {-10.759623608071863`, -1.767249371950954}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-10.759623608071863`, -1.767249371950954}, {
            3.399186938124422, -8.083980388508804}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-8.899186938124423, -4.996174644486022}, {
            7.360436669947441, -6.316731016557851}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-5.5, -7.361215932167728}, {
            10.049000034068609`, -3.4572614661443013`}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-1.1498130959441881`, -8.453436110630323}, {11., 0.}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{3.399186938124422, -8.083980388508804}, {
            10.049000034068609`, 3.4572614661443013`}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{7.360436669947441, -6.316731016557851}, {
            3.399186938124422, 8.083980388508804}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{10.049000034068609`, -3.4572614661443013`}, {-5.5, 
            7.361215932167728}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{11., 0.}, {-10.759623608071863`, 1.767249371950954}}]}}, 
         {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
          0.7]}], {
           DiskBox[{10.049000034068609, 3.4572614661443013}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 0\\nPayoff: 154\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {10.049000034068609, 3.4572614661443013},
            BaseStyle->"Graphics"]}, {
           DiskBox[{7.360436669947441, 6.316731016557851}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 4\\nPayoff: 73\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {7.360436669947441, 6.316731016557851},
            BaseStyle->"Graphics"]}, {
           DiskBox[{3.399186938124422, 8.083980388508804}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 1\\nPayoff: 68\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {3.399186938124422, 8.083980388508804},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-1.1498130959441881, 8.453436110630323}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 5\\nPayoff: 36\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-1.1498130959441881, 8.453436110630323},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-5.5, 7.361215932167728}, 0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 2\\nPayoff: 136\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-5.5, 7.361215932167728},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-8.899186938124423, 4.996174644486022}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 6\\nPayoff: 196\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-8.899186938124423, 4.996174644486022},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-10.759623608071863, 1.767249371950954}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 3\\nPayoff: 94\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-10.759623608071863, 1.767249371950954},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-10.759623608071863, -1.767249371950954}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 7\\nPayoff: 112\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-10.759623608071863, -1.767249371950954},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-8.899186938124423, -4.996174644486022}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 8\\nPayoff: 68\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-8.899186938124423, -4.996174644486022},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-5.5, -7.361215932167728}, 0.09359782207206707], 
           InsetBox[
            PanelBox["\<\"Number: 9\\nPayoff: 75\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-5.5, -7.361215932167728},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-1.1498130959441881, -8.453436110630323}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 10\\nPayoff: 4\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-1.1498130959441881, -8.453436110630323},
            BaseStyle->"Graphics"]}, {
           DiskBox[{3.399186938124422, -8.083980388508804}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 11\\nPayoff: 172\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {3.399186938124422, -8.083980388508804},
            BaseStyle->"Graphics"]}, {
           DiskBox[{7.360436669947441, -6.316731016557851}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 12\\nPayoff: 68\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {7.360436669947441, -6.316731016557851},
            BaseStyle->"Graphics"]}, {
           DiskBox[{10.049000034068609, -3.4572614661443013}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 13\\nPayoff: 52\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {10.049000034068609, -3.4572614661443013},
            BaseStyle->"Graphics"]}, {DiskBox[{11., 0.}, 0.09359782207206707],
            InsetBox[
            PanelBox["\<\"Number: 14\\nPayoff: 113\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {11., 0.},
            BaseStyle->"Graphics"]}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None,
    ImageSize->Large], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{0, 7, 8, 1, 9, 2, 10, 3, 11, 4, 12, 5, 13, 6, 
        14}, {{{1, 2}, {1, 3}, {4, 3}, {4, 5}, {6, 5}, {6, 7}, {8, 7}, {8, 
         9}, {10, 9}, {10, 11}, {12, 11}, {12, 13}, {14, 13}, {14, 15}, {2, 
         1}, {2, 15}, {3, 1}, {3, 4}, {5, 4}, {5, 6}, {7, 6}, {7, 8}, {9, 
         8}, {9, 10}, {11, 10}, {11, 12}, {13, 12}, {13, 14}, {15, 14}, {15, 
         2}}, Null}, {EdgeShapeFunction -> {
           GraphElementData["UnfilledArrow", "ArrowSize" -> 0.03]}, ImageSize -> 
         Large, VertexCoordinates -> {{
           11 Cos[Rational[2, 15] Pi], 3.4572614661443013`}, {
           11 Sin[Rational[7, 30] Pi], 6.316731016557851}, {
           Rational[11, 4] (-1 + 5^Rational[1, 2]), 
            8.083980388508804}, {(-11) Sin[Rational[1, 30] Pi], 
            8.453436110630323}, {
            Rational[-11, 2], 7.361215932167728}, {
           Rational[11, 4] (-1 - 5^Rational[1, 2]), 
            4.996174644486022}, {(-11) Cos[Rational[1, 15] Pi], 
            1.767249371950954}, {(-11) 
            Cos[Rational[1, 15] Pi], -1.767249371950954}, {
           Rational[11, 4] (-1 - 5^Rational[1, 2]), -4.996174644486022}, {
            Rational[-11, 2], -7.361215932167728}, {(-11) 
            Sin[Rational[1, 30] Pi], -8.453436110630323}, {
           Rational[11, 4] (-1 + 5^Rational[1, 2]), -8.083980388508804}, {
           11 Sin[Rational[7, 30] Pi], -6.316731016557851}, {
           11 Cos[Rational[2, 15] Pi], -3.4572614661443013`}, {11, 0.}}, 
         VertexLabels -> {
          6 -> Placed[
            "Number: 6\nPayoff: 196", Center, $CellContext`panelLabel], 3 -> 
           Placed["Number: 3\nPayoff: 94", Center, $CellContext`panelLabel], 
           11 -> Placed[
            "Number: 11\nPayoff: 172", Center, $CellContext`panelLabel], 5 -> 
           Placed["Number: 5\nPayoff: 36", Center, $CellContext`panelLabel], 
           8 -> Placed[
            "Number: 8\nPayoff: 68", Center, $CellContext`panelLabel], 7 -> 
           Placed["Number: 7\nPayoff: 112", Center, $CellContext`panelLabel], 
           14 -> Placed[
            "Number: 14\nPayoff: 113", Center, $CellContext`panelLabel], 10 -> 
           Placed["Number: 10\nPayoff: 4", Center, $CellContext`panelLabel], 
           9 -> Placed[
            "Number: 9\nPayoff: 75", Center, $CellContext`panelLabel], 4 -> 
           Placed["Number: 4\nPayoff: 73", Center, $CellContext`panelLabel], 
           12 -> Placed[
            "Number: 12\nPayoff: 68", Center, $CellContext`panelLabel], 13 -> 
           Placed["Number: 13\nPayoff: 52", Center, $CellContext`panelLabel], 
           2 -> Placed[
            "Number: 2\nPayoff: 136", Center, $CellContext`panelLabel], 1 -> 
           Placed["Number: 1\nPayoff: 68", Center, $CellContext`panelLabel], 
           0 -> Placed[
            "Number: 0\nPayoff: 154", Center, $CellContext`panelLabel]}}]]}, 
      TagBox[GraphicsGroupBox[{
         {Hue[0.6, 0.7, 0.5], Opacity[0.7], 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[BezierCurveBox[{{10.049000034068609`, 
            3.4572614661443013`}, {8.234505042590648, 4.444886872908986}, {
            7.360436669947441, 6.316731016557851}}]]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[BezierCurveBox[{{10.049000034068609`, 
            3.4572614661443013`}, {5.963272369496626, 4.677120693199975}, {
            3.399186938124422, 8.083980388508804}}]]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[BezierCurveBox[{{7.360436669947441, 6.316731016557851}, {
            9.174931661425394, 5.3291056098000364`}, {10.049000034068609`, 
            3.4572614661443013`}}]]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[BezierCurveBox[{{7.360436669947441, 6.316731016557851}, {
            10.218946303091288`, 3.7568580216929695`}, {11., 0.}}]]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[BezierCurveBox[{{3.399186938124422, 8.083980388508804}, {
            7.484914602696377, 6.864121161449966}, {10.049000034068609`, 
            3.4572614661443013`}}]]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[BezierCurveBox[{{3.399186938124422, 8.083980388508804}, {
            1.063933346093385, 7.5206672850298135`}, {-1.1498130959441881`, 
            8.453436110630323}}]]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[BezierCurveBox[{{-1.1498130959441881`, 
            8.453436110630323}, {1.1854404960868141`, 9.016749214111785}, {
            3.399186938124422, 8.083980388508804}}]]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[BezierCurveBox[{{-1.1498130959441881`, 
            8.453436110630323}, {-3.145301045737304, 
            7.191978036513387}, {-5.5, 7.361215932167728}}]]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[BezierCurveBox[{{-5.5, 
            7.361215932167728}, {-3.504512050206958, 
            8.622674006289872}, {-1.1498130959441881`, 8.453436110630323}}]]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[BezierCurveBox[{{-5.5, 
            7.361215932167728}, {-6.810684312596919, 
            5.619730448413851}, {-8.899186938124423, 4.996174644486022}}]]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[BezierCurveBox[{{-8.899186938124423, 
            4.996174644486022}, {-7.588502625527534, 
            6.737660128248351}, {-5.5, 7.361215932167728}}]]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[BezierCurveBox[{{-8.899186938124423, 
            4.996174644486022}, {-9.298438388684055, 
            3.0757804121246006`}, {-10.759623608071863`, 
            1.767249371950954}}]]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[BezierCurveBox[{{-10.759623608071863`, 
            1.767249371950954}, {-10.360372157512234`, 
            3.6876436043117953`}, {-8.899186938124423, 4.996174644486022}}]]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[BezierCurveBox[{{-10.759623608071863`, 
            1.767249371950954}, {-10.17840799370685, 
            0.}, {-10.759623608071863`, -1.767249371950954}}]]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[
            BezierCurveBox[{{-10.759623608071863`, -1.767249371950954}, \
{-11.340839222436871`, -6.067406804681278*^-13}, {-10.759623608071863`, 
            1.767249371950954}}]]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[
            BezierCurveBox[{{-10.759623608071863`, -1.767249371950954}, \
{-9.298438388684048, -3.075780412121243}, {-8.899186938124423, \
-4.996174644486022}}]]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[
            BezierCurveBox[{{-8.899186938124423, -4.996174644486022}, \
{-10.360372157512234`, -3.6876436043079406`}, {-10.759623608071863`, \
-1.767249371950954}}]]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[
            BezierCurveBox[{{-8.899186938124423, -4.996174644486022}, \
{-6.810684312596916, -5.619730448410314}, {-5.5, -7.361215932167728}}]]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[
            BezierCurveBox[{{-5.5, -7.361215932167728}, {-7.58850262552754, \
-6.737660128241091}, {-8.899186938124423, -4.996174644486022}}]]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[
            BezierCurveBox[{{-5.5, -7.361215932167728}, {-3.145301045737251, \
-7.191978036515335}, {-1.1498130959441881`, -8.453436110630323}}]]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[
            BezierCurveBox[{{-1.1498130959441881`, -8.453436110630323}, \
{-3.504512050206951, -8.622674006288129}, {-5.5, -7.361215932167728}}]]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[
            BezierCurveBox[{{-1.1498130959441881`, -8.453436110630323}, {
            1.0639333460934395`, -7.5206672850348655`}, {
            3.399186938124422, -8.083980388508804}}]]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[BezierCurveBox[{{3.399186938124422, -8.083980388508804}, {
            1.1854404960868563`, -9.016749214106875}, {-1.1498130959441881`, \
-8.453436110630323}}]]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[BezierCurveBox[{{3.399186938124422, -8.083980388508804}, {
            5.0892039968534135`, -6.548964836859322}, {
            7.360436669947441, -6.316731016557851}}]]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[BezierCurveBox[{{7.360436669947441, -6.316731016557851}, {
            5.670419611218439, -7.851746568214624}, {
            3.399186938124422, -8.083980388508804}}]]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[BezierCurveBox[{{7.360436669947441, -6.316731016557851}, {
            8.234505042590666, -4.444886872902862}, {
            10.049000034068609`, -3.4572614661443013`}}]]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[BezierCurveBox[{{
            10.049000034068609`, -3.4572614661443013`}, {
            9.174931661425386, -5.329105609797414}, {
            7.360436669947441, -6.316731016557851}}]]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[BezierCurveBox[{{
            10.049000034068609`, -3.4572614661443013`}, {
            9.955985358334136, -1.572247588103943}, {11., 0.}}]]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[BezierCurveBox[{{11., 0.}, {8.141490366856154, 
            2.5598729948651875`}, {7.360436669947441, 
            6.316731016557851}}]]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[BezierCurveBox[{{11., 0.}, {
            11.093014675734477`, -1.8850138780439836`}, {
            10.049000034068609`, -3.4572614661443013`}}]]}}, 
         {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
          0.7]}], {
           DiskBox[{10.049000034068609, 3.4572614661443013}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 0\\nPayoff: 154\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {10.049000034068609, 3.4572614661443013},
            BaseStyle->"Graphics"]}, {
           DiskBox[{7.360436669947441, 6.316731016557851}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 7\\nPayoff: 112\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {7.360436669947441, 6.316731016557851},
            BaseStyle->"Graphics"]}, {
           DiskBox[{3.399186938124422, 8.083980388508804}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 8\\nPayoff: 68\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {3.399186938124422, 8.083980388508804},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-1.1498130959441881, 8.453436110630323}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 1\\nPayoff: 68\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-1.1498130959441881, 8.453436110630323},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-5.5, 7.361215932167728}, 0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 9\\nPayoff: 75\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-5.5, 7.361215932167728},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-8.899186938124423, 4.996174644486022}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 2\\nPayoff: 136\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-8.899186938124423, 4.996174644486022},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-10.759623608071863, 1.767249371950954}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 10\\nPayoff: 4\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-10.759623608071863, 1.767249371950954},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-10.759623608071863, -1.767249371950954}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 3\\nPayoff: 94\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-10.759623608071863, -1.767249371950954},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-8.899186938124423, -4.996174644486022}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 11\\nPayoff: 172\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-8.899186938124423, -4.996174644486022},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-5.5, -7.361215932167728}, 0.09359782207206707], 
           InsetBox[
            PanelBox["\<\"Number: 4\\nPayoff: 73\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-5.5, -7.361215932167728},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-1.1498130959441881, -8.453436110630323}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 12\\nPayoff: 68\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-1.1498130959441881, -8.453436110630323},
            BaseStyle->"Graphics"]}, {
           DiskBox[{3.399186938124422, -8.083980388508804}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 5\\nPayoff: 36\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {3.399186938124422, -8.083980388508804},
            BaseStyle->"Graphics"]}, {
           DiskBox[{7.360436669947441, -6.316731016557851}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 13\\nPayoff: 52\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {7.360436669947441, -6.316731016557851},
            BaseStyle->"Graphics"]}, {
           DiskBox[{10.049000034068609, -3.4572614661443013}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 6\\nPayoff: 196\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {10.049000034068609, -3.4572614661443013},
            BaseStyle->"Graphics"]}, {DiskBox[{11., 0.}, 0.09359782207206707],
            InsetBox[
            PanelBox["\<\"Number: 14\\nPayoff: 113\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {11., 0.},
            BaseStyle->"Graphics"]}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None,
    ImageSize->Large], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{0, 1, 5, 2, 6, 3, 7, 4, 8, 9, 10, 11, 12, 13, 
        14}, {{{1, 2}, {1, 3}, {2, 4}, {2, 5}, {4, 6}, {4, 7}, {6, 8}, {6, 
         9}, {8, 3}, {8, 10}, {3, 5}, {3, 11}, {5, 7}, {5, 12}, {7, 9}, {7, 
         13}, {9, 10}, {9, 14}, {10, 11}, {10, 15}, {11, 1}, {11, 12}, {12, 
         2}, {12, 13}, {13, 4}, {13, 14}, {14, 6}, {14, 15}, {15, 1}, {15, 
         8}}, Null}, {EdgeShapeFunction -> {
           GraphElementData["UnfilledArrow", "ArrowSize" -> 0.03]}, ImageSize -> 
         Large, VertexCoordinates -> {{
           11 Cos[Rational[2, 15] Pi], 3.4572614661443013`}, {
           11 Sin[Rational[7, 30] Pi], 6.316731016557851}, {
           Rational[11, 4] (-1 + 5^Rational[1, 2]), 
            8.083980388508804}, {(-11) Sin[Rational[1, 30] Pi], 
            8.453436110630323}, {
            Rational[-11, 2], 7.361215932167728}, {
           Rational[11, 4] (-1 - 5^Rational[1, 2]), 
            4.996174644486022}, {(-11) Cos[Rational[1, 15] Pi], 
            1.767249371950954}, {(-11) 
            Cos[Rational[1, 15] Pi], -1.767249371950954}, {
           Rational[11, 4] (-1 - 5^Rational[1, 2]), -4.996174644486022}, {
            Rational[-11, 2], -7.361215932167728}, {(-11) 
            Sin[Rational[1, 30] Pi], -8.453436110630323}, {
           Rational[11, 4] (-1 + 5^Rational[1, 2]), -8.083980388508804}, {
           11 Sin[Rational[7, 30] Pi], -6.316731016557851}, {
           11 Cos[Rational[2, 15] Pi], -3.4572614661443013`}, {11, 0.}}, 
         VertexLabels -> {
          6 -> Placed[
            "Number: 6\nPayoff: 196", Center, $CellContext`panelLabel], 3 -> 
           Placed["Number: 3\nPayoff: 94", Center, $CellContext`panelLabel], 
           11 -> Placed[
            "Number: 11\nPayoff: 172", Center, $CellContext`panelLabel], 5 -> 
           Placed["Number: 5\nPayoff: 36", Center, $CellContext`panelLabel], 
           8 -> Placed[
            "Number: 8\nPayoff: 68", Center, $CellContext`panelLabel], 7 -> 
           Placed["Number: 7\nPayoff: 112", Center, $CellContext`panelLabel], 
           14 -> Placed[
            "Number: 14\nPayoff: 113", Center, $CellContext`panelLabel], 10 -> 
           Placed["Number: 10\nPayoff: 4", Center, $CellContext`panelLabel], 
           9 -> Placed[
            "Number: 9\nPayoff: 75", Center, $CellContext`panelLabel], 4 -> 
           Placed["Number: 4\nPayoff: 73", Center, $CellContext`panelLabel], 
           12 -> Placed[
            "Number: 12\nPayoff: 68", Center, $CellContext`panelLabel], 13 -> 
           Placed["Number: 13\nPayoff: 52", Center, $CellContext`panelLabel], 
           2 -> Placed[
            "Number: 2\nPayoff: 136", Center, $CellContext`panelLabel], 1 -> 
           Placed["Number: 1\nPayoff: 68", Center, $CellContext`panelLabel], 
           0 -> Placed[
            "Number: 0\nPayoff: 154", Center, $CellContext`panelLabel]}}]]}, 
      TagBox[GraphicsGroupBox[{
         {Hue[0.6, 0.7, 0.5], Opacity[0.7], 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{10.049000034068609`, 3.4572614661443013`}, {
            7.360436669947441, 6.316731016557851}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{10.049000034068609`, 3.4572614661443013`}, {
            3.399186938124422, 8.083980388508804}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{7.360436669947441, 
            6.316731016557851}, {-1.1498130959441881`, 
            8.453436110630323}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{7.360436669947441, 6.316731016557851}, {-5.5, 
            7.361215932167728}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{3.399186938124422, 8.083980388508804}, {-5.5, 
            7.361215932167728}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{3.399186938124422, 
            8.083980388508804}, {-1.1498130959441881`, -8.453436110630323}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-1.1498130959441881`, 
            8.453436110630323}, {-8.899186938124423, 4.996174644486022}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-1.1498130959441881`, 
            8.453436110630323}, {-10.759623608071863`, 
            1.767249371950954}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-5.5, 7.361215932167728}, {-10.759623608071863`, 
            1.767249371950954}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-5.5, 7.361215932167728}, {
            3.399186938124422, -8.083980388508804}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-8.899186938124423, 
            4.996174644486022}, {-10.759623608071863`, -1.767249371950954}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-8.899186938124423, 
            4.996174644486022}, {-8.899186938124423, -4.996174644486022}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-10.759623608071863`, 
            1.767249371950954}, {-8.899186938124423, -4.996174644486022}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-10.759623608071863`, 1.767249371950954}, {
            7.360436669947441, -6.316731016557851}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-10.759623608071863`, -1.767249371950954}, {
            3.399186938124422, 8.083980388508804}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-10.759623608071863`, -1.767249371950954}, {-5.5, \
-7.361215932167728}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-8.899186938124423, -4.996174644486022}, {-5.5, \
-7.361215932167728}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-8.899186938124423, -4.996174644486022}, {
            10.049000034068609`, -3.4572614661443013`}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-5.5, -7.361215932167728}, {-1.1498130959441881`, \
-8.453436110630323}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-5.5, -7.361215932167728}, {11., 0.}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 
                 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, {-1., \
-0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-1.1498130959441881`, -8.453436110630323}, {
            10.049000034068609`, 3.4572614661443013`}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-1.1498130959441881`, -8.453436110630323}, {
            3.399186938124422, -8.083980388508804}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{3.399186938124422, -8.083980388508804}, {
            7.360436669947441, 6.316731016557851}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{3.399186938124422, -8.083980388508804}, {
            7.360436669947441, -6.316731016557851}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 
                 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, {-1., \
-0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{
            7.360436669947441, -6.316731016557851}, {-1.1498130959441881`, 
            8.453436110630323}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{7.360436669947441, -6.316731016557851}, {
            10.049000034068609`, -3.4572614661443013`}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{
            10.049000034068609`, -3.4572614661443013`}, {-8.899186938124423, 
            4.996174644486022}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{10.049000034068609`, -3.4572614661443013`}, {11., 
            0.}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{11., 0.}, {10.049000034068609`, 3.4572614661443013`}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{11., 
            0.}, {-10.759623608071863`, -1.767249371950954}}]}}, 
         {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
          0.7]}], {
           DiskBox[{10.049000034068609, 3.4572614661443013}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 0\\nPayoff: 154\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {10.049000034068609, 3.4572614661443013},
            BaseStyle->"Graphics"]}, {
           DiskBox[{7.360436669947441, 6.316731016557851}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 1\\nPayoff: 68\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {7.360436669947441, 6.316731016557851},
            BaseStyle->"Graphics"]}, {
           DiskBox[{3.399186938124422, 8.083980388508804}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 5\\nPayoff: 36\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {3.399186938124422, 8.083980388508804},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-1.1498130959441881, 8.453436110630323}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 2\\nPayoff: 136\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-1.1498130959441881, 8.453436110630323},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-5.5, 7.361215932167728}, 0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 6\\nPayoff: 196\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-5.5, 7.361215932167728},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-8.899186938124423, 4.996174644486022}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 3\\nPayoff: 94\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-8.899186938124423, 4.996174644486022},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-10.759623608071863, 1.767249371950954}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 7\\nPayoff: 112\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-10.759623608071863, 1.767249371950954},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-10.759623608071863, -1.767249371950954}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 4\\nPayoff: 73\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-10.759623608071863, -1.767249371950954},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-8.899186938124423, -4.996174644486022}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 8\\nPayoff: 68\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-8.899186938124423, -4.996174644486022},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-5.5, -7.361215932167728}, 0.09359782207206707], 
           InsetBox[
            PanelBox["\<\"Number: 9\\nPayoff: 75\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-5.5, -7.361215932167728},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-1.1498130959441881, -8.453436110630323}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 10\\nPayoff: 4\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-1.1498130959441881, -8.453436110630323},
            BaseStyle->"Graphics"]}, {
           DiskBox[{3.399186938124422, -8.083980388508804}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 11\\nPayoff: 172\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {3.399186938124422, -8.083980388508804},
            BaseStyle->"Graphics"]}, {
           DiskBox[{7.360436669947441, -6.316731016557851}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 12\\nPayoff: 68\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {7.360436669947441, -6.316731016557851},
            BaseStyle->"Graphics"]}, {
           DiskBox[{10.049000034068609, -3.4572614661443013}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 13\\nPayoff: 52\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {10.049000034068609, -3.4572614661443013},
            BaseStyle->"Graphics"]}, {DiskBox[{11., 0.}, 0.09359782207206707],
            InsetBox[
            PanelBox["\<\"Number: 14\\nPayoff: 113\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {11., 0.},
            BaseStyle->"Graphics"]}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None,
    ImageSize->Large], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{0, 4, 5, 1, 6, 2, 7, 3, 8, 9, 10, 11, 12, 13, 
        14}, {{{1, 2}, {1, 3}, {4, 3}, {4, 5}, {6, 5}, {6, 7}, {8, 7}, {8, 
         9}, {2, 9}, {2, 10}, {3, 10}, {3, 11}, {5, 11}, {5, 12}, {7, 12}, {7,
          13}, {9, 13}, {9, 14}, {10, 14}, {10, 15}, {11, 1}, {11, 15}, {12, 
         1}, {12, 4}, {13, 4}, {13, 6}, {14, 6}, {14, 8}, {15, 8}, {15, 2}}, 
         Null}, {EdgeShapeFunction -> {
           GraphElementData["UnfilledArrow", "ArrowSize" -> 0.03]}, ImageSize -> 
         Large, VertexCoordinates -> {{
           11 Cos[Rational[2, 15] Pi], 3.4572614661443013`}, {
           11 Sin[Rational[7, 30] Pi], 6.316731016557851}, {
           Rational[11, 4] (-1 + 5^Rational[1, 2]), 
            8.083980388508804}, {(-11) Sin[Rational[1, 30] Pi], 
            8.453436110630323}, {
            Rational[-11, 2], 7.361215932167728}, {
           Rational[11, 4] (-1 - 5^Rational[1, 2]), 
            4.996174644486022}, {(-11) Cos[Rational[1, 15] Pi], 
            1.767249371950954}, {(-11) 
            Cos[Rational[1, 15] Pi], -1.767249371950954}, {
           Rational[11, 4] (-1 - 5^Rational[1, 2]), -4.996174644486022}, {
            Rational[-11, 2], -7.361215932167728}, {(-11) 
            Sin[Rational[1, 30] Pi], -8.453436110630323}, {
           Rational[11, 4] (-1 + 5^Rational[1, 2]), -8.083980388508804}, {
           11 Sin[Rational[7, 30] Pi], -6.316731016557851}, {
           11 Cos[Rational[2, 15] Pi], -3.4572614661443013`}, {11, 0.}}, 
         VertexLabels -> {
          6 -> Placed[
            "Number: 6\nPayoff: 196", Center, $CellContext`panelLabel], 3 -> 
           Placed["Number: 3\nPayoff: 94", Center, $CellContext`panelLabel], 
           11 -> Placed[
            "Number: 11\nPayoff: 172", Center, $CellContext`panelLabel], 5 -> 
           Placed["Number: 5\nPayoff: 36", Center, $CellContext`panelLabel], 
           8 -> Placed[
            "Number: 8\nPayoff: 68", Center, $CellContext`panelLabel], 7 -> 
           Placed["Number: 7\nPayoff: 112", Center, $CellContext`panelLabel], 
           14 -> Placed[
            "Number: 14\nPayoff: 113", Center, $CellContext`panelLabel], 10 -> 
           Placed["Number: 10\nPayoff: 4", Center, $CellContext`panelLabel], 
           9 -> Placed[
            "Number: 9\nPayoff: 75", Center, $CellContext`panelLabel], 4 -> 
           Placed["Number: 4\nPayoff: 73", Center, $CellContext`panelLabel], 
           12 -> 
           Placed["Number: 12\nPayoff: 68", Center, $CellContext`panelLabel], 
           13 -> Placed[
            "Number: 13\nPayoff: 52", Center, $CellContext`panelLabel], 2 -> 
           Placed["Number: 2\nPayoff: 136", Center, $CellContext`panelLabel], 
           1 -> Placed[
            "Number: 1\nPayoff: 68", Center, $CellContext`panelLabel], 0 -> 
           Placed["Number: 0\nPayoff: 154", 
             Center, $CellContext`panelLabel]}}]]}, 
      TagBox[GraphicsGroupBox[{
         {Hue[0.6, 0.7, 0.5], Opacity[0.7], 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{10.049000034068609`, 3.4572614661443013`}, {
            7.360436669947441, 6.316731016557851}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{10.049000034068609`, 3.4572614661443013`}, {
            3.399186938124422, 8.083980388508804}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{7.360436669947441, 
            6.316731016557851}, {-8.899186938124423, -4.996174644486022}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{7.360436669947441, 
            6.316731016557851}, {-5.5, -7.361215932167728}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{3.399186938124422, 
            8.083980388508804}, {-5.5, -7.361215932167728}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{3.399186938124422, 
            8.083980388508804}, {-1.1498130959441881`, -8.453436110630323}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-1.1498130959441881`, 8.453436110630323}, {
            3.399186938124422, 8.083980388508804}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-1.1498130959441881`, 8.453436110630323}, {-5.5, 
            7.361215932167728}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-5.5, 
            7.361215932167728}, {-1.1498130959441881`, -8.453436110630323}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-5.5, 7.361215932167728}, {
            3.399186938124422, -8.083980388508804}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-8.899186938124423, 4.996174644486022}, {-5.5, 
            7.361215932167728}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 
                 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, {-1., \
-0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-8.899186938124423, 
            4.996174644486022}, {-10.759623608071863`, 
            1.767249371950954}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-10.759623608071863`, 1.767249371950954}, {
            3.399186938124422, -8.083980388508804}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-10.759623608071863`, 1.767249371950954}, {
            7.360436669947441, -6.316731016557851}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-10.759623608071863`, -1.767249371950954}, \
{-10.759623608071863`, 1.767249371950954}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 
                 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, {-1., \
-0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-10.759623608071863`, -1.767249371950954}, \
{-8.899186938124423, -4.996174644486022}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-8.899186938124423, -4.996174644486022}, {
            7.360436669947441, -6.316731016557851}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-8.899186938124423, -4.996174644486022}, {
            10.049000034068609`, -3.4572614661443013`}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-5.5, -7.361215932167728}, {
            10.049000034068609`, -3.4572614661443013`}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 
                 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, {-1., \
-0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-5.5, -7.361215932167728}, {11., 0.}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-1.1498130959441881`, -8.453436110630323}, {
            10.049000034068609`, 3.4572614661443013`}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-1.1498130959441881`, -8.453436110630323}, {11., 0.}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{3.399186938124422, -8.083980388508804}, {
            10.049000034068609`, 3.4572614661443013`}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{
            3.399186938124422, -8.083980388508804}, {-1.1498130959441881`, 
            8.453436110630323}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{
            7.360436669947441, -6.316731016557851}, {-1.1498130959441881`, 
            8.453436110630323}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{
            7.360436669947441, -6.316731016557851}, {-8.899186938124423, 
            4.996174644486022}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{
            10.049000034068609`, -3.4572614661443013`}, {-8.899186938124423, 
            4.996174644486022}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{
            10.049000034068609`, -3.4572614661443013`}, \
{-10.759623608071863`, -1.767249371950954}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{11., 0.}, {7.360436669947441, 6.316731016557851}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{11., 
            0.}, {-10.759623608071863`, -1.767249371950954}}]}}, 
         {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
          0.7]}], {
           DiskBox[{10.049000034068609, 3.4572614661443013}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 0\\nPayoff: 154\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {10.049000034068609, 3.4572614661443013},
            BaseStyle->"Graphics"]}, {
           DiskBox[{7.360436669947441, 6.316731016557851}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 4\\nPayoff: 73\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {7.360436669947441, 6.316731016557851},
            BaseStyle->"Graphics"]}, {
           DiskBox[{3.399186938124422, 8.083980388508804}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 5\\nPayoff: 36\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {3.399186938124422, 8.083980388508804},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-1.1498130959441881, 8.453436110630323}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 1\\nPayoff: 68\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-1.1498130959441881, 8.453436110630323},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-5.5, 7.361215932167728}, 0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 6\\nPayoff: 196\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-5.5, 7.361215932167728},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-8.899186938124423, 4.996174644486022}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 2\\nPayoff: 136\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-8.899186938124423, 4.996174644486022},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-10.759623608071863, 1.767249371950954}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 7\\nPayoff: 112\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-10.759623608071863, 1.767249371950954},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-10.759623608071863, -1.767249371950954}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 3\\nPayoff: 94\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-10.759623608071863, -1.767249371950954},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-8.899186938124423, -4.996174644486022}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 8\\nPayoff: 68\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-8.899186938124423, -4.996174644486022},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-5.5, -7.361215932167728}, 0.09359782207206707], 
           InsetBox[
            PanelBox["\<\"Number: 9\\nPayoff: 75\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-5.5, -7.361215932167728},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-1.1498130959441881, -8.453436110630323}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 10\\nPayoff: 4\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-1.1498130959441881, -8.453436110630323},
            BaseStyle->"Graphics"]}, {
           DiskBox[{3.399186938124422, -8.083980388508804}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 11\\nPayoff: 172\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {3.399186938124422, -8.083980388508804},
            BaseStyle->"Graphics"]}, {
           DiskBox[{7.360436669947441, -6.316731016557851}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 12\\nPayoff: 68\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {7.360436669947441, -6.316731016557851},
            BaseStyle->"Graphics"]}, {
           DiskBox[{10.049000034068609, -3.4572614661443013}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 13\\nPayoff: 52\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {10.049000034068609, -3.4572614661443013},
            BaseStyle->"Graphics"]}, {DiskBox[{11., 0.}, 0.09359782207206707],
            InsetBox[
            PanelBox["\<\"Number: 14\\nPayoff: 113\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {11., 0.},
            BaseStyle->"Graphics"]}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None,
    ImageSize->Large], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{0, 4, 6, 1, 5, 7, 2, 8, 3, 9, 10, 11, 12, 13, 
        14}, {{{1, 2}, {1, 3}, {4, 5}, {4, 6}, {7, 3}, {7, 8}, {9, 6}, {9, 
         10}, {2, 8}, {2, 11}, {5, 10}, {5, 12}, {3, 11}, {3, 13}, {6, 12}, {
         6, 14}, {8, 13}, {8, 15}, {10, 1}, {10, 14}, {11, 4}, {11, 15}, {12, 
         1}, {12, 7}, {13, 4}, {13, 9}, {14, 7}, {14, 2}, {15, 9}, {15, 5}}, 
         Null}, {EdgeShapeFunction -> {
           GraphElementData["UnfilledArrow", "ArrowSize" -> 0.03]}, ImageSize -> 
         Large, VertexCoordinates -> {{
           11 Cos[Rational[2, 15] Pi], 3.4572614661443013`}, {
           11 Sin[Rational[7, 30] Pi], 6.316731016557851}, {
           Rational[11, 4] (-1 + 5^Rational[1, 2]), 
            8.083980388508804}, {(-11) Sin[Rational[1, 30] Pi], 
            8.453436110630323}, {
            Rational[-11, 2], 7.361215932167728}, {
           Rational[11, 4] (-1 - 5^Rational[1, 2]), 
            4.996174644486022}, {(-11) Cos[Rational[1, 15] Pi], 
            1.767249371950954}, {(-11) 
            Cos[Rational[1, 15] Pi], -1.767249371950954}, {
           Rational[11, 4] (-1 - 5^Rational[1, 2]), -4.996174644486022}, {
            Rational[-11, 2], -7.361215932167728}, {(-11) 
            Sin[Rational[1, 30] Pi], -8.453436110630323}, {
           Rational[11, 4] (-1 + 5^Rational[1, 2]), -8.083980388508804}, {
           11 Sin[Rational[7, 30] Pi], -6.316731016557851}, {
           11 Cos[Rational[2, 15] Pi], -3.4572614661443013`}, {11, 0.}}, 
         VertexLabels -> {
          6 -> Placed[
            "Number: 6\nPayoff: 196", Center, $CellContext`panelLabel], 3 -> 
           Placed["Number: 3\nPayoff: 94", Center, $CellContext`panelLabel], 
           11 -> Placed[
            "Number: 11\nPayoff: 172", Center, $CellContext`panelLabel], 5 -> 
           Placed["Number: 5\nPayoff: 36", Center, $CellContext`panelLabel], 
           8 -> 
           Placed["Number: 8\nPayoff: 68", Center, $CellContext`panelLabel], 
           7 -> Placed[
            "Number: 7\nPayoff: 112", Center, $CellContext`panelLabel], 14 -> 
           Placed["Number: 14\nPayoff: 113", Center, $CellContext`panelLabel],
            10 -> Placed[
            "Number: 10\nPayoff: 4", Center, $CellContext`panelLabel], 9 -> 
           Placed["Number: 9\nPayoff: 75", Center, $CellContext`panelLabel], 
           4 -> Placed[
            "Number: 4\nPayoff: 73", Center, $CellContext`panelLabel], 12 -> 
           Placed["Number: 12\nPayoff: 68", Center, $CellContext`panelLabel], 
           13 -> Placed[
            "Number: 13\nPayoff: 52", Center, $CellContext`panelLabel], 2 -> 
           Placed["Number: 2\nPayoff: 136", Center, $CellContext`panelLabel], 
           1 -> Placed[
            "Number: 1\nPayoff: 68", Center, $CellContext`panelLabel], 0 -> 
           Placed["Number: 0\nPayoff: 154", 
             Center, $CellContext`panelLabel]}}]]}, 
      TagBox[GraphicsGroupBox[{
         {Hue[0.6, 0.7, 0.5], Opacity[0.7], 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{10.049000034068609`, 3.4572614661443013`}, {
            7.360436669947441, 6.316731016557851}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{10.049000034068609`, 3.4572614661443013`}, {
            3.399186938124422, 8.083980388508804}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{7.360436669947441, 
            6.316731016557851}, {-10.759623608071863`, -1.767249371950954}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{7.360436669947441, 
            6.316731016557851}, {-1.1498130959441881`, -8.453436110630323}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{3.399186938124422, 
            8.083980388508804}, {-1.1498130959441881`, -8.453436110630323}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{3.399186938124422, 8.083980388508804}, {
            7.360436669947441, -6.316731016557851}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-1.1498130959441881`, 8.453436110630323}, {-5.5, 
            7.361215932167728}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-1.1498130959441881`, 
            8.453436110630323}, {-8.899186938124423, 4.996174644486022}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-5.5, 7.361215932167728}, {-5.5, -7.361215932167728}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-5.5, 7.361215932167728}, {
            3.399186938124422, -8.083980388508804}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 
                 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, {-1., \
-0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-8.899186938124423, 4.996174644486022}, {
            3.399186938124422, -8.083980388508804}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-8.899186938124423, 4.996174644486022}, {
            10.049000034068609`, -3.4572614661443013`}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-10.759623608071863`, 1.767249371950954}, {
            3.399186938124422, 8.083980388508804}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-10.759623608071863`, 
            1.767249371950954}, {-10.759623608071863`, -1.767249371950954}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 
                 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, {-1., \
-0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-10.759623608071863`, -1.767249371950954}, {
            7.360436669947441, -6.316731016557851}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-10.759623608071863`, -1.767249371950954}, {11., 0.}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-8.899186938124423, -4.996174644486022}, \
{-8.899186938124423, 4.996174644486022}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-8.899186938124423, -4.996174644486022}, {-5.5, \
-7.361215932167728}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-5.5, -7.361215932167728}, {10.049000034068609`, 
            3.4572614661443013`}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-5.5, -7.361215932167728}, {
            10.049000034068609`, -3.4572614661443013`}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-1.1498130959441881`, -8.453436110630323}, \
{-1.1498130959441881`, 8.453436110630323}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-1.1498130959441881`, -8.453436110630323}, {11., 0.}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{3.399186938124422, -8.083980388508804}, {
            10.049000034068609`, 3.4572614661443013`}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{
            3.399186938124422, -8.083980388508804}, {-10.759623608071863`, 
            1.767249371950954}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{
            7.360436669947441, -6.316731016557851}, {-1.1498130959441881`, 
            8.453436110630323}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{
            7.360436669947441, -6.316731016557851}, {-8.899186938124423, \
-4.996174644486022}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{10.049000034068609`, -3.4572614661443013`}, {
            7.360436669947441, 6.316731016557851}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{
            10.049000034068609`, -3.4572614661443013`}, {-10.759623608071863`,
             1.767249371950954}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{11., 0.}, {-5.5, 7.361215932167728}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{11., 
            0.}, {-8.899186938124423, -4.996174644486022}}]}}, 
         {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
          0.7]}], {
           DiskBox[{10.049000034068609, 3.4572614661443013}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 0\\nPayoff: 154\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {10.049000034068609, 3.4572614661443013},
            BaseStyle->"Graphics"]}, {
           DiskBox[{7.360436669947441, 6.316731016557851}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 4\\nPayoff: 73\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {7.360436669947441, 6.316731016557851},
            BaseStyle->"Graphics"]}, {
           DiskBox[{3.399186938124422, 8.083980388508804}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 6\\nPayoff: 196\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {3.399186938124422, 8.083980388508804},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-1.1498130959441881, 8.453436110630323}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 1\\nPayoff: 68\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-1.1498130959441881, 8.453436110630323},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-5.5, 7.361215932167728}, 0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 5\\nPayoff: 36\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-5.5, 7.361215932167728},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-8.899186938124423, 4.996174644486022}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 7\\nPayoff: 112\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-8.899186938124423, 4.996174644486022},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-10.759623608071863, 1.767249371950954}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 2\\nPayoff: 136\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-10.759623608071863, 1.767249371950954},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-10.759623608071863, -1.767249371950954}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 8\\nPayoff: 68\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-10.759623608071863, -1.767249371950954},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-8.899186938124423, -4.996174644486022}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 3\\nPayoff: 94\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-8.899186938124423, -4.996174644486022},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-5.5, -7.361215932167728}, 0.09359782207206707], 
           InsetBox[
            PanelBox["\<\"Number: 9\\nPayoff: 75\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-5.5, -7.361215932167728},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-1.1498130959441881, -8.453436110630323}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 10\\nPayoff: 4\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-1.1498130959441881, -8.453436110630323},
            BaseStyle->"Graphics"]}, {
           DiskBox[{3.399186938124422, -8.083980388508804}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 11\\nPayoff: 172\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {3.399186938124422, -8.083980388508804},
            BaseStyle->"Graphics"]}, {
           DiskBox[{7.360436669947441, -6.316731016557851}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 12\\nPayoff: 68\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {7.360436669947441, -6.316731016557851},
            BaseStyle->"Graphics"]}, {
           DiskBox[{10.049000034068609, -3.4572614661443013}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 13\\nPayoff: 52\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {10.049000034068609, -3.4572614661443013},
            BaseStyle->"Graphics"]}, {DiskBox[{11., 0.}, 0.09359782207206707],
            InsetBox[
            PanelBox["\<\"Number: 14\\nPayoff: 113\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {11., 0.},
            BaseStyle->"Graphics"]}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None,
    ImageSize->Large], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{0, 8, 9, 1, 10, 2, 11, 3, 12, 4, 13, 5, 14, 6, 
        7}, {{{1, 2}, {1, 3}, {4, 3}, {4, 5}, {6, 5}, {6, 7}, {8, 7}, {8, 
         9}, {10, 9}, {10, 11}, {12, 11}, {12, 13}, {14, 1}, {14, 13}, {15, 
         1}, {15, 4}, {2, 4}, {2, 6}, {3, 6}, {3, 8}, {5, 8}, {5, 10}, {7, 
         10}, {7, 12}, {9, 12}, {9, 14}, {11, 14}, {11, 15}, {13, 15}, {13, 
         2}}, Null}, {EdgeShapeFunction -> {
           GraphElementData["UnfilledArrow", "ArrowSize" -> 0.03]}, ImageSize -> 
         Large, VertexCoordinates -> {{
           11 Cos[Rational[2, 15] Pi], 3.4572614661443013`}, {
           11 Sin[Rational[7, 30] Pi], 6.316731016557851}, {
           Rational[11, 4] (-1 + 5^Rational[1, 2]), 
            8.083980388508804}, {(-11) Sin[Rational[1, 30] Pi], 
            8.453436110630323}, {
            Rational[-11, 2], 7.361215932167728}, {
           Rational[11, 4] (-1 - 5^Rational[1, 2]), 
            4.996174644486022}, {(-11) Cos[Rational[1, 15] Pi], 
            1.767249371950954}, {(-11) 
            Cos[Rational[1, 15] Pi], -1.767249371950954}, {
           Rational[11, 4] (-1 - 5^Rational[1, 2]), -4.996174644486022}, {
            Rational[-11, 2], -7.361215932167728}, {(-11) 
            Sin[Rational[1, 30] Pi], -8.453436110630323}, {
           Rational[11, 4] (-1 + 5^Rational[1, 2]), -8.083980388508804}, {
           11 Sin[Rational[7, 30] Pi], -6.316731016557851}, {
           11 Cos[Rational[2, 15] Pi], -3.4572614661443013`}, {11, 0.}}, 
         VertexLabels -> {
          6 -> Placed[
            "Number: 6\nPayoff: 196", Center, $CellContext`panelLabel], 3 -> 
           Placed["Number: 3\nPayoff: 94", Center, $CellContext`panelLabel], 
           11 -> Placed[
            "Number: 11\nPayoff: 172", Center, $CellContext`panelLabel], 5 -> 
           Placed["Number: 5\nPayoff: 36", Center, $CellContext`panelLabel], 
           8 -> Placed[
            "Number: 8\nPayoff: 68", Center, $CellContext`panelLabel], 7 -> 
           Placed["Number: 7\nPayoff: 112", Center, $CellContext`panelLabel], 
           14 -> Placed[
            "Number: 14\nPayoff: 113", Center, $CellContext`panelLabel], 10 -> 
           Placed["Number: 10\nPayoff: 4", Center, $CellContext`panelLabel], 
           9 -> Placed[
            "Number: 9\nPayoff: 75", Center, $CellContext`panelLabel], 4 -> 
           Placed["Number: 4\nPayoff: 73", Center, $CellContext`panelLabel], 
           12 -> Placed[
            "Number: 12\nPayoff: 68", Center, $CellContext`panelLabel], 13 -> 
           Placed["Number: 13\nPayoff: 52", Center, $CellContext`panelLabel], 
           2 -> Placed[
            "Number: 2\nPayoff: 136", Center, $CellContext`panelLabel], 1 -> 
           Placed["Number: 1\nPayoff: 68", Center, $CellContext`panelLabel], 
           0 -> Placed[
            "Number: 0\nPayoff: 154", Center, $CellContext`panelLabel]}}]]}, 
      TagBox[GraphicsGroupBox[{
         {Hue[0.6, 0.7, 0.5], Opacity[0.7], 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{10.049000034068609`, 3.4572614661443013`}, {
            7.360436669947441, 6.316731016557851}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 
                 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, {-1., \
-0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{10.049000034068609`, 3.4572614661443013`}, {
            3.399186938124422, 8.083980388508804}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{7.360436669947441, 
            6.316731016557851}, {-1.1498130959441881`, 
            8.453436110630323}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{7.360436669947441, 
            6.316731016557851}, {-8.899186938124423, 4.996174644486022}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{3.399186938124422, 
            8.083980388508804}, {-8.899186938124423, 4.996174644486022}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 
                 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, {-1., \
-0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{3.399186938124422, 
            8.083980388508804}, {-10.759623608071863`, -1.767249371950954}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-1.1498130959441881`, 8.453436110630323}, {
            3.399186938124422, 8.083980388508804}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-1.1498130959441881`, 8.453436110630323}, {-5.5, 
            7.361215932167728}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-5.5, 
            7.361215932167728}, {-10.759623608071863`, -1.767249371950954}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-5.5, 7.361215932167728}, {-5.5, -7.361215932167728}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-8.899186938124423, 4.996174644486022}, {-5.5, 
            7.361215932167728}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-8.899186938124423, 
            4.996174644486022}, {-10.759623608071863`, 
            1.767249371950954}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-10.759623608071863`, 
            1.767249371950954}, {-5.5, -7.361215932167728}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-10.759623608071863`, 1.767249371950954}, {
            3.399186938124422, -8.083980388508804}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-10.759623608071863`, -1.767249371950954}, \
{-10.759623608071863`, 1.767249371950954}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-10.759623608071863`, -1.767249371950954}, \
{-8.899186938124423, -4.996174644486022}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-8.899186938124423, -4.996174644486022}, {
            3.399186938124422, -8.083980388508804}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-8.899186938124423, -4.996174644486022}, {
            10.049000034068609`, -3.4572614661443013`}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-5.5, -7.361215932167728}, {-8.899186938124423, \
-4.996174644486022}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-5.5, -7.361215932167728}, {-1.1498130959441881`, \
-8.453436110630323}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-1.1498130959441881`, -8.453436110630323}, {
            10.049000034068609`, -3.4572614661443013`}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-1.1498130959441881`, -8.453436110630323}, {11., 0.}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{
            3.399186938124422, -8.083980388508804}, {-1.1498130959441881`, \
-8.453436110630323}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{3.399186938124422, -8.083980388508804}, {
            7.360436669947441, -6.316731016557851}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{7.360436669947441, -6.316731016557851}, {
            7.360436669947441, 6.316731016557851}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{7.360436669947441, -6.316731016557851}, {11., 0.}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{10.049000034068609`, -3.4572614661443013`}, {
            10.049000034068609`, 3.4572614661443013`}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{10.049000034068609`, -3.4572614661443013`}, {
            7.360436669947441, -6.316731016557851}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{11., 0.}, {10.049000034068609`, 3.4572614661443013`}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{11., 0.}, {-1.1498130959441881`, 8.453436110630323}}]}}, 
         {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
          0.7]}], {
           DiskBox[{10.049000034068609, 3.4572614661443013}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 0\\nPayoff: 154\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {10.049000034068609, 3.4572614661443013},
            BaseStyle->"Graphics"]}, {
           DiskBox[{7.360436669947441, 6.316731016557851}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 8\\nPayoff: 68\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {7.360436669947441, 6.316731016557851},
            BaseStyle->"Graphics"]}, {
           DiskBox[{3.399186938124422, 8.083980388508804}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 9\\nPayoff: 75\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {3.399186938124422, 8.083980388508804},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-1.1498130959441881, 8.453436110630323}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 1\\nPayoff: 68\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-1.1498130959441881, 8.453436110630323},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-5.5, 7.361215932167728}, 0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 10\\nPayoff: 4\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-5.5, 7.361215932167728},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-8.899186938124423, 4.996174644486022}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 2\\nPayoff: 136\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-8.899186938124423, 4.996174644486022},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-10.759623608071863, 1.767249371950954}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 11\\nPayoff: 172\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-10.759623608071863, 1.767249371950954},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-10.759623608071863, -1.767249371950954}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 3\\nPayoff: 94\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-10.759623608071863, -1.767249371950954},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-8.899186938124423, -4.996174644486022}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 12\\nPayoff: 68\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-8.899186938124423, -4.996174644486022},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-5.5, -7.361215932167728}, 0.09359782207206707], 
           InsetBox[
            PanelBox["\<\"Number: 4\\nPayoff: 73\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-5.5, -7.361215932167728},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-1.1498130959441881, -8.453436110630323}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 13\\nPayoff: 52\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-1.1498130959441881, -8.453436110630323},
            BaseStyle->"Graphics"]}, {
           DiskBox[{3.399186938124422, -8.083980388508804}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 5\\nPayoff: 36\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {3.399186938124422, -8.083980388508804},
            BaseStyle->"Graphics"]}, {
           DiskBox[{7.360436669947441, -6.316731016557851}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 14\\nPayoff: 113\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {7.360436669947441, -6.316731016557851},
            BaseStyle->"Graphics"]}, {
           DiskBox[{10.049000034068609, -3.4572614661443013}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 6\\nPayoff: 196\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {10.049000034068609, -3.4572614661443013},
            BaseStyle->"Graphics"]}, {DiskBox[{11., 0.}, 0.09359782207206707],
            InsetBox[
            PanelBox["\<\"Number: 7\\nPayoff: 112\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {11., 0.},
            BaseStyle->"Graphics"]}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None,
    ImageSize->Large], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{0, 5, 8, 1, 6, 9, 2, 7, 10, 3, 11, 4, 12, 13, 
        14}, {{{1, 2}, {1, 3}, {4, 5}, {4, 6}, {7, 8}, {7, 9}, {10, 3}, {10, 
         11}, {12, 6}, {12, 13}, {2, 9}, {2, 14}, {5, 11}, {5, 15}, {8, 1}, {
         8, 13}, {3, 4}, {3, 14}, {6, 7}, {6, 15}, {9, 1}, {9, 10}, {11, 4}, {
         11, 12}, {13, 7}, {13, 2}, {14, 10}, {14, 5}, {15, 12}, {15, 8}}, 
         Null}, {EdgeShapeFunction -> {
           GraphElementData["UnfilledArrow", "ArrowSize" -> 0.03]}, ImageSize -> 
         Large, VertexCoordinates -> {{
           11 Cos[Rational[2, 15] Pi], 3.4572614661443013`}, {
           11 Sin[Rational[7, 30] Pi], 6.316731016557851}, {
           Rational[11, 4] (-1 + 5^Rational[1, 2]), 
            8.083980388508804}, {(-11) Sin[Rational[1, 30] Pi], 
            8.453436110630323}, {
            Rational[-11, 2], 7.361215932167728}, {
           Rational[11, 4] (-1 - 5^Rational[1, 2]), 
            4.996174644486022}, {(-11) Cos[Rational[1, 15] Pi], 
            1.767249371950954}, {(-11) 
            Cos[Rational[1, 15] Pi], -1.767249371950954}, {
           Rational[11, 4] (-1 - 5^Rational[1, 2]), -4.996174644486022}, {
            Rational[-11, 2], -7.361215932167728}, {(-11) 
            Sin[Rational[1, 30] Pi], -8.453436110630323}, {
           Rational[11, 4] (-1 + 5^Rational[1, 2]), -8.083980388508804}, {
           11 Sin[Rational[7, 30] Pi], -6.316731016557851}, {
           11 Cos[Rational[2, 15] Pi], -3.4572614661443013`}, {11, 0.}}, 
         VertexLabels -> {
          6 -> Placed[
            "Number: 6\nPayoff: 196", Center, $CellContext`panelLabel], 3 -> 
           Placed["Number: 3\nPayoff: 94", Center, $CellContext`panelLabel], 
           11 -> Placed[
            "Number: 11\nPayoff: 172", Center, $CellContext`panelLabel], 5 -> 
           Placed["Number: 5\nPayoff: 36", Center, $CellContext`panelLabel], 
           8 -> Placed[
            "Number: 8\nPayoff: 68", Center, $CellContext`panelLabel], 7 -> 
           Placed["Number: 7\nPayoff: 112", Center, $CellContext`panelLabel], 
           14 -> Placed[
            "Number: 14\nPayoff: 113", Center, $CellContext`panelLabel], 10 -> 
           Placed["Number: 10\nPayoff: 4", Center, $CellContext`panelLabel], 
           9 -> Placed[
            "Number: 9\nPayoff: 75", Center, $CellContext`panelLabel], 4 -> 
           Placed["Number: 4\nPayoff: 73", Center, $CellContext`panelLabel], 
           12 -> Placed[
            "Number: 12\nPayoff: 68", Center, $CellContext`panelLabel], 13 -> 
           Placed["Number: 13\nPayoff: 52", Center, $CellContext`panelLabel], 
           2 -> Placed[
            "Number: 2\nPayoff: 136", Center, $CellContext`panelLabel], 1 -> 
           Placed["Number: 1\nPayoff: 68", Center, $CellContext`panelLabel], 
           0 -> Placed[
            "Number: 0\nPayoff: 154", Center, $CellContext`panelLabel]}}]]}, 
      TagBox[GraphicsGroupBox[{
         {Hue[0.6, 0.7, 0.5], Opacity[0.7], 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{10.049000034068609`, 3.4572614661443013`}, {
            7.360436669947441, 6.316731016557851}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{10.049000034068609`, 3.4572614661443013`}, {
            3.399186938124422, 8.083980388508804}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{7.360436669947441, 
            6.316731016557851}, {-8.899186938124423, -4.996174644486022}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{7.360436669947441, 6.316731016557851}, {
            10.049000034068609`, -3.4572614661443013`}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{3.399186938124422, 
            8.083980388508804}, {-1.1498130959441881`, 
            8.453436110630323}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{3.399186938124422, 8.083980388508804}, {
            10.049000034068609`, -3.4572614661443013`}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-1.1498130959441881`, 8.453436110630323}, {-5.5, 
            7.361215932167728}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-1.1498130959441881`, 
            8.453436110630323}, {-8.899186938124423, 4.996174644486022}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-5.5, 
            7.361215932167728}, {-1.1498130959441881`, -8.453436110630323}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-5.5, 7.361215932167728}, {11., 0.}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-8.899186938124423, 
            4.996174644486022}, {-10.759623608071863`, 
            1.767249371950954}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-8.899186938124423, 4.996174644486022}, {11., 0.}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-10.759623608071863`, 
            1.767249371950954}, {-10.759623608071863`, -1.767249371950954}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-10.759623608071863`, 
            1.767249371950954}, {-8.899186938124423, -4.996174644486022}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-10.759623608071863`, -1.767249371950954}, {
            10.049000034068609`, 3.4572614661443013`}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-10.759623608071863`, -1.767249371950954}, {
            7.360436669947441, -6.316731016557851}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-8.899186938124423, -4.996174644486022}, {
            10.049000034068609`, 3.4572614661443013`}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-8.899186938124423, -4.996174644486022}, {-5.5, \
-7.361215932167728}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-5.5, -7.361215932167728}, {3.399186938124422, 
            8.083980388508804}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-5.5, -7.361215932167728}, {-1.1498130959441881`, \
-8.453436110630323}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           
           ArrowBox[{{-1.1498130959441881`, -8.453436110630323}, \
{-1.1498130959441881`, 8.453436110630323}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-1.1498130959441881`, -8.453436110630323}, {
            3.399186938124422, -8.083980388508804}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{
            3.399186938124422, -8.083980388508804}, {-8.899186938124423, 
            4.996174644486022}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{3.399186938124422, -8.083980388508804}, {
            7.360436669947441, -6.316731016557851}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{7.360436669947441, -6.316731016557851}, {
            7.360436669947441, 6.316731016557851}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{
            7.360436669947441, -6.316731016557851}, {-10.759623608071863`, 
            1.767249371950954}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{10.049000034068609`, -3.4572614661443013`}, {-5.5, 
            7.361215932167728}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{
            10.049000034068609`, -3.4572614661443013`}, {-5.5, \
-7.361215932167728}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{11., 0.}, {-10.759623608071863`, -1.767249371950954}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{11., 0.}, {3.399186938124422, -8.083980388508804}}]}}, 
         {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
          0.7]}], {
           DiskBox[{10.049000034068609, 3.4572614661443013}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 0\\nPayoff: 154\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {10.049000034068609, 3.4572614661443013},
            BaseStyle->"Graphics"]}, {
           DiskBox[{7.360436669947441, 6.316731016557851}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 5\\nPayoff: 36\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {7.360436669947441, 6.316731016557851},
            BaseStyle->"Graphics"]}, {
           DiskBox[{3.399186938124422, 8.083980388508804}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 8\\nPayoff: 68\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {3.399186938124422, 8.083980388508804},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-1.1498130959441881, 8.453436110630323}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 1\\nPayoff: 68\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-1.1498130959441881, 8.453436110630323},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-5.5, 7.361215932167728}, 0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 6\\nPayoff: 196\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-5.5, 7.361215932167728},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-8.899186938124423, 4.996174644486022}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 9\\nPayoff: 75\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-8.899186938124423, 4.996174644486022},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-10.759623608071863, 1.767249371950954}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 2\\nPayoff: 136\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-10.759623608071863, 1.767249371950954},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-10.759623608071863, -1.767249371950954}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 7\\nPayoff: 112\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-10.759623608071863, -1.767249371950954},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-8.899186938124423, -4.996174644486022}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 10\\nPayoff: 4\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-8.899186938124423, -4.996174644486022},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-5.5, -7.361215932167728}, 0.09359782207206707], 
           InsetBox[
            PanelBox["\<\"Number: 3\\nPayoff: 94\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-5.5, -7.361215932167728},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-1.1498130959441881, -8.453436110630323}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 11\\nPayoff: 172\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-1.1498130959441881, -8.453436110630323},
            BaseStyle->"Graphics"]}, {
           DiskBox[{3.399186938124422, -8.083980388508804}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 4\\nPayoff: 73\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {3.399186938124422, -8.083980388508804},
            BaseStyle->"Graphics"]}, {
           DiskBox[{7.360436669947441, -6.316731016557851}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 12\\nPayoff: 68\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {7.360436669947441, -6.316731016557851},
            BaseStyle->"Graphics"]}, {
           DiskBox[{10.049000034068609, -3.4572614661443013}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 13\\nPayoff: 52\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {10.049000034068609, -3.4572614661443013},
            BaseStyle->"Graphics"]}, {DiskBox[{11., 0.}, 0.09359782207206707],
            InsetBox[
            PanelBox["\<\"Number: 14\\nPayoff: 113\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {11., 0.},
            BaseStyle->"Graphics"]}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None,
    ImageSize->Large], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{0, 1, 4, 2, 5, 3, 6, 7, 8, 9, 10, 11, 12, 13, 
        14}, {{{1, 2}, {1, 3}, {2, 4}, {2, 5}, {4, 6}, {4, 7}, {6, 3}, {6, 
         8}, {3, 5}, {3, 9}, {5, 7}, {5, 10}, {7, 8}, {7, 11}, {8, 9}, {8, 
         12}, {9, 10}, {9, 13}, {10, 11}, {10, 14}, {11, 12}, {11, 15}, {12, 
         1}, {12, 13}, {13, 2}, {13, 14}, {14, 4}, {14, 15}, {15, 1}, {15, 
         6}}, Null}, {EdgeShapeFunction -> {
           GraphElementData["UnfilledArrow", "ArrowSize" -> 0.03]}, ImageSize -> 
         Large, VertexCoordinates -> {{
           11 Cos[Rational[2, 15] Pi], 3.4572614661443013`}, {
           11 Sin[Rational[7, 30] Pi], 6.316731016557851}, {
           Rational[11, 4] (-1 + 5^Rational[1, 2]), 
            8.083980388508804}, {(-11) Sin[Rational[1, 30] Pi], 
            8.453436110630323}, {
            Rational[-11, 2], 7.361215932167728}, {
           Rational[11, 4] (-1 - 5^Rational[1, 2]), 
            4.996174644486022}, {(-11) Cos[Rational[1, 15] Pi], 
            1.767249371950954}, {(-11) 
            Cos[Rational[1, 15] Pi], -1.767249371950954}, {
           Rational[11, 4] (-1 - 5^Rational[1, 2]), -4.996174644486022}, {
            Rational[-11, 2], -7.361215932167728}, {(-11) 
            Sin[Rational[1, 30] Pi], -8.453436110630323}, {
           Rational[11, 4] (-1 + 5^Rational[1, 2]), -8.083980388508804}, {
           11 Sin[Rational[7, 30] Pi], -6.316731016557851}, {
           11 Cos[Rational[2, 15] Pi], -3.4572614661443013`}, {11, 0.}}, 
         VertexLabels -> {
          6 -> Placed[
            "Number: 6\nPayoff: 196", Center, $CellContext`panelLabel], 3 -> 
           Placed["Number: 3\nPayoff: 94", Center, $CellContext`panelLabel], 
           11 -> Placed[
            "Number: 11\nPayoff: 172", Center, $CellContext`panelLabel], 5 -> 
           Placed["Number: 5\nPayoff: 36", Center, $CellContext`panelLabel], 
           8 -> Placed[
            "Number: 8\nPayoff: 68", Center, $CellContext`panelLabel], 7 -> 
           Placed["Number: 7\nPayoff: 112", Center, $CellContext`panelLabel], 
           14 -> Placed[
            "Number: 14\nPayoff: 113", Center, $CellContext`panelLabel], 10 -> 
           Placed["Number: 10\nPayoff: 4", Center, $CellContext`panelLabel], 
           9 -> Placed[
            "Number: 9\nPayoff: 75", Center, $CellContext`panelLabel], 4 -> 
           Placed["Number: 4\nPayoff: 73", Center, $CellContext`panelLabel], 
           12 -> Placed[
            "Number: 12\nPayoff: 68", Center, $CellContext`panelLabel], 13 -> 
           Placed["Number: 13\nPayoff: 52", Center, $CellContext`panelLabel], 
           2 -> Placed[
            "Number: 2\nPayoff: 136", Center, $CellContext`panelLabel], 1 -> 
           Placed["Number: 1\nPayoff: 68", Center, $CellContext`panelLabel], 
           0 -> Placed[
            "Number: 0\nPayoff: 154", Center, $CellContext`panelLabel]}}]]}, 
      TagBox[GraphicsGroupBox[{
         {Hue[0.6, 0.7, 0.5], Opacity[0.7], 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{10.049000034068609`, 3.4572614661443013`}, {
            7.360436669947441, 6.316731016557851}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{10.049000034068609`, 3.4572614661443013`}, {
            3.399186938124422, 8.083980388508804}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{7.360436669947441, 
            6.316731016557851}, {-1.1498130959441881`, 
            8.453436110630323}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{7.360436669947441, 6.316731016557851}, {-5.5, 
            7.361215932167728}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{3.399186938124422, 8.083980388508804}, {-5.5, 
            7.361215932167728}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{3.399186938124422, 
            8.083980388508804}, {-8.899186938124423, -4.996174644486022}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-1.1498130959441881`, 
            8.453436110630323}, {-8.899186938124423, 4.996174644486022}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-1.1498130959441881`, 
            8.453436110630323}, {-10.759623608071863`, 
            1.767249371950954}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-5.5, 7.361215932167728}, {-10.759623608071863`, 
            1.767249371950954}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-5.5, 7.361215932167728}, {-5.5, -7.361215932167728}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-8.899186938124423, 4.996174644486022}, {
            3.399186938124422, 8.083980388508804}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-8.899186938124423, 
            4.996174644486022}, {-10.759623608071863`, -1.767249371950954}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-10.759623608071863`, 
            1.767249371950954}, {-10.759623608071863`, -1.767249371950954}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-10.759623608071863`, 
            1.767249371950954}, {-1.1498130959441881`, -8.453436110630323}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-10.759623608071863`, -1.767249371950954}, \
{-8.899186938124423, -4.996174644486022}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-10.759623608071863`, -1.767249371950954}, {
            3.399186938124422, -8.083980388508804}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-8.899186938124423, -4.996174644486022}, {-5.5, \
-7.361215932167728}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-8.899186938124423, -4.996174644486022}, {
            7.360436669947441, -6.316731016557851}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-5.5, -7.361215932167728}, {-1.1498130959441881`, \
-8.453436110630323}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-5.5, -7.361215932167728}, {
            10.049000034068609`, -3.4572614661443013`}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-1.1498130959441881`, -8.453436110630323}, {
            3.399186938124422, -8.083980388508804}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-1.1498130959441881`, -8.453436110630323}, {11., 0.}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{3.399186938124422, -8.083980388508804}, {
            10.049000034068609`, 3.4572614661443013`}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{3.399186938124422, -8.083980388508804}, {
            7.360436669947441, -6.316731016557851}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{7.360436669947441, -6.316731016557851}, {
            7.360436669947441, 6.316731016557851}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{7.360436669947441, -6.316731016557851}, {
            10.049000034068609`, -3.4572614661443013`}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{
            10.049000034068609`, -3.4572614661443013`}, {-1.1498130959441881`,
             8.453436110630323}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{10.049000034068609`, -3.4572614661443013`}, {11., 
            0.}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{11., 0.}, {10.049000034068609`, 3.4572614661443013`}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{11., 0.}, {-8.899186938124423, 4.996174644486022}}]}}, 
         {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
          0.7]}], {
           DiskBox[{10.049000034068609, 3.4572614661443013}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 0\\nPayoff: 154\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {10.049000034068609, 3.4572614661443013},
            BaseStyle->"Graphics"]}, {
           DiskBox[{7.360436669947441, 6.316731016557851}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 1\\nPayoff: 68\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {7.360436669947441, 6.316731016557851},
            BaseStyle->"Graphics"]}, {
           DiskBox[{3.399186938124422, 8.083980388508804}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 4\\nPayoff: 73\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {3.399186938124422, 8.083980388508804},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-1.1498130959441881, 8.453436110630323}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 2\\nPayoff: 136\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-1.1498130959441881, 8.453436110630323},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-5.5, 7.361215932167728}, 0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 5\\nPayoff: 36\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-5.5, 7.361215932167728},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-8.899186938124423, 4.996174644486022}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 3\\nPayoff: 94\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-8.899186938124423, 4.996174644486022},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-10.759623608071863, 1.767249371950954}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 6\\nPayoff: 196\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-10.759623608071863, 1.767249371950954},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-10.759623608071863, -1.767249371950954}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 7\\nPayoff: 112\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-10.759623608071863, -1.767249371950954},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-8.899186938124423, -4.996174644486022}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 8\\nPayoff: 68\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-8.899186938124423, -4.996174644486022},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-5.5, -7.361215932167728}, 0.09359782207206707], 
           InsetBox[
            PanelBox["\<\"Number: 9\\nPayoff: 75\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-5.5, -7.361215932167728},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-1.1498130959441881, -8.453436110630323}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 10\\nPayoff: 4\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-1.1498130959441881, -8.453436110630323},
            BaseStyle->"Graphics"]}, {
           DiskBox[{3.399186938124422, -8.083980388508804}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 11\\nPayoff: 172\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {3.399186938124422, -8.083980388508804},
            BaseStyle->"Graphics"]}, {
           DiskBox[{7.360436669947441, -6.316731016557851}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 12\\nPayoff: 68\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {7.360436669947441, -6.316731016557851},
            BaseStyle->"Graphics"]}, {
           DiskBox[{10.049000034068609, -3.4572614661443013}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 13\\nPayoff: 52\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {10.049000034068609, -3.4572614661443013},
            BaseStyle->"Graphics"]}, {DiskBox[{11., 0.}, 0.09359782207206707],
            InsetBox[
            PanelBox["\<\"Number: 14\\nPayoff: 113\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {11., 0.},
            BaseStyle->"Graphics"]}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None,
    ImageSize->Large], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{0, 1, 4, 2, 5, 3, 6, 7, 8, 9, 10, 11, 12, 13, 
        14}, {{{1, 2}, {1, 3}, {2, 4}, {2, 5}, {4, 6}, {4, 7}, {6, 3}, {6, 
         8}, {3, 5}, {3, 9}, {5, 7}, {5, 10}, {7, 8}, {7, 11}, {8, 9}, {8, 
         12}, {9, 10}, {9, 13}, {10, 11}, {10, 14}, {11, 12}, {11, 15}, {12, 
         1}, {12, 13}, {13, 2}, {13, 14}, {14, 4}, {14, 15}, {15, 1}, {15, 
         6}}, Null}, {EdgeShapeFunction -> {
           GraphElementData["UnfilledArrow", "ArrowSize" -> 0.03]}, ImageSize -> 
         Large, VertexCoordinates -> {{
           11 Cos[Rational[2, 15] Pi], 3.4572614661443013`}, {
           11 Sin[Rational[7, 30] Pi], 6.316731016557851}, {
           Rational[11, 4] (-1 + 5^Rational[1, 2]), 
            8.083980388508804}, {(-11) Sin[Rational[1, 30] Pi], 
            8.453436110630323}, {
            Rational[-11, 2], 7.361215932167728}, {
           Rational[11, 4] (-1 - 5^Rational[1, 2]), 
            4.996174644486022}, {(-11) Cos[Rational[1, 15] Pi], 
            1.767249371950954}, {(-11) 
            Cos[Rational[1, 15] Pi], -1.767249371950954}, {
           Rational[11, 4] (-1 - 5^Rational[1, 2]), -4.996174644486022}, {
            Rational[-11, 2], -7.361215932167728}, {(-11) 
            Sin[Rational[1, 30] Pi], -8.453436110630323}, {
           Rational[11, 4] (-1 + 5^Rational[1, 2]), -8.083980388508804}, {
           11 Sin[Rational[7, 30] Pi], -6.316731016557851}, {
           11 Cos[Rational[2, 15] Pi], -3.4572614661443013`}, {11, 0.}}, 
         VertexLabels -> {
          6 -> Placed[
            "Number: 6\nPayoff: 196", Center, $CellContext`panelLabel], 3 -> 
           Placed["Number: 3\nPayoff: 94", Center, $CellContext`panelLabel], 
           11 -> Placed[
            "Number: 11\nPayoff: 172", Center, $CellContext`panelLabel], 5 -> 
           Placed["Number: 5\nPayoff: 36", Center, $CellContext`panelLabel], 
           8 -> Placed[
            "Number: 8\nPayoff: 68", Center, $CellContext`panelLabel], 7 -> 
           Placed["Number: 7\nPayoff: 112", Center, $CellContext`panelLabel], 
           14 -> Placed[
            "Number: 14\nPayoff: 113", Center, $CellContext`panelLabel], 10 -> 
           Placed["Number: 10\nPayoff: 4", Center, $CellContext`panelLabel], 
           9 -> 
           Placed["Number: 9\nPayoff: 75", Center, $CellContext`panelLabel], 
           4 -> Placed[
            "Number: 4\nPayoff: 73", Center, $CellContext`panelLabel], 12 -> 
           Placed["Number: 12\nPayoff: 68", Center, $CellContext`panelLabel], 
           13 -> Placed[
            "Number: 13\nPayoff: 52", Center, $CellContext`panelLabel], 2 -> 
           Placed["Number: 2\nPayoff: 136", Center, $CellContext`panelLabel], 
           1 -> Placed[
            "Number: 1\nPayoff: 68", Center, $CellContext`panelLabel], 0 -> 
           Placed["Number: 0\nPayoff: 154", 
             Center, $CellContext`panelLabel]}}]]}, 
      TagBox[GraphicsGroupBox[{
         {Hue[0.6, 0.7, 0.5], Opacity[0.7], 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{10.049000034068609`, 3.4572614661443013`}, {
            7.360436669947441, 6.316731016557851}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{10.049000034068609`, 3.4572614661443013`}, {
            3.399186938124422, 8.083980388508804}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{7.360436669947441, 
            6.316731016557851}, {-1.1498130959441881`, 
            8.453436110630323}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{7.360436669947441, 6.316731016557851}, {-5.5, 
            7.361215932167728}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{3.399186938124422, 8.083980388508804}, {-5.5, 
            7.361215932167728}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{3.399186938124422, 
            8.083980388508804}, {-8.899186938124423, -4.996174644486022}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-1.1498130959441881`, 
            8.453436110630323}, {-8.899186938124423, 4.996174644486022}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-1.1498130959441881`, 
            8.453436110630323}, {-10.759623608071863`, 
            1.767249371950954}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-5.5, 7.361215932167728}, {-10.759623608071863`, 
            1.767249371950954}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-5.5, 7.361215932167728}, {-5.5, -7.361215932167728}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-8.899186938124423, 4.996174644486022}, {
            3.399186938124422, 8.083980388508804}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-8.899186938124423, 
            4.996174644486022}, {-10.759623608071863`, -1.767249371950954}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-10.759623608071863`, 
            1.767249371950954}, {-10.759623608071863`, -1.767249371950954}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-10.759623608071863`, 
            1.767249371950954}, {-1.1498130959441881`, -8.453436110630323}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-10.759623608071863`, -1.767249371950954}, \
{-8.899186938124423, -4.996174644486022}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-10.759623608071863`, -1.767249371950954}, {
            3.399186938124422, -8.083980388508804}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-8.899186938124423, -4.996174644486022}, {-5.5, \
-7.361215932167728}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-8.899186938124423, -4.996174644486022}, {
            7.360436669947441, -6.316731016557851}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-5.5, -7.361215932167728}, {-1.1498130959441881`, \
-8.453436110630323}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-5.5, -7.361215932167728}, {
            10.049000034068609`, -3.4572614661443013`}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-1.1498130959441881`, -8.453436110630323}, {
            3.399186938124422, -8.083980388508804}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-1.1498130959441881`, -8.453436110630323}, {11., 0.}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{3.399186938124422, -8.083980388508804}, {
            10.049000034068609`, 3.4572614661443013`}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{3.399186938124422, -8.083980388508804}, {
            7.360436669947441, -6.316731016557851}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{7.360436669947441, -6.316731016557851}, {
            7.360436669947441, 6.316731016557851}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{7.360436669947441, -6.316731016557851}, {
            10.049000034068609`, -3.4572614661443013`}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{
            10.049000034068609`, -3.4572614661443013`}, {-1.1498130959441881`,
             8.453436110630323}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{10.049000034068609`, -3.4572614661443013`}, {11., 
            0.}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{11., 0.}, {10.049000034068609`, 3.4572614661443013`}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{11., 0.}, {-8.899186938124423, 4.996174644486022}}]}}, 
         {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
          0.7]}], {
           DiskBox[{10.049000034068609, 3.4572614661443013}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 0\\nPayoff: 154\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {10.049000034068609, 3.4572614661443013},
            BaseStyle->"Graphics"]}, {
           DiskBox[{7.360436669947441, 6.316731016557851}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 1\\nPayoff: 68\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {7.360436669947441, 6.316731016557851},
            BaseStyle->"Graphics"]}, {
           DiskBox[{3.399186938124422, 8.083980388508804}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 4\\nPayoff: 73\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {3.399186938124422, 8.083980388508804},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-1.1498130959441881, 8.453436110630323}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 2\\nPayoff: 136\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-1.1498130959441881, 8.453436110630323},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-5.5, 7.361215932167728}, 0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 5\\nPayoff: 36\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-5.5, 7.361215932167728},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-8.899186938124423, 4.996174644486022}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 3\\nPayoff: 94\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-8.899186938124423, 4.996174644486022},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-10.759623608071863, 1.767249371950954}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 6\\nPayoff: 196\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-10.759623608071863, 1.767249371950954},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-10.759623608071863, -1.767249371950954}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 7\\nPayoff: 112\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-10.759623608071863, -1.767249371950954},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-8.899186938124423, -4.996174644486022}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 8\\nPayoff: 68\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-8.899186938124423, -4.996174644486022},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-5.5, -7.361215932167728}, 0.09359782207206707], 
           InsetBox[
            PanelBox["\<\"Number: 9\\nPayoff: 75\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-5.5, -7.361215932167728},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-1.1498130959441881, -8.453436110630323}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 10\\nPayoff: 4\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-1.1498130959441881, -8.453436110630323},
            BaseStyle->"Graphics"]}, {
           DiskBox[{3.399186938124422, -8.083980388508804}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 11\\nPayoff: 172\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {3.399186938124422, -8.083980388508804},
            BaseStyle->"Graphics"]}, {
           DiskBox[{7.360436669947441, -6.316731016557851}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 12\\nPayoff: 68\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {7.360436669947441, -6.316731016557851},
            BaseStyle->"Graphics"]}, {
           DiskBox[{10.049000034068609, -3.4572614661443013}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 13\\nPayoff: 52\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {10.049000034068609, -3.4572614661443013},
            BaseStyle->"Graphics"]}, {DiskBox[{11., 0.}, 0.09359782207206707],
            InsetBox[
            PanelBox["\<\"Number: 14\\nPayoff: 113\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {11., 0.},
            BaseStyle->"Graphics"]}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None,
    ImageSize->Large], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{0, 6, 8, 1, 7, 9, 2, 10, 3, 11, 4, 12, 5, 13, 
        14}, {{{1, 2}, {1, 3}, {4, 5}, {4, 6}, {7, 3}, {7, 8}, {9, 6}, {9, 
         10}, {11, 8}, {11, 12}, {13, 10}, {13, 14}, {2, 12}, {2, 15}, {5, 
         1}, {5, 14}, {3, 4}, {3, 15}, {6, 1}, {6, 7}, {8, 4}, {8, 9}, {10, 
         7}, {10, 11}, {12, 9}, {12, 13}, {14, 11}, {14, 2}, {15, 13}, {15, 
         5}}, Null}, {EdgeShapeFunction -> {
           GraphElementData["UnfilledArrow", "ArrowSize" -> 0.03]}, ImageSize -> 
         Large, VertexCoordinates -> {{
           11 Cos[Rational[2, 15] Pi], 3.4572614661443013`}, {
           11 Sin[Rational[7, 30] Pi], 6.316731016557851}, {
           Rational[11, 4] (-1 + 5^Rational[1, 2]), 
            8.083980388508804}, {(-11) Sin[Rational[1, 30] Pi], 
            8.453436110630323}, {
            Rational[-11, 2], 7.361215932167728}, {
           Rational[11, 4] (-1 - 5^Rational[1, 2]), 
            4.996174644486022}, {(-11) Cos[Rational[1, 15] Pi], 
            1.767249371950954}, {(-11) 
            Cos[Rational[1, 15] Pi], -1.767249371950954}, {
           Rational[11, 4] (-1 - 5^Rational[1, 2]), -4.996174644486022}, {
            Rational[-11, 2], -7.361215932167728}, {(-11) 
            Sin[Rational[1, 30] Pi], -8.453436110630323}, {
           Rational[11, 4] (-1 + 5^Rational[1, 2]), -8.083980388508804}, {
           11 Sin[Rational[7, 30] Pi], -6.316731016557851}, {
           11 Cos[Rational[2, 15] Pi], -3.4572614661443013`}, {11, 0.}}, 
         VertexLabels -> {
          6 -> Placed[
            "Number: 6\nPayoff: 196", Center, $CellContext`panelLabel], 3 -> 
           Placed["Number: 3\nPayoff: 94", Center, $CellContext`panelLabel], 
           11 -> 
           Placed["Number: 11\nPayoff: 172", Center, $CellContext`panelLabel],
            5 -> Placed[
            "Number: 5\nPayoff: 36", Center, $CellContext`panelLabel], 8 -> 
           Placed["Number: 8\nPayoff: 68", Center, $CellContext`panelLabel], 
           7 -> Placed[
            "Number: 7\nPayoff: 112", Center, $CellContext`panelLabel], 14 -> 
           Placed["Number: 14\nPayoff: 113", Center, $CellContext`panelLabel],
            10 -> Placed[
            "Number: 10\nPayoff: 4", Center, $CellContext`panelLabel], 9 -> 
           Placed["Number: 9\nPayoff: 75", Center, $CellContext`panelLabel], 
           4 -> Placed[
            "Number: 4\nPayoff: 73", Center, $CellContext`panelLabel], 12 -> 
           Placed["Number: 12\nPayoff: 68", Center, $CellContext`panelLabel], 
           13 -> Placed[
            "Number: 13\nPayoff: 52", Center, $CellContext`panelLabel], 2 -> 
           Placed["Number: 2\nPayoff: 136", Center, $CellContext`panelLabel], 
           1 -> Placed[
            "Number: 1\nPayoff: 68", Center, $CellContext`panelLabel], 0 -> 
           Placed["Number: 0\nPayoff: 154", 
             Center, $CellContext`panelLabel]}}]]}, 
      TagBox[GraphicsGroupBox[{
         {Hue[0.6, 0.7, 0.5], Opacity[0.7], 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{10.049000034068609`, 3.4572614661443013`}, {
            7.360436669947441, 6.316731016557851}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{10.049000034068609`, 3.4572614661443013`}, {
            3.399186938124422, 8.083980388508804}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{7.360436669947441, 6.316731016557851}, {
            3.399186938124422, -8.083980388508804}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{7.360436669947441, 6.316731016557851}, {11., 0.}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{3.399186938124422, 
            8.083980388508804}, {-1.1498130959441881`, 
            8.453436110630323}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{3.399186938124422, 8.083980388508804}, {11., 0.}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-1.1498130959441881`, 8.453436110630323}, {-5.5, 
            7.361215932167728}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-1.1498130959441881`, 
            8.453436110630323}, {-8.899186938124423, 4.996174644486022}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-5.5, 7.361215932167728}, {10.049000034068609`, 
            3.4572614661443013`}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-5.5, 7.361215932167728}, {
            10.049000034068609`, -3.4572614661443013`}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-8.899186938124423, 4.996174644486022}, {
            10.049000034068609`, 3.4572614661443013`}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-8.899186938124423, 
            4.996174644486022}, {-10.759623608071863`, 
            1.767249371950954}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-10.759623608071863`, 1.767249371950954}, {
            3.399186938124422, 8.083980388508804}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-10.759623608071863`, 
            1.767249371950954}, {-10.759623608071863`, -1.767249371950954}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-10.759623608071863`, -1.767249371950954}, \
{-1.1498130959441881`, 8.453436110630323}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-10.759623608071863`, -1.767249371950954}, \
{-8.899186938124423, -4.996174644486022}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-8.899186938124423, -4.996174644486022}, \
{-8.899186938124423, 4.996174644486022}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-8.899186938124423, -4.996174644486022}, {-5.5, \
-7.361215932167728}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-5.5, -7.361215932167728}, {-10.759623608071863`, 
            1.767249371950954}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-5.5, -7.361215932167728}, {-1.1498130959441881`, \
-8.453436110630323}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-1.1498130959441881`, -8.453436110630323}, \
{-10.759623608071863`, -1.767249371950954}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-1.1498130959441881`, -8.453436110630323}, {
            3.399186938124422, -8.083980388508804}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{
            3.399186938124422, -8.083980388508804}, {-8.899186938124423, \
-4.996174644486022}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{3.399186938124422, -8.083980388508804}, {
            7.360436669947441, -6.316731016557851}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{
            7.360436669947441, -6.316731016557851}, {-5.5, \
-7.361215932167728}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{7.360436669947441, -6.316731016557851}, {
            10.049000034068609`, -3.4572614661443013`}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{10.049000034068609`, -3.4572614661443013`}, {
            7.360436669947441, 6.316731016557851}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{
            10.049000034068609`, -3.4572614661443013`}, \
{-1.1498130959441881`, -8.453436110630323}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{11., 0.}, {-5.5, 7.361215932167728}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{11., 0.}, {7.360436669947441, -6.316731016557851}}]}}, 
         {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
          0.7]}], {
           DiskBox[{10.049000034068609, 3.4572614661443013}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 0\\nPayoff: 154\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {10.049000034068609, 3.4572614661443013},
            BaseStyle->"Graphics"]}, {
           DiskBox[{7.360436669947441, 6.316731016557851}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 6\\nPayoff: 196\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {7.360436669947441, 6.316731016557851},
            BaseStyle->"Graphics"]}, {
           DiskBox[{3.399186938124422, 8.083980388508804}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 8\\nPayoff: 68\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {3.399186938124422, 8.083980388508804},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-1.1498130959441881, 8.453436110630323}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 1\\nPayoff: 68\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-1.1498130959441881, 8.453436110630323},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-5.5, 7.361215932167728}, 0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 7\\nPayoff: 112\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-5.5, 7.361215932167728},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-8.899186938124423, 4.996174644486022}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 9\\nPayoff: 75\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-8.899186938124423, 4.996174644486022},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-10.759623608071863, 1.767249371950954}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 2\\nPayoff: 136\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-10.759623608071863, 1.767249371950954},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-10.759623608071863, -1.767249371950954}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 10\\nPayoff: 4\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-10.759623608071863, -1.767249371950954},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-8.899186938124423, -4.996174644486022}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 3\\nPayoff: 94\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-8.899186938124423, -4.996174644486022},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-5.5, -7.361215932167728}, 0.09359782207206707], 
           InsetBox[
            PanelBox["\<\"Number: 11\\nPayoff: 172\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-5.5, -7.361215932167728},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-1.1498130959441881, -8.453436110630323}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 4\\nPayoff: 73\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-1.1498130959441881, -8.453436110630323},
            BaseStyle->"Graphics"]}, {
           DiskBox[{3.399186938124422, -8.083980388508804}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 12\\nPayoff: 68\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {3.399186938124422, -8.083980388508804},
            BaseStyle->"Graphics"]}, {
           DiskBox[{7.360436669947441, -6.316731016557851}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 5\\nPayoff: 36\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {7.360436669947441, -6.316731016557851},
            BaseStyle->"Graphics"]}, {
           DiskBox[{10.049000034068609, -3.4572614661443013}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 13\\nPayoff: 52\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {10.049000034068609, -3.4572614661443013},
            BaseStyle->"Graphics"]}, {DiskBox[{11., 0.}, 0.09359782207206707],
            InsetBox[
            PanelBox["\<\"Number: 14\\nPayoff: 113\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {11., 0.},
            BaseStyle->"Graphics"]}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None,
    ImageSize->Large], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{0, 5, 9, 1, 6, 10, 2, 7, 11, 3, 8, 12, 4, 13, 
        14}, {{{1, 2}, {1, 3}, {4, 5}, {4, 6}, {7, 8}, {7, 9}, {10, 11}, {10, 
         12}, {13, 3}, {13, 14}, {2, 6}, {2, 15}, {5, 1}, {5, 9}, {8, 4}, {8, 
         12}, {11, 7}, {11, 14}, {3, 10}, {3, 15}, {6, 1}, {6, 13}, {9, 4}, {
         9, 2}, {12, 7}, {12, 5}, {14, 10}, {14, 8}, {15, 13}, {15, 11}}, 
         Null}, {EdgeShapeFunction -> {
           GraphElementData["UnfilledArrow", "ArrowSize" -> 0.03]}, ImageSize -> 
         Large, VertexCoordinates -> {{
           11 Cos[Rational[2, 15] Pi], 3.4572614661443013`}, {
           11 Sin[Rational[7, 30] Pi], 6.316731016557851}, {
           Rational[11, 4] (-1 + 5^Rational[1, 2]), 
            8.083980388508804}, {(-11) Sin[Rational[1, 30] Pi], 
            8.453436110630323}, {
            Rational[-11, 2], 7.361215932167728}, {
           Rational[11, 4] (-1 - 5^Rational[1, 2]), 
            4.996174644486022}, {(-11) Cos[Rational[1, 15] Pi], 
            1.767249371950954}, {(-11) 
            Cos[Rational[1, 15] Pi], -1.767249371950954}, {
           Rational[11, 4] (-1 - 5^Rational[1, 2]), -4.996174644486022}, {
            Rational[-11, 2], -7.361215932167728}, {(-11) 
            Sin[Rational[1, 30] Pi], -8.453436110630323}, {
           Rational[11, 4] (-1 + 5^Rational[1, 2]), -8.083980388508804}, {
           11 Sin[Rational[7, 30] Pi], -6.316731016557851}, {
           11 Cos[Rational[2, 15] Pi], -3.4572614661443013`}, {11, 0.}}, 
         VertexLabels -> {
          6 -> Placed[
            "Number: 6\nPayoff: 196", Center, $CellContext`panelLabel], 3 -> 
           Placed["Number: 3\nPayoff: 94", Center, $CellContext`panelLabel], 
           11 -> Placed[
            "Number: 11\nPayoff: 172", Center, $CellContext`panelLabel], 5 -> 
           Placed["Number: 5\nPayoff: 36", Center, $CellContext`panelLabel], 
           8 -> Placed[
            "Number: 8\nPayoff: 68", Center, $CellContext`panelLabel], 7 -> 
           Placed["Number: 7\nPayoff: 112", Center, $CellContext`panelLabel], 
           14 -> Placed[
            "Number: 14\nPayoff: 113", Center, $CellContext`panelLabel], 10 -> 
           Placed["Number: 10\nPayoff: 4", Center, $CellContext`panelLabel], 
           9 -> Placed[
            "Number: 9\nPayoff: 75", Center, $CellContext`panelLabel], 4 -> 
           Placed["Number: 4\nPayoff: 73", Center, $CellContext`panelLabel], 
           12 -> Placed[
            "Number: 12\nPayoff: 68", Center, $CellContext`panelLabel], 13 -> 
           Placed["Number: 13\nPayoff: 52", Center, $CellContext`panelLabel], 
           2 -> Placed[
            "Number: 2\nPayoff: 136", Center, $CellContext`panelLabel], 1 -> 
           Placed["Number: 1\nPayoff: 68", Center, $CellContext`panelLabel], 
           0 -> Placed[
            "Number: 0\nPayoff: 154", Center, $CellContext`panelLabel]}}]]}, 
      TagBox[GraphicsGroupBox[{
         {Hue[0.6, 0.7, 0.5], Opacity[0.7], 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{10.049000034068609`, 3.4572614661443013`}, {
            7.360436669947441, 6.316731016557851}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{10.049000034068609`, 3.4572614661443013`}, {
            3.399186938124422, 8.083980388508804}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{7.360436669947441, 
            6.316731016557851}, {-8.899186938124423, 4.996174644486022}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{7.360436669947441, 6.316731016557851}, {11., 0.}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{3.399186938124422, 
            8.083980388508804}, {-5.5, -7.361215932167728}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{3.399186938124422, 8.083980388508804}, {11., 0.}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-1.1498130959441881`, 8.453436110630323}, {-5.5, 
            7.361215932167728}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-1.1498130959441881`, 
            8.453436110630323}, {-8.899186938124423, 4.996174644486022}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-5.5, 7.361215932167728}, {10.049000034068609`, 
            3.4572614661443013`}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-5.5, 
            7.361215932167728}, {-8.899186938124423, -4.996174644486022}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-8.899186938124423, 4.996174644486022}, {
            10.049000034068609`, 3.4572614661443013`}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-8.899186938124423, 4.996174644486022}, {
            7.360436669947441, -6.316731016557851}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-10.759623608071863`, 
            1.767249371950954}, {-10.759623608071863`, -1.767249371950954}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-10.759623608071863`, 
            1.767249371950954}, {-8.899186938124423, -4.996174644486022}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-10.759623608071863`, -1.767249371950954}, \
{-1.1498130959441881`, 8.453436110630323}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-10.759623608071863`, -1.767249371950954}, {
            3.399186938124422, -8.083980388508804}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-8.899186938124423, -4.996174644486022}, {
            7.360436669947441, 6.316731016557851}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-8.899186938124423, -4.996174644486022}, \
{-1.1498130959441881`, 8.453436110630323}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-5.5, -7.361215932167728}, {-1.1498130959441881`, \
-8.453436110630323}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-5.5, -7.361215932167728}, {
            3.399186938124422, -8.083980388508804}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-1.1498130959441881`, -8.453436110630323}, \
{-10.759623608071863`, 1.767249371950954}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-1.1498130959441881`, -8.453436110630323}, {
            10.049000034068609`, -3.4572614661443013`}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{3.399186938124422, -8.083980388508804}, {-5.5, 
            7.361215932167728}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{
            3.399186938124422, -8.083980388508804}, {-10.759623608071863`, 
            1.767249371950954}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{7.360436669947441, -6.316731016557851}, {
            3.399186938124422, 8.083980388508804}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{7.360436669947441, -6.316731016557851}, {
            10.049000034068609`, -3.4572614661443013`}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{
            10.049000034068609`, -3.4572614661443013`}, \
{-10.759623608071863`, -1.767249371950954}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{
            10.049000034068609`, -3.4572614661443013`}, {-5.5, \
-7.361215932167728}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{11., 0.}, {-1.1498130959441881`, -8.453436110630323}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 
                 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, {-1., \
-0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{11., 0.}, {7.360436669947441, -6.316731016557851}}]}}, 
         {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
          0.7]}], {
           DiskBox[{10.049000034068609, 3.4572614661443013}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 0\\nPayoff: 154\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {10.049000034068609, 3.4572614661443013},
            BaseStyle->"Graphics"]}, {
           DiskBox[{7.360436669947441, 6.316731016557851}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 5\\nPayoff: 36\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {7.360436669947441, 6.316731016557851},
            BaseStyle->"Graphics"]}, {
           DiskBox[{3.399186938124422, 8.083980388508804}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 9\\nPayoff: 75\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {3.399186938124422, 8.083980388508804},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-1.1498130959441881, 8.453436110630323}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 1\\nPayoff: 68\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-1.1498130959441881, 8.453436110630323},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-5.5, 7.361215932167728}, 0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 6\\nPayoff: 196\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-5.5, 7.361215932167728},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-8.899186938124423, 4.996174644486022}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 10\\nPayoff: 4\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-8.899186938124423, 4.996174644486022},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-10.759623608071863, 1.767249371950954}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 2\\nPayoff: 136\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-10.759623608071863, 1.767249371950954},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-10.759623608071863, -1.767249371950954}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 7\\nPayoff: 112\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-10.759623608071863, -1.767249371950954},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-8.899186938124423, -4.996174644486022}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 11\\nPayoff: 172\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-8.899186938124423, -4.996174644486022},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-5.5, -7.361215932167728}, 0.09359782207206707], 
           InsetBox[
            PanelBox["\<\"Number: 3\\nPayoff: 94\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-5.5, -7.361215932167728},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-1.1498130959441881, -8.453436110630323}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 8\\nPayoff: 68\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-1.1498130959441881, -8.453436110630323},
            BaseStyle->"Graphics"]}, {
           DiskBox[{3.399186938124422, -8.083980388508804}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 12\\nPayoff: 68\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {3.399186938124422, -8.083980388508804},
            BaseStyle->"Graphics"]}, {
           DiskBox[{7.360436669947441, -6.316731016557851}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 4\\nPayoff: 73\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {7.360436669947441, -6.316731016557851},
            BaseStyle->"Graphics"]}, {
           DiskBox[{10.049000034068609, -3.4572614661443013}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 13\\nPayoff: 52\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {10.049000034068609, -3.4572614661443013},
            BaseStyle->"Graphics"]}, {DiskBox[{11., 0.}, 0.09359782207206707],
            InsetBox[
            PanelBox["\<\"Number: 14\\nPayoff: 113\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {11., 0.},
            BaseStyle->"Graphics"]}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None,
    ImageSize->Large], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{0, 5, 8, 1, 6, 9, 2, 7, 10, 3, 11, 4, 12, 13, 
        14}, {{{1, 2}, {1, 3}, {4, 5}, {4, 6}, {7, 8}, {7, 9}, {10, 3}, {10, 
         11}, {12, 6}, {12, 13}, {2, 9}, {2, 14}, {5, 11}, {5, 15}, {8, 1}, {
         8, 13}, {3, 4}, {3, 14}, {6, 7}, {6, 15}, {9, 1}, {9, 10}, {11, 4}, {
         11, 12}, {13, 7}, {13, 2}, {14, 10}, {14, 5}, {15, 12}, {15, 8}}, 
         Null}, {EdgeShapeFunction -> {
           GraphElementData["UnfilledArrow", "ArrowSize" -> 0.03]}, ImageSize -> 
         Large, VertexCoordinates -> {{
           11 Cos[Rational[2, 15] Pi], 3.4572614661443013`}, {
           11 Sin[Rational[7, 30] Pi], 6.316731016557851}, {
           Rational[11, 4] (-1 + 5^Rational[1, 2]), 
            8.083980388508804}, {(-11) Sin[Rational[1, 30] Pi], 
            8.453436110630323}, {
            Rational[-11, 2], 7.361215932167728}, {
           Rational[11, 4] (-1 - 5^Rational[1, 2]), 
            4.996174644486022}, {(-11) Cos[Rational[1, 15] Pi], 
            1.767249371950954}, {(-11) 
            Cos[Rational[1, 15] Pi], -1.767249371950954}, {
           Rational[11, 4] (-1 - 5^Rational[1, 2]), -4.996174644486022}, {
            Rational[-11, 2], -7.361215932167728}, {(-11) 
            Sin[Rational[1, 30] Pi], -8.453436110630323}, {
           Rational[11, 4] (-1 + 5^Rational[1, 2]), -8.083980388508804}, {
           11 Sin[Rational[7, 30] Pi], -6.316731016557851}, {
           11 Cos[Rational[2, 15] Pi], -3.4572614661443013`}, {11, 0.}}, 
         VertexLabels -> {
          6 -> Placed[
            "Number: 6\nPayoff: 196", Center, $CellContext`panelLabel], 3 -> 
           Placed["Number: 3\nPayoff: 94", Center, $CellContext`panelLabel], 
           11 -> Placed[
            "Number: 11\nPayoff: 172", Center, $CellContext`panelLabel], 5 -> 
           Placed["Number: 5\nPayoff: 36", Center, $CellContext`panelLabel], 
           8 -> Placed[
            "Number: 8\nPayoff: 68", Center, $CellContext`panelLabel], 7 -> 
           Placed["Number: 7\nPayoff: 112", Center, $CellContext`panelLabel], 
           14 -> Placed[
            "Number: 14\nPayoff: 113", Center, $CellContext`panelLabel], 10 -> 
           Placed["Number: 10\nPayoff: 4", Center, $CellContext`panelLabel], 
           9 -> Placed[
            "Number: 9\nPayoff: 75", Center, $CellContext`panelLabel], 4 -> 
           Placed["Number: 4\nPayoff: 73", Center, $CellContext`panelLabel], 
           12 -> Placed[
            "Number: 12\nPayoff: 68", Center, $CellContext`panelLabel], 13 -> 
           Placed["Number: 13\nPayoff: 52", Center, $CellContext`panelLabel], 
           2 -> Placed[
            "Number: 2\nPayoff: 136", Center, $CellContext`panelLabel], 1 -> 
           Placed["Number: 1\nPayoff: 68", Center, $CellContext`panelLabel], 
           0 -> Placed[
            "Number: 0\nPayoff: 154", Center, $CellContext`panelLabel]}}]]}, 
      TagBox[GraphicsGroupBox[{
         {Hue[0.6, 0.7, 0.5], Opacity[0.7], 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{10.049000034068609`, 3.4572614661443013`}, {
            7.360436669947441, 6.316731016557851}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{10.049000034068609`, 3.4572614661443013`}, {
            3.399186938124422, 8.083980388508804}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{7.360436669947441, 
            6.316731016557851}, {-8.899186938124423, -4.996174644486022}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{7.360436669947441, 6.316731016557851}, {
            10.049000034068609`, -3.4572614661443013`}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{3.399186938124422, 
            8.083980388508804}, {-1.1498130959441881`, 
            8.453436110630323}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{3.399186938124422, 8.083980388508804}, {
            10.049000034068609`, -3.4572614661443013`}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-1.1498130959441881`, 8.453436110630323}, {-5.5, 
            7.361215932167728}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-1.1498130959441881`, 
            8.453436110630323}, {-8.899186938124423, 4.996174644486022}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-5.5, 
            7.361215932167728}, {-1.1498130959441881`, -8.453436110630323}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-5.5, 7.361215932167728}, {11., 0.}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-8.899186938124423, 
            4.996174644486022}, {-10.759623608071863`, 
            1.767249371950954}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-8.899186938124423, 4.996174644486022}, {11., 0.}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 
                 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, {-1., \
-0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-10.759623608071863`, 
            1.767249371950954}, {-10.759623608071863`, -1.767249371950954}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-10.759623608071863`, 
            1.767249371950954}, {-8.899186938124423, -4.996174644486022}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-10.759623608071863`, -1.767249371950954}, {
            10.049000034068609`, 3.4572614661443013`}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-10.759623608071863`, -1.767249371950954}, {
            7.360436669947441, -6.316731016557851}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 
                 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, {-1., \
-0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-8.899186938124423, -4.996174644486022}, {
            10.049000034068609`, 3.4572614661443013`}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-8.899186938124423, -4.996174644486022}, {-5.5, \
-7.361215932167728}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-5.5, -7.361215932167728}, {3.399186938124422, 
            8.083980388508804}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-5.5, -7.361215932167728}, {-1.1498130959441881`, \
-8.453436110630323}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-1.1498130959441881`, -8.453436110630323}, \
{-1.1498130959441881`, 8.453436110630323}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-1.1498130959441881`, -8.453436110630323}, {
            3.399186938124422, -8.083980388508804}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{
            3.399186938124422, -8.083980388508804}, {-8.899186938124423, 
            4.996174644486022}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{3.399186938124422, -8.083980388508804}, {
            7.360436669947441, -6.316731016557851}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{7.360436669947441, -6.316731016557851}, {
            7.360436669947441, 6.316731016557851}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{
            7.360436669947441, -6.316731016557851}, {-10.759623608071863`, 
            1.767249371950954}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{10.049000034068609`, -3.4572614661443013`}, {-5.5, 
            7.361215932167728}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{
            10.049000034068609`, -3.4572614661443013`}, {-5.5, \
-7.361215932167728}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{11., 0.}, {-10.759623608071863`, -1.767249371950954}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{11., 0.}, {3.399186938124422, -8.083980388508804}}]}}, 
         {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
          0.7]}], {
           DiskBox[{10.049000034068609, 3.4572614661443013}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 0\\nPayoff: 154\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {10.049000034068609, 3.4572614661443013},
            BaseStyle->"Graphics"]}, {
           DiskBox[{7.360436669947441, 6.316731016557851}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 5\\nPayoff: 36\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {7.360436669947441, 6.316731016557851},
            BaseStyle->"Graphics"]}, {
           DiskBox[{3.399186938124422, 8.083980388508804}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 8\\nPayoff: 68\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {3.399186938124422, 8.083980388508804},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-1.1498130959441881, 8.453436110630323}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 1\\nPayoff: 68\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-1.1498130959441881, 8.453436110630323},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-5.5, 7.361215932167728}, 0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 6\\nPayoff: 196\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-5.5, 7.361215932167728},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-8.899186938124423, 4.996174644486022}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 9\\nPayoff: 75\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-8.899186938124423, 4.996174644486022},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-10.759623608071863, 1.767249371950954}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 2\\nPayoff: 136\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-10.759623608071863, 1.767249371950954},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-10.759623608071863, -1.767249371950954}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 7\\nPayoff: 112\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-10.759623608071863, -1.767249371950954},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-8.899186938124423, -4.996174644486022}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 10\\nPayoff: 4\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-8.899186938124423, -4.996174644486022},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-5.5, -7.361215932167728}, 0.09359782207206707], 
           InsetBox[
            PanelBox["\<\"Number: 3\\nPayoff: 94\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-5.5, -7.361215932167728},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-1.1498130959441881, -8.453436110630323}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 11\\nPayoff: 172\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-1.1498130959441881, -8.453436110630323},
            BaseStyle->"Graphics"]}, {
           DiskBox[{3.399186938124422, -8.083980388508804}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 4\\nPayoff: 73\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {3.399186938124422, -8.083980388508804},
            BaseStyle->"Graphics"]}, {
           DiskBox[{7.360436669947441, -6.316731016557851}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 12\\nPayoff: 68\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {7.360436669947441, -6.316731016557851},
            BaseStyle->"Graphics"]}, {
           DiskBox[{10.049000034068609, -3.4572614661443013}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 13\\nPayoff: 52\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {10.049000034068609, -3.4572614661443013},
            BaseStyle->"Graphics"]}, {DiskBox[{11., 0.}, 0.09359782207206707],
            InsetBox[
            PanelBox["\<\"Number: 14\\nPayoff: 113\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {11., 0.},
            BaseStyle->"Graphics"]}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None,
    ImageSize->Large], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{0, 1, 6, 2, 7, 3, 8, 4, 9, 5, 10, 11, 12, 13, 
        14}, {{{1, 2}, {1, 3}, {2, 4}, {2, 5}, {4, 6}, {4, 7}, {6, 8}, {6, 
         9}, {8, 10}, {8, 11}, {10, 3}, {10, 12}, {3, 5}, {3, 13}, {5, 7}, {5,
          14}, {7, 9}, {7, 15}, {9, 1}, {9, 11}, {11, 2}, {11, 12}, {12, 4}, {
         12, 13}, {13, 6}, {13, 14}, {14, 8}, {14, 15}, {15, 1}, {15, 10}}, 
         Null}, {EdgeShapeFunction -> {
           GraphElementData["UnfilledArrow", "ArrowSize" -> 0.03]}, ImageSize -> 
         Large, VertexCoordinates -> {{
           11 Cos[Rational[2, 15] Pi], 3.4572614661443013`}, {
           11 Sin[Rational[7, 30] Pi], 6.316731016557851}, {
           Rational[11, 4] (-1 + 5^Rational[1, 2]), 
            8.083980388508804}, {(-11) Sin[Rational[1, 30] Pi], 
            8.453436110630323}, {
            Rational[-11, 2], 7.361215932167728}, {
           Rational[11, 4] (-1 - 5^Rational[1, 2]), 
            4.996174644486022}, {(-11) Cos[Rational[1, 15] Pi], 
            1.767249371950954}, {(-11) 
            Cos[Rational[1, 15] Pi], -1.767249371950954}, {
           Rational[11, 4] (-1 - 5^Rational[1, 2]), -4.996174644486022}, {
            Rational[-11, 2], -7.361215932167728}, {(-11) 
            Sin[Rational[1, 30] Pi], -8.453436110630323}, {
           Rational[11, 4] (-1 + 5^Rational[1, 2]), -8.083980388508804}, {
           11 Sin[Rational[7, 30] Pi], -6.316731016557851}, {
           11 Cos[Rational[2, 15] Pi], -3.4572614661443013`}, {11, 0.}}, 
         VertexLabels -> {
          6 -> Placed[
            "Number: 6\nPayoff: 196", Center, $CellContext`panelLabel], 3 -> 
           Placed["Number: 3\nPayoff: 94", Center, $CellContext`panelLabel], 
           11 -> Placed[
            "Number: 11\nPayoff: 172", Center, $CellContext`panelLabel], 5 -> 
           Placed["Number: 5\nPayoff: 36", Center, $CellContext`panelLabel], 
           8 -> Placed[
            "Number: 8\nPayoff: 68", Center, $CellContext`panelLabel], 7 -> 
           Placed["Number: 7\nPayoff: 112", Center, $CellContext`panelLabel], 
           14 -> Placed[
            "Number: 14\nPayoff: 113", Center, $CellContext`panelLabel], 10 -> 
           Placed["Number: 10\nPayoff: 4", Center, $CellContext`panelLabel], 
           9 -> Placed[
            "Number: 9\nPayoff: 75", Center, $CellContext`panelLabel], 4 -> 
           Placed["Number: 4\nPayoff: 73", Center, $CellContext`panelLabel], 
           12 -> 
           Placed["Number: 12\nPayoff: 68", Center, $CellContext`panelLabel], 
           13 -> Placed[
            "Number: 13\nPayoff: 52", Center, $CellContext`panelLabel], 2 -> 
           Placed["Number: 2\nPayoff: 136", Center, $CellContext`panelLabel], 
           1 -> Placed[
            "Number: 1\nPayoff: 68", Center, $CellContext`panelLabel], 0 -> 
           Placed["Number: 0\nPayoff: 154", 
             Center, $CellContext`panelLabel]}}]]}, 
      TagBox[GraphicsGroupBox[{
         {Hue[0.6, 0.7, 0.5], Opacity[0.7], 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{10.049000034068609`, 3.4572614661443013`}, {
            7.360436669947441, 6.316731016557851}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{10.049000034068609`, 3.4572614661443013`}, {
            3.399186938124422, 8.083980388508804}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{7.360436669947441, 
            6.316731016557851}, {-1.1498130959441881`, 
            8.453436110630323}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{7.360436669947441, 6.316731016557851}, {-5.5, 
            7.361215932167728}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{3.399186938124422, 8.083980388508804}, {-5.5, 
            7.361215932167728}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{3.399186938124422, 8.083980388508804}, {
            7.360436669947441, -6.316731016557851}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-1.1498130959441881`, 
            8.453436110630323}, {-8.899186938124423, 4.996174644486022}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-1.1498130959441881`, 
            8.453436110630323}, {-10.759623608071863`, 
            1.767249371950954}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-5.5, 7.361215932167728}, {-10.759623608071863`, 
            1.767249371950954}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-5.5, 7.361215932167728}, {
            10.049000034068609`, -3.4572614661443013`}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-8.899186938124423, 
            4.996174644486022}, {-10.759623608071863`, -1.767249371950954}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 
                 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, {-1., \
-0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-8.899186938124423, 
            4.996174644486022}, {-8.899186938124423, -4.996174644486022}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-10.759623608071863`, 
            1.767249371950954}, {-8.899186938124423, -4.996174644486022}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-10.759623608071863`, 1.767249371950954}, {11., 
            0.}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-10.759623608071863`, -1.767249371950954}, {-5.5, \
-7.361215932167728}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-10.759623608071863`, -1.767249371950954}, \
{-1.1498130959441881`, -8.453436110630323}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-8.899186938124423, -4.996174644486022}, {
            10.049000034068609`, 3.4572614661443013`}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-8.899186938124423, -4.996174644486022}, \
{-1.1498130959441881`, -8.453436110630323}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-5.5, -7.361215932167728}, {3.399186938124422, 
            8.083980388508804}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-5.5, -7.361215932167728}, {
            3.399186938124422, -8.083980388508804}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-1.1498130959441881`, -8.453436110630323}, {
            7.360436669947441, 6.316731016557851}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-1.1498130959441881`, -8.453436110630323}, {
            3.399186938124422, -8.083980388508804}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{
            3.399186938124422, -8.083980388508804}, {-1.1498130959441881`, 
            8.453436110630323}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{3.399186938124422, -8.083980388508804}, {
            7.360436669947441, -6.316731016557851}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{
            7.360436669947441, -6.316731016557851}, {-8.899186938124423, 
            4.996174644486022}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{7.360436669947441, -6.316731016557851}, {
            10.049000034068609`, -3.4572614661443013`}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{
            10.049000034068609`, -3.4572614661443013`}, \
{-10.759623608071863`, -1.767249371950954}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{10.049000034068609`, -3.4572614661443013`}, {11., 
            0.}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{11., 0.}, {10.049000034068609`, 3.4572614661443013`}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{11., 0.}, {-5.5, -7.361215932167728}}]}}, 
         {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
          0.7]}], {
           DiskBox[{10.049000034068609, 3.4572614661443013}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 0\\nPayoff: 154\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {10.049000034068609, 3.4572614661443013},
            BaseStyle->"Graphics"]}, {
           DiskBox[{7.360436669947441, 6.316731016557851}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 1\\nPayoff: 68\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {7.360436669947441, 6.316731016557851},
            BaseStyle->"Graphics"]}, {
           DiskBox[{3.399186938124422, 8.083980388508804}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 6\\nPayoff: 196\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {3.399186938124422, 8.083980388508804},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-1.1498130959441881, 8.453436110630323}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 2\\nPayoff: 136\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-1.1498130959441881, 8.453436110630323},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-5.5, 7.361215932167728}, 0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 7\\nPayoff: 112\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-5.5, 7.361215932167728},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-8.899186938124423, 4.996174644486022}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 3\\nPayoff: 94\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-8.899186938124423, 4.996174644486022},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-10.759623608071863, 1.767249371950954}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 8\\nPayoff: 68\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-10.759623608071863, 1.767249371950954},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-10.759623608071863, -1.767249371950954}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 4\\nPayoff: 73\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-10.759623608071863, -1.767249371950954},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-8.899186938124423, -4.996174644486022}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 9\\nPayoff: 75\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-8.899186938124423, -4.996174644486022},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-5.5, -7.361215932167728}, 0.09359782207206707], 
           InsetBox[
            PanelBox["\<\"Number: 5\\nPayoff: 36\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-5.5, -7.361215932167728},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-1.1498130959441881, -8.453436110630323}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 10\\nPayoff: 4\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-1.1498130959441881, -8.453436110630323},
            BaseStyle->"Graphics"]}, {
           DiskBox[{3.399186938124422, -8.083980388508804}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 11\\nPayoff: 172\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {3.399186938124422, -8.083980388508804},
            BaseStyle->"Graphics"]}, {
           DiskBox[{7.360436669947441, -6.316731016557851}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 12\\nPayoff: 68\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {7.360436669947441, -6.316731016557851},
            BaseStyle->"Graphics"]}, {
           DiskBox[{10.049000034068609, -3.4572614661443013}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 13\\nPayoff: 52\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {10.049000034068609, -3.4572614661443013},
            BaseStyle->"Graphics"]}, {DiskBox[{11., 0.}, 0.09359782207206707],
            InsetBox[
            PanelBox["\<\"Number: 14\\nPayoff: 113\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {11., 0.},
            BaseStyle->"Graphics"]}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None,
    ImageSize->Large], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{0, 1, 9, 2, 10, 3, 11, 4, 12, 5, 13, 6, 14, 7, 
        8}, {{{1, 2}, {1, 3}, {2, 4}, {2, 5}, {4, 6}, {4, 7}, {6, 8}, {6, 
         9}, {8, 10}, {8, 11}, {10, 12}, {10, 13}, {12, 1}, {12, 14}, {14, 
         2}, {14, 15}, {15, 4}, {15, 3}, {3, 6}, {3, 5}, {5, 8}, {5, 7}, {7, 
         10}, {7, 9}, {9, 12}, {9, 11}, {11, 14}, {11, 13}, {13, 1}, {13, 
         15}}, Null}, {EdgeShapeFunction -> {
           GraphElementData["UnfilledArrow", "ArrowSize" -> 0.03]}, ImageSize -> 
         Large, VertexCoordinates -> {{
           11 Cos[Rational[2, 15] Pi], 3.4572614661443013`}, {
           11 Sin[Rational[7, 30] Pi], 6.316731016557851}, {
           Rational[11, 4] (-1 + 5^Rational[1, 2]), 
            8.083980388508804}, {(-11) Sin[Rational[1, 30] Pi], 
            8.453436110630323}, {
            Rational[-11, 2], 7.361215932167728}, {
           Rational[11, 4] (-1 - 5^Rational[1, 2]), 
            4.996174644486022}, {(-11) Cos[Rational[1, 15] Pi], 
            1.767249371950954}, {(-11) 
            Cos[Rational[1, 15] Pi], -1.767249371950954}, {
           Rational[11, 4] (-1 - 5^Rational[1, 2]), -4.996174644486022}, {
            Rational[-11, 2], -7.361215932167728}, {(-11) 
            Sin[Rational[1, 30] Pi], -8.453436110630323}, {
           Rational[11, 4] (-1 + 5^Rational[1, 2]), -8.083980388508804}, {
           11 Sin[Rational[7, 30] Pi], -6.316731016557851}, {
           11 Cos[Rational[2, 15] Pi], -3.4572614661443013`}, {11, 0.}}, 
         VertexLabels -> {
          6 -> Placed[
            "Number: 6\nPayoff: 196", Center, $CellContext`panelLabel], 3 -> 
           Placed["Number: 3\nPayoff: 94", Center, $CellContext`panelLabel], 
           11 -> Placed[
            "Number: 11\nPayoff: 172", Center, $CellContext`panelLabel], 5 -> 
           Placed["Number: 5\nPayoff: 36", Center, $CellContext`panelLabel], 
           8 -> Placed[
            "Number: 8\nPayoff: 68", Center, $CellContext`panelLabel], 7 -> 
           Placed["Number: 7\nPayoff: 112", Center, $CellContext`panelLabel], 
           14 -> Placed[
            "Number: 14\nPayoff: 113", Center, $CellContext`panelLabel], 10 -> 
           Placed["Number: 10\nPayoff: 4", Center, $CellContext`panelLabel], 
           9 -> Placed[
            "Number: 9\nPayoff: 75", Center, $CellContext`panelLabel], 4 -> 
           Placed["Number: 4\nPayoff: 73", Center, $CellContext`panelLabel], 
           12 -> Placed[
            "Number: 12\nPayoff: 68", Center, $CellContext`panelLabel], 13 -> 
           Placed["Number: 13\nPayoff: 52", Center, $CellContext`panelLabel], 
           2 -> Placed[
            "Number: 2\nPayoff: 136", Center, $CellContext`panelLabel], 1 -> 
           Placed["Number: 1\nPayoff: 68", Center, $CellContext`panelLabel], 
           0 -> Placed[
            "Number: 0\nPayoff: 154", Center, $CellContext`panelLabel]}}]]}, 
      TagBox[GraphicsGroupBox[{
         {Hue[0.6, 0.7, 0.5], Opacity[0.7], 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{10.049000034068609`, 3.4572614661443013`}, {
            7.360436669947441, 6.316731016557851}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{10.049000034068609`, 3.4572614661443013`}, {
            3.399186938124422, 8.083980388508804}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 
                 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, {-1., \
-0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{7.360436669947441, 
            6.316731016557851}, {-1.1498130959441881`, 
            8.453436110630323}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{7.360436669947441, 6.316731016557851}, {-5.5, 
            7.361215932167728}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{3.399186938124422, 8.083980388508804}, {-5.5, 
            7.361215932167728}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{3.399186938124422, 
            8.083980388508804}, {-8.899186938124423, 4.996174644486022}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-1.1498130959441881`, 
            8.453436110630323}, {-8.899186938124423, 4.996174644486022}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-1.1498130959441881`, 
            8.453436110630323}, {-10.759623608071863`, 
            1.767249371950954}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-5.5, 7.361215932167728}, {-10.759623608071863`, 
            1.767249371950954}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-5.5, 
            7.361215932167728}, {-10.759623608071863`, -1.767249371950954}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-8.899186938124423, 
            4.996174644486022}, {-10.759623608071863`, -1.767249371950954}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-8.899186938124423, 
            4.996174644486022}, {-8.899186938124423, -4.996174644486022}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-10.759623608071863`, 
            1.767249371950954}, {-8.899186938124423, -4.996174644486022}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-10.759623608071863`, 
            1.767249371950954}, {-5.5, -7.361215932167728}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-10.759623608071863`, -1.767249371950954}, {-5.5, \
-7.361215932167728}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-10.759623608071863`, -1.767249371950954}, \
{-1.1498130959441881`, -8.453436110630323}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-8.899186938124423, -4.996174644486022}, \
{-1.1498130959441881`, -8.453436110630323}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-8.899186938124423, -4.996174644486022}, {
            3.399186938124422, -8.083980388508804}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-5.5, -7.361215932167728}, {
            3.399186938124422, -8.083980388508804}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-5.5, -7.361215932167728}, {
            7.360436669947441, -6.316731016557851}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-1.1498130959441881`, -8.453436110630323}, {
            7.360436669947441, -6.316731016557851}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-1.1498130959441881`, -8.453436110630323}, {
            10.049000034068609`, -3.4572614661443013`}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{3.399186938124422, -8.083980388508804}, {
            10.049000034068609`, 3.4572614661443013`}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{3.399186938124422, -8.083980388508804}, {
            10.049000034068609`, -3.4572614661443013`}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{7.360436669947441, -6.316731016557851}, {
            10.049000034068609`, 3.4572614661443013`}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{7.360436669947441, -6.316731016557851}, {11., 0.}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{10.049000034068609`, -3.4572614661443013`}, {
            7.360436669947441, 6.316731016557851}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{10.049000034068609`, -3.4572614661443013`}, {11., 
            0.}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{11., 0.}, {3.399186938124422, 8.083980388508804}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{11., 0.}, {-1.1498130959441881`, 8.453436110630323}}]}}, 
         {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
          0.7]}], {
           DiskBox[{10.049000034068609, 3.4572614661443013}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 0\\nPayoff: 154\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {10.049000034068609, 3.4572614661443013},
            BaseStyle->"Graphics"]}, {
           DiskBox[{7.360436669947441, 6.316731016557851}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 1\\nPayoff: 68\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {7.360436669947441, 6.316731016557851},
            BaseStyle->"Graphics"]}, {
           DiskBox[{3.399186938124422, 8.083980388508804}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 9\\nPayoff: 75\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {3.399186938124422, 8.083980388508804},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-1.1498130959441881, 8.453436110630323}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 2\\nPayoff: 136\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-1.1498130959441881, 8.453436110630323},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-5.5, 7.361215932167728}, 0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 10\\nPayoff: 4\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-5.5, 7.361215932167728},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-8.899186938124423, 4.996174644486022}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 3\\nPayoff: 94\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-8.899186938124423, 4.996174644486022},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-10.759623608071863, 1.767249371950954}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 11\\nPayoff: 172\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-10.759623608071863, 1.767249371950954},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-10.759623608071863, -1.767249371950954}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 4\\nPayoff: 73\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-10.759623608071863, -1.767249371950954},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-8.899186938124423, -4.996174644486022}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 12\\nPayoff: 68\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-8.899186938124423, -4.996174644486022},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-5.5, -7.361215932167728}, 0.09359782207206707], 
           InsetBox[
            PanelBox["\<\"Number: 5\\nPayoff: 36\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-5.5, -7.361215932167728},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-1.1498130959441881, -8.453436110630323}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 13\\nPayoff: 52\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-1.1498130959441881, -8.453436110630323},
            BaseStyle->"Graphics"]}, {
           DiskBox[{3.399186938124422, -8.083980388508804}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 6\\nPayoff: 196\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {3.399186938124422, -8.083980388508804},
            BaseStyle->"Graphics"]}, {
           DiskBox[{7.360436669947441, -6.316731016557851}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 14\\nPayoff: 113\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {7.360436669947441, -6.316731016557851},
            BaseStyle->"Graphics"]}, {
           DiskBox[{10.049000034068609, -3.4572614661443013}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 7\\nPayoff: 112\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {10.049000034068609, -3.4572614661443013},
            BaseStyle->"Graphics"]}, {DiskBox[{11., 0.}, 0.09359782207206707],
            InsetBox[
            PanelBox["\<\"Number: 8\\nPayoff: 68\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {11., 0.},
            BaseStyle->"Graphics"]}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None,
    ImageSize->Large], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{0, 4, 7, 1, 5, 8, 2, 6, 9, 3, 10, 11, 12, 13, 
        14}, {{{1, 2}, {1, 3}, {4, 5}, {4, 6}, {7, 8}, {7, 9}, {10, 3}, {10, 
         11}, {2, 6}, {2, 12}, {5, 9}, {5, 13}, {8, 11}, {8, 14}, {3, 12}, {3,
          15}, {6, 1}, {6, 13}, {9, 4}, {9, 14}, {11, 7}, {11, 15}, {12, 1}, {
         12, 10}, {13, 4}, {13, 2}, {14, 7}, {14, 5}, {15, 10}, {15, 8}}, 
         Null}, {EdgeShapeFunction -> {
           GraphElementData["UnfilledArrow", "ArrowSize" -> 0.03]}, ImageSize -> 
         Large, VertexCoordinates -> {{
           11 Cos[Rational[2, 15] Pi], 3.4572614661443013`}, {
           11 Sin[Rational[7, 30] Pi], 6.316731016557851}, {
           Rational[11, 4] (-1 + 5^Rational[1, 2]), 
            8.083980388508804}, {(-11) Sin[Rational[1, 30] Pi], 
            8.453436110630323}, {
            Rational[-11, 2], 7.361215932167728}, {
           Rational[11, 4] (-1 - 5^Rational[1, 2]), 
            4.996174644486022}, {(-11) Cos[Rational[1, 15] Pi], 
            1.767249371950954}, {(-11) 
            Cos[Rational[1, 15] Pi], -1.767249371950954}, {
           Rational[11, 4] (-1 - 5^Rational[1, 2]), -4.996174644486022}, {
            Rational[-11, 2], -7.361215932167728}, {(-11) 
            Sin[Rational[1, 30] Pi], -8.453436110630323}, {
           Rational[11, 4] (-1 + 5^Rational[1, 2]), -8.083980388508804}, {
           11 Sin[Rational[7, 30] Pi], -6.316731016557851}, {
           11 Cos[Rational[2, 15] Pi], -3.4572614661443013`}, {11, 0.}}, 
         VertexLabels -> {
          6 -> Placed[
            "Number: 6\nPayoff: 196", Center, $CellContext`panelLabel], 3 -> 
           Placed["Number: 3\nPayoff: 94", Center, $CellContext`panelLabel], 
           11 -> Placed[
            "Number: 11\nPayoff: 172", Center, $CellContext`panelLabel], 5 -> 
           Placed["Number: 5\nPayoff: 36", Center, $CellContext`panelLabel], 
           8 -> Placed[
            "Number: 8\nPayoff: 68", Center, $CellContext`panelLabel], 7 -> 
           Placed["Number: 7\nPayoff: 112", Center, $CellContext`panelLabel], 
           14 -> Placed[
            "Number: 14\nPayoff: 113", Center, $CellContext`panelLabel], 10 -> 
           Placed["Number: 10\nPayoff: 4", Center, $CellContext`panelLabel], 
           9 -> Placed[
            "Number: 9\nPayoff: 75", Center, $CellContext`panelLabel], 4 -> 
           Placed["Number: 4\nPayoff: 73", Center, $CellContext`panelLabel], 
           12 -> Placed[
            "Number: 12\nPayoff: 68", Center, $CellContext`panelLabel], 13 -> 
           Placed["Number: 13\nPayoff: 52", Center, $CellContext`panelLabel], 
           2 -> Placed[
            "Number: 2\nPayoff: 136", Center, $CellContext`panelLabel], 1 -> 
           Placed["Number: 1\nPayoff: 68", Center, $CellContext`panelLabel], 
           0 -> Placed[
            "Number: 0\nPayoff: 154", Center, $CellContext`panelLabel]}}]]}, 
      TagBox[GraphicsGroupBox[{
         {Hue[0.6, 0.7, 0.5], Opacity[0.7], 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{10.049000034068609`, 3.4572614661443013`}, {
            7.360436669947441, 6.316731016557851}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{10.049000034068609`, 3.4572614661443013`}, {
            3.399186938124422, 8.083980388508804}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{7.360436669947441, 
            6.316731016557851}, {-8.899186938124423, 4.996174644486022}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{7.360436669947441, 6.316731016557851}, {
            3.399186938124422, -8.083980388508804}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{3.399186938124422, 8.083980388508804}, {
            3.399186938124422, -8.083980388508804}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{3.399186938124422, 8.083980388508804}, {11., 0.}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-1.1498130959441881`, 8.453436110630323}, {-5.5, 
            7.361215932167728}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-1.1498130959441881`, 
            8.453436110630323}, {-8.899186938124423, 4.996174644486022}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-5.5, 
            7.361215932167728}, {-8.899186938124423, -4.996174644486022}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-5.5, 7.361215932167728}, {
            7.360436669947441, -6.316731016557851}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-8.899186938124423, 4.996174644486022}, {
            10.049000034068609`, 3.4572614661443013`}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-8.899186938124423, 4.996174644486022}, {
            7.360436669947441, -6.316731016557851}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-10.759623608071863`, 
            1.767249371950954}, {-10.759623608071863`, -1.767249371950954}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-10.759623608071863`, 
            1.767249371950954}, {-8.899186938124423, -4.996174644486022}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-10.759623608071863`, -1.767249371950954}, \
{-1.1498130959441881`, -8.453436110630323}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-10.759623608071863`, -1.767249371950954}, {
            10.049000034068609`, -3.4572614661443013`}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-8.899186938124423, -4.996174644486022}, \
{-1.1498130959441881`, 8.453436110630323}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-8.899186938124423, -4.996174644486022}, {
            10.049000034068609`, -3.4572614661443013`}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-5.5, -7.361215932167728}, {3.399186938124422, 
            8.083980388508804}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-5.5, -7.361215932167728}, {-1.1498130959441881`, \
-8.453436110630323}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-1.1498130959441881`, -8.453436110630323}, \
{-10.759623608071863`, 1.767249371950954}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-1.1498130959441881`, -8.453436110630323}, {11., 0.}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{3.399186938124422, -8.083980388508804}, {
            10.049000034068609`, 3.4572614661443013`}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{
            3.399186938124422, -8.083980388508804}, {-5.5, \
-7.361215932167728}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{7.360436669947441, -6.316731016557851}, {
            7.360436669947441, 6.316731016557851}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{
            7.360436669947441, -6.316731016557851}, {-1.1498130959441881`, 
            8.453436110630323}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{10.049000034068609`, -3.4572614661443013`}, {-5.5, 
            7.361215932167728}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{
            10.049000034068609`, -3.4572614661443013`}, {-10.759623608071863`,
             1.767249371950954}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{11., 0.}, {-10.759623608071863`, -1.767249371950954}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{11., 0.}, {-5.5, -7.361215932167728}}]}}, 
         {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
          0.7]}], {
           DiskBox[{10.049000034068609, 3.4572614661443013}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 0\\nPayoff: 154\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {10.049000034068609, 3.4572614661443013},
            BaseStyle->"Graphics"]}, {
           DiskBox[{7.360436669947441, 6.316731016557851}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 4\\nPayoff: 73\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {7.360436669947441, 6.316731016557851},
            BaseStyle->"Graphics"]}, {
           DiskBox[{3.399186938124422, 8.083980388508804}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 7\\nPayoff: 112\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {3.399186938124422, 8.083980388508804},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-1.1498130959441881, 8.453436110630323}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 1\\nPayoff: 68\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-1.1498130959441881, 8.453436110630323},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-5.5, 7.361215932167728}, 0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 5\\nPayoff: 36\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-5.5, 7.361215932167728},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-8.899186938124423, 4.996174644486022}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 8\\nPayoff: 68\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-8.899186938124423, 4.996174644486022},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-10.759623608071863, 1.767249371950954}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 2\\nPayoff: 136\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-10.759623608071863, 1.767249371950954},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-10.759623608071863, -1.767249371950954}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 6\\nPayoff: 196\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-10.759623608071863, -1.767249371950954},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-8.899186938124423, -4.996174644486022}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 9\\nPayoff: 75\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-8.899186938124423, -4.996174644486022},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-5.5, -7.361215932167728}, 0.09359782207206707], 
           InsetBox[
            PanelBox["\<\"Number: 3\\nPayoff: 94\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-5.5, -7.361215932167728},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-1.1498130959441881, -8.453436110630323}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 10\\nPayoff: 4\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-1.1498130959441881, -8.453436110630323},
            BaseStyle->"Graphics"]}, {
           DiskBox[{3.399186938124422, -8.083980388508804}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 11\\nPayoff: 172\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {3.399186938124422, -8.083980388508804},
            BaseStyle->"Graphics"]}, {
           DiskBox[{7.360436669947441, -6.316731016557851}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 12\\nPayoff: 68\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {7.360436669947441, -6.316731016557851},
            BaseStyle->"Graphics"]}, {
           DiskBox[{10.049000034068609, -3.4572614661443013}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 13\\nPayoff: 52\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {10.049000034068609, -3.4572614661443013},
            BaseStyle->"Graphics"]}, {DiskBox[{11., 0.}, 0.09359782207206707],
            InsetBox[
            PanelBox["\<\"Number: 14\\nPayoff: 113\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {11., 0.},
            BaseStyle->"Graphics"]}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None,
    ImageSize->Large], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{0, 2, 6, 1, 3, 7, 4, 8, 5, 9, 10, 11, 12, 13, 
        14}, {{{1, 2}, {1, 3}, {4, 5}, {4, 6}, {2, 7}, {2, 8}, {5, 9}, {5, 
         10}, {7, 3}, {7, 11}, {9, 6}, {9, 12}, {3, 8}, {3, 13}, {6, 10}, {6, 
         14}, {8, 11}, {8, 15}, {10, 1}, {10, 12}, {11, 4}, {11, 13}, {12, 
         2}, {12, 14}, {13, 5}, {13, 15}, {14, 1}, {14, 7}, {15, 4}, {15, 9}},
          Null}, {EdgeShapeFunction -> {
           GraphElementData["UnfilledArrow", "ArrowSize" -> 0.03]}, ImageSize -> 
         Large, VertexCoordinates -> {{
           11 Cos[Rational[2, 15] Pi], 3.4572614661443013`}, {
           11 Sin[Rational[7, 30] Pi], 6.316731016557851}, {
           Rational[11, 4] (-1 + 5^Rational[1, 2]), 
            8.083980388508804}, {(-11) Sin[Rational[1, 30] Pi], 
            8.453436110630323}, {
            Rational[-11, 2], 7.361215932167728}, {
           Rational[11, 4] (-1 - 5^Rational[1, 2]), 
            4.996174644486022}, {(-11) Cos[Rational[1, 15] Pi], 
            1.767249371950954}, {(-11) 
            Cos[Rational[1, 15] Pi], -1.767249371950954}, {
           Rational[11, 4] (-1 - 5^Rational[1, 2]), -4.996174644486022}, {
            Rational[-11, 2], -7.361215932167728}, {(-11) 
            Sin[Rational[1, 30] Pi], -8.453436110630323}, {
           Rational[11, 4] (-1 + 5^Rational[1, 2]), -8.083980388508804}, {
           11 Sin[Rational[7, 30] Pi], -6.316731016557851}, {
           11 Cos[Rational[2, 15] Pi], -3.4572614661443013`}, {11, 0.}}, 
         VertexLabels -> {
          6 -> Placed[
            "Number: 6\nPayoff: 196", Center, $CellContext`panelLabel], 3 -> 
           Placed["Number: 3\nPayoff: 94", Center, $CellContext`panelLabel], 
           11 -> Placed[
            "Number: 11\nPayoff: 172", Center, $CellContext`panelLabel], 5 -> 
           Placed["Number: 5\nPayoff: 36", Center, $CellContext`panelLabel], 
           8 -> Placed[
            "Number: 8\nPayoff: 68", Center, $CellContext`panelLabel], 7 -> 
           Placed["Number: 7\nPayoff: 112", Center, $CellContext`panelLabel], 
           14 -> Placed[
            "Number: 14\nPayoff: 113", Center, $CellContext`panelLabel], 10 -> 
           Placed["Number: 10\nPayoff: 4", Center, $CellContext`panelLabel], 
           9 -> Placed[
            "Number: 9\nPayoff: 75", Center, $CellContext`panelLabel], 4 -> 
           Placed["Number: 4\nPayoff: 73", Center, $CellContext`panelLabel], 
           12 -> Placed[
            "Number: 12\nPayoff: 68", Center, $CellContext`panelLabel], 13 -> 
           Placed["Number: 13\nPayoff: 52", Center, $CellContext`panelLabel], 
           2 -> Placed[
            "Number: 2\nPayoff: 136", Center, $CellContext`panelLabel], 1 -> 
           Placed["Number: 1\nPayoff: 68", Center, $CellContext`panelLabel], 
           0 -> Placed[
            "Number: 0\nPayoff: 154", Center, $CellContext`panelLabel]}}]]}, 
      TagBox[GraphicsGroupBox[{
         {Hue[0.6, 0.7, 0.5], Opacity[0.7], 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{10.049000034068609`, 3.4572614661443013`}, {
            7.360436669947441, 6.316731016557851}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{10.049000034068609`, 3.4572614661443013`}, {
            3.399186938124422, 8.083980388508804}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{7.360436669947441, 
            6.316731016557851}, {-10.759623608071863`, 
            1.767249371950954}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{7.360436669947441, 
            6.316731016557851}, {-10.759623608071863`, -1.767249371950954}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{3.399186938124422, 
            8.083980388508804}, {-10.759623608071863`, -1.767249371950954}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{3.399186938124422, 8.083980388508804}, {
            7.360436669947441, -6.316731016557851}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-1.1498130959441881`, 8.453436110630323}, {-5.5, 
            7.361215932167728}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-1.1498130959441881`, 
            8.453436110630323}, {-8.899186938124423, 4.996174644486022}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-5.5, 
            7.361215932167728}, {-8.899186938124423, -4.996174644486022}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-5.5, 7.361215932167728}, {-5.5, -7.361215932167728}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-8.899186938124423, 
            4.996174644486022}, {-5.5, -7.361215932167728}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-8.899186938124423, 4.996174644486022}, {
            10.049000034068609`, -3.4572614661443013`}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-10.759623608071863`, 1.767249371950954}, {
            3.399186938124422, 8.083980388508804}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-10.759623608071863`, 
            1.767249371950954}, {-1.1498130959441881`, -8.453436110630323}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-10.759623608071863`, -1.767249371950954}, \
{-1.1498130959441881`, -8.453436110630323}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-10.759623608071863`, -1.767249371950954}, {11., 0.}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           
           ArrowBox[{{-8.899186938124423, -4.996174644486022}, \
{-8.899186938124423, 4.996174644486022}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-8.899186938124423, -4.996174644486022}, {
            3.399186938124422, -8.083980388508804}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-5.5, -7.361215932167728}, {10.049000034068609`, 
            3.4572614661443013`}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-5.5, -7.361215932167728}, {
            3.399186938124422, -8.083980388508804}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-1.1498130959441881`, -8.453436110630323}, \
{-1.1498130959441881`, 8.453436110630323}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-1.1498130959441881`, -8.453436110630323}, {
            7.360436669947441, -6.316731016557851}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{3.399186938124422, -8.083980388508804}, {
            7.360436669947441, 6.316731016557851}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{3.399186938124422, -8.083980388508804}, {
            10.049000034068609`, -3.4572614661443013`}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{7.360436669947441, -6.316731016557851}, {-5.5, 
            7.361215932167728}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{7.360436669947441, -6.316731016557851}, {11., 0.}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{10.049000034068609`, -3.4572614661443013`}, {
            10.049000034068609`, 3.4572614661443013`}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{
            10.049000034068609`, -3.4572614661443013`}, {-10.759623608071863`,
             1.767249371950954}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{11., 0.}, {-1.1498130959441881`, 
            8.453436110630323}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{11., 
            0.}, {-8.899186938124423, -4.996174644486022}}]}}, 
         {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
          0.7]}], {
           DiskBox[{10.049000034068609, 3.4572614661443013}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 0\\nPayoff: 154\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {10.049000034068609, 3.4572614661443013},
            BaseStyle->"Graphics"]}, {
           DiskBox[{7.360436669947441, 6.316731016557851}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 2\\nPayoff: 136\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {7.360436669947441, 6.316731016557851},
            BaseStyle->"Graphics"]}, {
           DiskBox[{3.399186938124422, 8.083980388508804}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 6\\nPayoff: 196\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {3.399186938124422, 8.083980388508804},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-1.1498130959441881, 8.453436110630323}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 1\\nPayoff: 68\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-1.1498130959441881, 8.453436110630323},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-5.5, 7.361215932167728}, 0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 3\\nPayoff: 94\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-5.5, 7.361215932167728},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-8.899186938124423, 4.996174644486022}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 7\\nPayoff: 112\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-8.899186938124423, 4.996174644486022},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-10.759623608071863, 1.767249371950954}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 4\\nPayoff: 73\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-10.759623608071863, 1.767249371950954},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-10.759623608071863, -1.767249371950954}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 8\\nPayoff: 68\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-10.759623608071863, -1.767249371950954},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-8.899186938124423, -4.996174644486022}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 5\\nPayoff: 36\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-8.899186938124423, -4.996174644486022},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-5.5, -7.361215932167728}, 0.09359782207206707], 
           InsetBox[
            PanelBox["\<\"Number: 9\\nPayoff: 75\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-5.5, -7.361215932167728},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-1.1498130959441881, -8.453436110630323}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 10\\nPayoff: 4\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-1.1498130959441881, -8.453436110630323},
            BaseStyle->"Graphics"]}, {
           DiskBox[{3.399186938124422, -8.083980388508804}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 11\\nPayoff: 172\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {3.399186938124422, -8.083980388508804},
            BaseStyle->"Graphics"]}, {
           DiskBox[{7.360436669947441, -6.316731016557851}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 12\\nPayoff: 68\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {7.360436669947441, -6.316731016557851},
            BaseStyle->"Graphics"]}, {
           DiskBox[{10.049000034068609, -3.4572614661443013}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 13\\nPayoff: 52\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {10.049000034068609, -3.4572614661443013},
            BaseStyle->"Graphics"]}, {DiskBox[{11., 0.}, 0.09359782207206707],
            InsetBox[
            PanelBox["\<\"Number: 14\\nPayoff: 113\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {11., 0.},
            BaseStyle->"Graphics"]}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None,
    ImageSize->Large], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{0, 6, 8, 1, 7, 9, 2, 10, 3, 11, 4, 12, 5, 13, 
        14}, {{{1, 2}, {1, 3}, {4, 5}, {4, 6}, {7, 3}, {7, 8}, {9, 6}, {9, 
         10}, {11, 8}, {11, 12}, {13, 10}, {13, 14}, {2, 12}, {2, 15}, {5, 
         1}, {5, 14}, {3, 4}, {3, 15}, {6, 1}, {6, 7}, {8, 4}, {8, 9}, {10, 
         7}, {10, 11}, {12, 9}, {12, 13}, {14, 11}, {14, 2}, {15, 13}, {15, 
         5}}, Null}, {EdgeShapeFunction -> {
           GraphElementData["UnfilledArrow", "ArrowSize" -> 0.03]}, ImageSize -> 
         Large, VertexCoordinates -> {{
           11 Cos[Rational[2, 15] Pi], 3.4572614661443013`}, {
           11 Sin[Rational[7, 30] Pi], 6.316731016557851}, {
           Rational[11, 4] (-1 + 5^Rational[1, 2]), 
            8.083980388508804}, {(-11) Sin[Rational[1, 30] Pi], 
            8.453436110630323}, {
            Rational[-11, 2], 7.361215932167728}, {
           Rational[11, 4] (-1 - 5^Rational[1, 2]), 
            4.996174644486022}, {(-11) Cos[Rational[1, 15] Pi], 
            1.767249371950954}, {(-11) 
            Cos[Rational[1, 15] Pi], -1.767249371950954}, {
           Rational[11, 4] (-1 - 5^Rational[1, 2]), -4.996174644486022}, {
            Rational[-11, 2], -7.361215932167728}, {(-11) 
            Sin[Rational[1, 30] Pi], -8.453436110630323}, {
           Rational[11, 4] (-1 + 5^Rational[1, 2]), -8.083980388508804}, {
           11 Sin[Rational[7, 30] Pi], -6.316731016557851}, {
           11 Cos[Rational[2, 15] Pi], -3.4572614661443013`}, {11, 0.}}, 
         VertexLabels -> {
          6 -> Placed[
            "Number: 6\nPayoff: 196", Center, $CellContext`panelLabel], 3 -> 
           Placed["Number: 3\nPayoff: 94", Center, $CellContext`panelLabel], 
           11 -> Placed[
            "Number: 11\nPayoff: 172", Center, $CellContext`panelLabel], 5 -> 
           Placed["Number: 5\nPayoff: 36", Center, $CellContext`panelLabel], 
           8 -> Placed[
            "Number: 8\nPayoff: 68", Center, $CellContext`panelLabel], 7 -> 
           Placed["Number: 7\nPayoff: 112", Center, $CellContext`panelLabel], 
           14 -> Placed[
            "Number: 14\nPayoff: 113", Center, $CellContext`panelLabel], 10 -> 
           Placed["Number: 10\nPayoff: 4", Center, $CellContext`panelLabel], 
           9 -> Placed[
            "Number: 9\nPayoff: 75", Center, $CellContext`panelLabel], 4 -> 
           Placed["Number: 4\nPayoff: 73", Center, $CellContext`panelLabel], 
           12 -> Placed[
            "Number: 12\nPayoff: 68", Center, $CellContext`panelLabel], 13 -> 
           Placed["Number: 13\nPayoff: 52", Center, $CellContext`panelLabel], 
           2 -> Placed[
            "Number: 2\nPayoff: 136", Center, $CellContext`panelLabel], 1 -> 
           Placed["Number: 1\nPayoff: 68", Center, $CellContext`panelLabel], 
           0 -> 
           Placed["Number: 0\nPayoff: 154", 
             Center, $CellContext`panelLabel]}}]]}, 
      TagBox[GraphicsGroupBox[{
         {Hue[0.6, 0.7, 0.5], Opacity[0.7], 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{10.049000034068609`, 3.4572614661443013`}, {
            7.360436669947441, 6.316731016557851}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{10.049000034068609`, 3.4572614661443013`}, {
            3.399186938124422, 8.083980388508804}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{7.360436669947441, 6.316731016557851}, {
            3.399186938124422, -8.083980388508804}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{7.360436669947441, 6.316731016557851}, {11., 0.}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{3.399186938124422, 
            8.083980388508804}, {-1.1498130959441881`, 
            8.453436110630323}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{3.399186938124422, 8.083980388508804}, {11., 0.}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-1.1498130959441881`, 8.453436110630323}, {-5.5, 
            7.361215932167728}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-1.1498130959441881`, 
            8.453436110630323}, {-8.899186938124423, 4.996174644486022}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-5.5, 7.361215932167728}, {10.049000034068609`, 
            3.4572614661443013`}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-5.5, 7.361215932167728}, {
            10.049000034068609`, -3.4572614661443013`}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-8.899186938124423, 4.996174644486022}, {
            10.049000034068609`, 3.4572614661443013`}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-8.899186938124423, 
            4.996174644486022}, {-10.759623608071863`, 
            1.767249371950954}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-10.759623608071863`, 1.767249371950954}, {
            3.399186938124422, 8.083980388508804}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-10.759623608071863`, 
            1.767249371950954}, {-10.759623608071863`, -1.767249371950954}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-10.759623608071863`, -1.767249371950954}, \
{-1.1498130959441881`, 8.453436110630323}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-10.759623608071863`, -1.767249371950954}, \
{-8.899186938124423, -4.996174644486022}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-8.899186938124423, -4.996174644486022}, \
{-8.899186938124423, 4.996174644486022}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-8.899186938124423, -4.996174644486022}, {-5.5, \
-7.361215932167728}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-5.5, -7.361215932167728}, {-10.759623608071863`, 
            1.767249371950954}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-5.5, -7.361215932167728}, {-1.1498130959441881`, \
-8.453436110630323}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-1.1498130959441881`, -8.453436110630323}, \
{-10.759623608071863`, -1.767249371950954}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-1.1498130959441881`, -8.453436110630323}, {
            3.399186938124422, -8.083980388508804}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{
            3.399186938124422, -8.083980388508804}, {-8.899186938124423, \
-4.996174644486022}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{3.399186938124422, -8.083980388508804}, {
            7.360436669947441, -6.316731016557851}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{
            7.360436669947441, -6.316731016557851}, {-5.5, \
-7.361215932167728}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{7.360436669947441, -6.316731016557851}, {
            10.049000034068609`, -3.4572614661443013`}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{10.049000034068609`, -3.4572614661443013`}, {
            7.360436669947441, 6.316731016557851}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{
            10.049000034068609`, -3.4572614661443013`}, \
{-1.1498130959441881`, -8.453436110630323}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{11., 0.}, {-5.5, 7.361215932167728}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{11., 0.}, {7.360436669947441, -6.316731016557851}}]}}, 
         {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
          0.7]}], {
           DiskBox[{10.049000034068609, 3.4572614661443013}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 0\\nPayoff: 154\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {10.049000034068609, 3.4572614661443013},
            BaseStyle->"Graphics"]}, {
           DiskBox[{7.360436669947441, 6.316731016557851}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 6\\nPayoff: 196\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {7.360436669947441, 6.316731016557851},
            BaseStyle->"Graphics"]}, {
           DiskBox[{3.399186938124422, 8.083980388508804}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 8\\nPayoff: 68\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {3.399186938124422, 8.083980388508804},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-1.1498130959441881, 8.453436110630323}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 1\\nPayoff: 68\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-1.1498130959441881, 8.453436110630323},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-5.5, 7.361215932167728}, 0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 7\\nPayoff: 112\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-5.5, 7.361215932167728},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-8.899186938124423, 4.996174644486022}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 9\\nPayoff: 75\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-8.899186938124423, 4.996174644486022},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-10.759623608071863, 1.767249371950954}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 2\\nPayoff: 136\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-10.759623608071863, 1.767249371950954},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-10.759623608071863, -1.767249371950954}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 10\\nPayoff: 4\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-10.759623608071863, -1.767249371950954},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-8.899186938124423, -4.996174644486022}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 3\\nPayoff: 94\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-8.899186938124423, -4.996174644486022},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-5.5, -7.361215932167728}, 0.09359782207206707], 
           InsetBox[
            PanelBox["\<\"Number: 11\\nPayoff: 172\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-5.5, -7.361215932167728},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-1.1498130959441881, -8.453436110630323}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 4\\nPayoff: 73\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-1.1498130959441881, -8.453436110630323},
            BaseStyle->"Graphics"]}, {
           DiskBox[{3.399186938124422, -8.083980388508804}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 12\\nPayoff: 68\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {3.399186938124422, -8.083980388508804},
            BaseStyle->"Graphics"]}, {
           DiskBox[{7.360436669947441, -6.316731016557851}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 5\\nPayoff: 36\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {7.360436669947441, -6.316731016557851},
            BaseStyle->"Graphics"]}, {
           DiskBox[{10.049000034068609, -3.4572614661443013}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 13\\nPayoff: 52\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {10.049000034068609, -3.4572614661443013},
            BaseStyle->"Graphics"]}, {DiskBox[{11., 0.}, 0.09359782207206707],
            InsetBox[
            PanelBox["\<\"Number: 14\\nPayoff: 113\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {11., 0.},
            BaseStyle->"Graphics"]}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None,
    ImageSize->Large], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{0, 3, 8, 1, 4, 9, 2, 5, 10, 6, 11, 7, 12, 13, 
        14}, {{{1, 2}, {1, 3}, {4, 5}, {4, 6}, {7, 8}, {7, 9}, {2, 10}, {2, 
         11}, {5, 12}, {5, 13}, {8, 3}, {8, 14}, {10, 6}, {10, 15}, {12, 1}, {
         12, 9}, {3, 4}, {3, 11}, {6, 7}, {6, 13}, {9, 2}, {9, 14}, {11, 5}, {
         11, 15}, {13, 1}, {13, 8}, {14, 4}, {14, 10}, {15, 7}, {15, 12}}, 
         Null}, {EdgeShapeFunction -> {
           GraphElementData["UnfilledArrow", "ArrowSize" -> 0.03]}, ImageSize -> 
         Large, VertexCoordinates -> {{
           11 Cos[Rational[2, 15] Pi], 3.4572614661443013`}, {
           11 Sin[Rational[7, 30] Pi], 6.316731016557851}, {
           Rational[11, 4] (-1 + 5^Rational[1, 2]), 
            8.083980388508804}, {(-11) Sin[Rational[1, 30] Pi], 
            8.453436110630323}, {
            Rational[-11, 2], 7.361215932167728}, {
           Rational[11, 4] (-1 - 5^Rational[1, 2]), 
            4.996174644486022}, {(-11) Cos[Rational[1, 15] Pi], 
            1.767249371950954}, {(-11) 
            Cos[Rational[1, 15] Pi], -1.767249371950954}, {
           Rational[11, 4] (-1 - 5^Rational[1, 2]), -4.996174644486022}, {
            Rational[-11, 2], -7.361215932167728}, {(-11) 
            Sin[Rational[1, 30] Pi], -8.453436110630323}, {
           Rational[11, 4] (-1 + 5^Rational[1, 2]), -8.083980388508804}, {
           11 Sin[Rational[7, 30] Pi], -6.316731016557851}, {
           11 Cos[Rational[2, 15] Pi], -3.4572614661443013`}, {11, 0.}}, 
         VertexLabels -> {
          6 -> Placed[
            "Number: 6\nPayoff: 196", Center, $CellContext`panelLabel], 3 -> 
           Placed["Number: 3\nPayoff: 94", Center, $CellContext`panelLabel], 
           11 -> Placed[
            "Number: 11\nPayoff: 172", Center, $CellContext`panelLabel], 5 -> 
           Placed["Number: 5\nPayoff: 36", Center, $CellContext`panelLabel], 
           8 -> Placed[
            "Number: 8\nPayoff: 68", Center, $CellContext`panelLabel], 7 -> 
           Placed["Number: 7\nPayoff: 112", Center, $CellContext`panelLabel], 
           14 -> Placed[
            "Number: 14\nPayoff: 113", Center, $CellContext`panelLabel], 10 -> 
           Placed["Number: 10\nPayoff: 4", Center, $CellContext`panelLabel], 
           9 -> 
           Placed["Number: 9\nPayoff: 75", Center, $CellContext`panelLabel], 
           4 -> Placed[
            "Number: 4\nPayoff: 73", Center, $CellContext`panelLabel], 12 -> 
           Placed["Number: 12\nPayoff: 68", Center, $CellContext`panelLabel], 
           13 -> Placed[
            "Number: 13\nPayoff: 52", Center, $CellContext`panelLabel], 2 -> 
           Placed["Number: 2\nPayoff: 136", Center, $CellContext`panelLabel], 
           1 -> Placed[
            "Number: 1\nPayoff: 68", Center, $CellContext`panelLabel], 0 -> 
           Placed["Number: 0\nPayoff: 154", 
             Center, $CellContext`panelLabel]}}]]}, 
      TagBox[GraphicsGroupBox[{
         {Hue[0.6, 0.7, 0.5], Opacity[0.7], 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{10.049000034068609`, 3.4572614661443013`}, {
            7.360436669947441, 6.316731016557851}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{10.049000034068609`, 3.4572614661443013`}, {
            3.399186938124422, 8.083980388508804}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{7.360436669947441, 
            6.316731016557851}, {-5.5, -7.361215932167728}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{7.360436669947441, 
            6.316731016557851}, {-1.1498130959441881`, -8.453436110630323}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{3.399186938124422, 
            8.083980388508804}, {-1.1498130959441881`, 
            8.453436110630323}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{3.399186938124422, 
            8.083980388508804}, {-1.1498130959441881`, -8.453436110630323}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-1.1498130959441881`, 8.453436110630323}, {-5.5, 
            7.361215932167728}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-1.1498130959441881`, 
            8.453436110630323}, {-8.899186938124423, 4.996174644486022}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-5.5, 7.361215932167728}, {
            3.399186938124422, -8.083980388508804}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-5.5, 7.361215932167728}, {
            7.360436669947441, -6.316731016557851}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-8.899186938124423, 
            4.996174644486022}, {-10.759623608071863`, 
            1.767249371950954}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-8.899186938124423, 4.996174644486022}, {
            7.360436669947441, -6.316731016557851}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-10.759623608071863`, 
            1.767249371950954}, {-10.759623608071863`, -1.767249371950954}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-10.759623608071863`, 
            1.767249371950954}, {-8.899186938124423, -4.996174644486022}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-10.759623608071863`, -1.767249371950954}, {
            3.399186938124422, 8.083980388508804}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-10.759623608071863`, -1.767249371950954}, {
            10.049000034068609`, -3.4572614661443013`}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-8.899186938124423, -4.996174644486022}, {
            7.360436669947441, 6.316731016557851}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-8.899186938124423, -4.996174644486022}, {
            10.049000034068609`, -3.4572614661443013`}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-5.5, -7.361215932167728}, {-8.899186938124423, 
            4.996174644486022}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-5.5, -7.361215932167728}, {11., 0.}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-1.1498130959441881`, -8.453436110630323}, {-5.5, 
            7.361215932167728}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-1.1498130959441881`, -8.453436110630323}, {11., 0.}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{3.399186938124422, -8.083980388508804}, {
            10.049000034068609`, 3.4572614661443013`}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 
                 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, {-1., \
-0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{
            3.399186938124422, -8.083980388508804}, {-8.899186938124423, \
-4.996174644486022}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{7.360436669947441, -6.316731016557851}, {
            10.049000034068609`, 3.4572614661443013`}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{
            7.360436669947441, -6.316731016557851}, {-10.759623608071863`, \
-1.767249371950954}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{
            10.049000034068609`, -3.4572614661443013`}, {-1.1498130959441881`,
             8.453436110630323}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 
                 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, {-1., \
-0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{
            10.049000034068609`, -3.4572614661443013`}, {-5.5, \
-7.361215932167728}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{11., 0.}, {-10.759623608071863`, 
            1.767249371950954}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{11., 0.}, {3.399186938124422, -8.083980388508804}}]}}, 
         {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
          0.7]}], {
           DiskBox[{10.049000034068609, 3.4572614661443013}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 0\\nPayoff: 154\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {10.049000034068609, 3.4572614661443013},
            BaseStyle->"Graphics"]}, {
           DiskBox[{7.360436669947441, 6.316731016557851}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 3\\nPayoff: 94\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {7.360436669947441, 6.316731016557851},
            BaseStyle->"Graphics"]}, {
           DiskBox[{3.399186938124422, 8.083980388508804}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 8\\nPayoff: 68\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {3.399186938124422, 8.083980388508804},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-1.1498130959441881, 8.453436110630323}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 1\\nPayoff: 68\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-1.1498130959441881, 8.453436110630323},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-5.5, 7.361215932167728}, 0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 4\\nPayoff: 73\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-5.5, 7.361215932167728},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-8.899186938124423, 4.996174644486022}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 9\\nPayoff: 75\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-8.899186938124423, 4.996174644486022},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-10.759623608071863, 1.767249371950954}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 2\\nPayoff: 136\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-10.759623608071863, 1.767249371950954},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-10.759623608071863, -1.767249371950954}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 5\\nPayoff: 36\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-10.759623608071863, -1.767249371950954},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-8.899186938124423, -4.996174644486022}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 10\\nPayoff: 4\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-8.899186938124423, -4.996174644486022},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-5.5, -7.361215932167728}, 0.09359782207206707], 
           InsetBox[
            PanelBox["\<\"Number: 6\\nPayoff: 196\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-5.5, -7.361215932167728},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-1.1498130959441881, -8.453436110630323}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 11\\nPayoff: 172\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-1.1498130959441881, -8.453436110630323},
            BaseStyle->"Graphics"]}, {
           DiskBox[{3.399186938124422, -8.083980388508804}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 7\\nPayoff: 112\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {3.399186938124422, -8.083980388508804},
            BaseStyle->"Graphics"]}, {
           DiskBox[{7.360436669947441, -6.316731016557851}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 12\\nPayoff: 68\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {7.360436669947441, -6.316731016557851},
            BaseStyle->"Graphics"]}, {
           DiskBox[{10.049000034068609, -3.4572614661443013}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 13\\nPayoff: 52\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {10.049000034068609, -3.4572614661443013},
            BaseStyle->"Graphics"]}, {DiskBox[{11., 0.}, 0.09359782207206707],
            InsetBox[
            PanelBox["\<\"Number: 14\\nPayoff: 113\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {11., 0.},
            BaseStyle->"Graphics"]}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None,
    ImageSize->Large], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{0, 3, 8, 1, 4, 9, 2, 5, 10, 6, 11, 7, 12, 13, 
        14}, {{{1, 2}, {1, 3}, {4, 5}, {4, 6}, {7, 8}, {7, 9}, {2, 10}, {2, 
         11}, {5, 12}, {5, 13}, {8, 3}, {8, 14}, {10, 6}, {10, 15}, {12, 1}, {
         12, 9}, {3, 4}, {3, 11}, {6, 7}, {6, 13}, {9, 2}, {9, 14}, {11, 5}, {
         11, 15}, {13, 1}, {13, 8}, {14, 4}, {14, 10}, {15, 7}, {15, 12}}, 
         Null}, {EdgeShapeFunction -> {
           GraphElementData["UnfilledArrow", "ArrowSize" -> 0.03]}, ImageSize -> 
         Large, VertexCoordinates -> {{
           11 Cos[Rational[2, 15] Pi], 3.4572614661443013`}, {
           11 Sin[Rational[7, 30] Pi], 6.316731016557851}, {
           Rational[11, 4] (-1 + 5^Rational[1, 2]), 
            8.083980388508804}, {(-11) Sin[Rational[1, 30] Pi], 
            8.453436110630323}, {
            Rational[-11, 2], 7.361215932167728}, {
           Rational[11, 4] (-1 - 5^Rational[1, 2]), 
            4.996174644486022}, {(-11) Cos[Rational[1, 15] Pi], 
            1.767249371950954}, {(-11) 
            Cos[Rational[1, 15] Pi], -1.767249371950954}, {
           Rational[11, 4] (-1 - 5^Rational[1, 2]), -4.996174644486022}, {
            Rational[-11, 2], -7.361215932167728}, {(-11) 
            Sin[Rational[1, 30] Pi], -8.453436110630323}, {
           Rational[11, 4] (-1 + 5^Rational[1, 2]), -8.083980388508804}, {
           11 Sin[Rational[7, 30] Pi], -6.316731016557851}, {
           11 Cos[Rational[2, 15] Pi], -3.4572614661443013`}, {11, 0.}}, 
         VertexLabels -> {
          6 -> Placed[
            "Number: 6\nPayoff: 196", Center, $CellContext`panelLabel], 3 -> 
           Placed["Number: 3\nPayoff: 94", Center, $CellContext`panelLabel], 
           11 -> 
           Placed["Number: 11\nPayoff: 172", Center, $CellContext`panelLabel],
            5 -> Placed[
            "Number: 5\nPayoff: 36", Center, $CellContext`panelLabel], 8 -> 
           Placed["Number: 8\nPayoff: 68", Center, $CellContext`panelLabel], 
           7 -> Placed[
            "Number: 7\nPayoff: 112", Center, $CellContext`panelLabel], 14 -> 
           Placed["Number: 14\nPayoff: 113", Center, $CellContext`panelLabel],
            10 -> Placed[
            "Number: 10\nPayoff: 4", Center, $CellContext`panelLabel], 9 -> 
           Placed["Number: 9\nPayoff: 75", Center, $CellContext`panelLabel], 
           4 -> Placed[
            "Number: 4\nPayoff: 73", Center, $CellContext`panelLabel], 12 -> 
           Placed["Number: 12\nPayoff: 68", Center, $CellContext`panelLabel], 
           13 -> Placed[
            "Number: 13\nPayoff: 52", Center, $CellContext`panelLabel], 2 -> 
           Placed["Number: 2\nPayoff: 136", Center, $CellContext`panelLabel], 
           1 -> Placed[
            "Number: 1\nPayoff: 68", Center, $CellContext`panelLabel], 0 -> 
           Placed["Number: 0\nPayoff: 154", 
             Center, $CellContext`panelLabel]}}]]}, 
      TagBox[GraphicsGroupBox[{
         {Hue[0.6, 0.7, 0.5], Opacity[0.7], 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{10.049000034068609`, 3.4572614661443013`}, {
            7.360436669947441, 6.316731016557851}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{10.049000034068609`, 3.4572614661443013`}, {
            3.399186938124422, 8.083980388508804}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{7.360436669947441, 
            6.316731016557851}, {-5.5, -7.361215932167728}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{7.360436669947441, 
            6.316731016557851}, {-1.1498130959441881`, -8.453436110630323}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{3.399186938124422, 
            8.083980388508804}, {-1.1498130959441881`, 
            8.453436110630323}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{3.399186938124422, 
            8.083980388508804}, {-1.1498130959441881`, -8.453436110630323}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-1.1498130959441881`, 8.453436110630323}, {-5.5, 
            7.361215932167728}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-1.1498130959441881`, 
            8.453436110630323}, {-8.899186938124423, 4.996174644486022}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-5.5, 7.361215932167728}, {
            3.399186938124422, -8.083980388508804}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-5.5, 7.361215932167728}, {
            7.360436669947441, -6.316731016557851}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-8.899186938124423, 
            4.996174644486022}, {-10.759623608071863`, 
            1.767249371950954}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-8.899186938124423, 4.996174644486022}, {
            7.360436669947441, -6.316731016557851}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-10.759623608071863`, 
            1.767249371950954}, {-10.759623608071863`, -1.767249371950954}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-10.759623608071863`, 
            1.767249371950954}, {-8.899186938124423, -4.996174644486022}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-10.759623608071863`, -1.767249371950954}, {
            3.399186938124422, 8.083980388508804}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-10.759623608071863`, -1.767249371950954}, {
            10.049000034068609`, -3.4572614661443013`}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-8.899186938124423, -4.996174644486022}, {
            7.360436669947441, 6.316731016557851}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-8.899186938124423, -4.996174644486022}, {
            10.049000034068609`, -3.4572614661443013`}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-5.5, -7.361215932167728}, {-8.899186938124423, 
            4.996174644486022}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-5.5, -7.361215932167728}, {11., 0.}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-1.1498130959441881`, -8.453436110630323}, {-5.5, 
            7.361215932167728}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-1.1498130959441881`, -8.453436110630323}, {11., 0.}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 
                 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, {-1., \
-0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{3.399186938124422, -8.083980388508804}, {
            10.049000034068609`, 3.4572614661443013`}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{
            3.399186938124422, -8.083980388508804}, {-8.899186938124423, \
-4.996174644486022}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{7.360436669947441, -6.316731016557851}, {
            10.049000034068609`, 3.4572614661443013`}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{
            7.360436669947441, -6.316731016557851}, {-10.759623608071863`, \
-1.767249371950954}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 
                 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, {-1., \
-0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{
            10.049000034068609`, -3.4572614661443013`}, {-1.1498130959441881`,
             8.453436110630323}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{
            10.049000034068609`, -3.4572614661443013`}, {-5.5, \
-7.361215932167728}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{11., 0.}, {-10.759623608071863`, 
            1.767249371950954}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{11., 0.}, {3.399186938124422, -8.083980388508804}}]}}, 
         {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
          0.7]}], {
           DiskBox[{10.049000034068609, 3.4572614661443013}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 0\\nPayoff: 154\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {10.049000034068609, 3.4572614661443013},
            BaseStyle->"Graphics"]}, {
           DiskBox[{7.360436669947441, 6.316731016557851}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 3\\nPayoff: 94\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {7.360436669947441, 6.316731016557851},
            BaseStyle->"Graphics"]}, {
           DiskBox[{3.399186938124422, 8.083980388508804}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 8\\nPayoff: 68\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {3.399186938124422, 8.083980388508804},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-1.1498130959441881, 8.453436110630323}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 1\\nPayoff: 68\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-1.1498130959441881, 8.453436110630323},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-5.5, 7.361215932167728}, 0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 4\\nPayoff: 73\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-5.5, 7.361215932167728},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-8.899186938124423, 4.996174644486022}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 9\\nPayoff: 75\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-8.899186938124423, 4.996174644486022},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-10.759623608071863, 1.767249371950954}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 2\\nPayoff: 136\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-10.759623608071863, 1.767249371950954},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-10.759623608071863, -1.767249371950954}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 5\\nPayoff: 36\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-10.759623608071863, -1.767249371950954},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-8.899186938124423, -4.996174644486022}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 10\\nPayoff: 4\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-8.899186938124423, -4.996174644486022},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-5.5, -7.361215932167728}, 0.09359782207206707], 
           InsetBox[
            PanelBox["\<\"Number: 6\\nPayoff: 196\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-5.5, -7.361215932167728},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-1.1498130959441881, -8.453436110630323}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 11\\nPayoff: 172\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-1.1498130959441881, -8.453436110630323},
            BaseStyle->"Graphics"]}, {
           DiskBox[{3.399186938124422, -8.083980388508804}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 7\\nPayoff: 112\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {3.399186938124422, -8.083980388508804},
            BaseStyle->"Graphics"]}, {
           DiskBox[{7.360436669947441, -6.316731016557851}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 12\\nPayoff: 68\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {7.360436669947441, -6.316731016557851},
            BaseStyle->"Graphics"]}, {
           DiskBox[{10.049000034068609, -3.4572614661443013}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 13\\nPayoff: 52\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {10.049000034068609, -3.4572614661443013},
            BaseStyle->"Graphics"]}, {DiskBox[{11., 0.}, 0.09359782207206707],
            InsetBox[
            PanelBox["\<\"Number: 14\\nPayoff: 113\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {11., 0.},
            BaseStyle->"Graphics"]}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None,
    ImageSize->Large], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{0, 5, 8, 1, 6, 9, 2, 7, 10, 3, 11, 4, 12, 13, 
        14}, {{{1, 2}, {1, 3}, {4, 5}, {4, 6}, {7, 8}, {7, 9}, {10, 3}, {10, 
         11}, {12, 6}, {12, 13}, {2, 9}, {2, 14}, {5, 11}, {5, 15}, {8, 1}, {
         8, 13}, {3, 4}, {3, 14}, {6, 7}, {6, 15}, {9, 1}, {9, 10}, {11, 4}, {
         11, 12}, {13, 7}, {13, 2}, {14, 10}, {14, 5}, {15, 12}, {15, 8}}, 
         Null}, {EdgeShapeFunction -> {
           GraphElementData["UnfilledArrow", "ArrowSize" -> 0.03]}, ImageSize -> 
         Large, VertexCoordinates -> {{
           11 Cos[Rational[2, 15] Pi], 3.4572614661443013`}, {
           11 Sin[Rational[7, 30] Pi], 6.316731016557851}, {
           Rational[11, 4] (-1 + 5^Rational[1, 2]), 
            8.083980388508804}, {(-11) Sin[Rational[1, 30] Pi], 
            8.453436110630323}, {
            Rational[-11, 2], 7.361215932167728}, {
           Rational[11, 4] (-1 - 5^Rational[1, 2]), 
            4.996174644486022}, {(-11) Cos[Rational[1, 15] Pi], 
            1.767249371950954}, {(-11) 
            Cos[Rational[1, 15] Pi], -1.767249371950954}, {
           Rational[11, 4] (-1 - 5^Rational[1, 2]), -4.996174644486022}, {
            Rational[-11, 2], -7.361215932167728}, {(-11) 
            Sin[Rational[1, 30] Pi], -8.453436110630323}, {
           Rational[11, 4] (-1 + 5^Rational[1, 2]), -8.083980388508804}, {
           11 Sin[Rational[7, 30] Pi], -6.316731016557851}, {
           11 Cos[Rational[2, 15] Pi], -3.4572614661443013`}, {11, 0.}}, 
         VertexLabels -> {
          6 -> Placed[
            "Number: 6\nPayoff: 196", Center, $CellContext`panelLabel], 3 -> 
           Placed["Number: 3\nPayoff: 94", Center, $CellContext`panelLabel], 
           11 -> Placed[
            "Number: 11\nPayoff: 172", Center, $CellContext`panelLabel], 5 -> 
           Placed["Number: 5\nPayoff: 36", Center, $CellContext`panelLabel], 
           8 -> Placed[
            "Number: 8\nPayoff: 68", Center, $CellContext`panelLabel], 7 -> 
           Placed["Number: 7\nPayoff: 112", Center, $CellContext`panelLabel], 
           14 -> Placed[
            "Number: 14\nPayoff: 113", Center, $CellContext`panelLabel], 10 -> 
           Placed["Number: 10\nPayoff: 4", Center, $CellContext`panelLabel], 
           9 -> Placed[
            "Number: 9\nPayoff: 75", Center, $CellContext`panelLabel], 4 -> 
           Placed["Number: 4\nPayoff: 73", Center, $CellContext`panelLabel], 
           12 -> Placed[
            "Number: 12\nPayoff: 68", Center, $CellContext`panelLabel], 13 -> 
           Placed["Number: 13\nPayoff: 52", Center, $CellContext`panelLabel], 
           2 -> Placed[
            "Number: 2\nPayoff: 136", Center, $CellContext`panelLabel], 1 -> 
           Placed["Number: 1\nPayoff: 68", Center, $CellContext`panelLabel], 
           0 -> Placed[
            "Number: 0\nPayoff: 154", Center, $CellContext`panelLabel]}}]]}, 
      TagBox[GraphicsGroupBox[{
         {Hue[0.6, 0.7, 0.5], Opacity[0.7], 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{10.049000034068609`, 3.4572614661443013`}, {
            7.360436669947441, 6.316731016557851}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{10.049000034068609`, 3.4572614661443013`}, {
            3.399186938124422, 8.083980388508804}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{7.360436669947441, 
            6.316731016557851}, {-8.899186938124423, -4.996174644486022}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{7.360436669947441, 6.316731016557851}, {
            10.049000034068609`, -3.4572614661443013`}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{3.399186938124422, 
            8.083980388508804}, {-1.1498130959441881`, 8.453436110630323}}]}, 
          
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{3.399186938124422, 8.083980388508804}, {
            10.049000034068609`, -3.4572614661443013`}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-1.1498130959441881`, 8.453436110630323}, {-5.5, 
            7.361215932167728}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-1.1498130959441881`, 
            8.453436110630323}, {-8.899186938124423, 4.996174644486022}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-5.5, 
            7.361215932167728}, {-1.1498130959441881`, -8.453436110630323}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-5.5, 7.361215932167728}, {11., 0.}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-8.899186938124423, 
            4.996174644486022}, {-10.759623608071863`, 
            1.767249371950954}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-8.899186938124423, 4.996174644486022}, {11., 0.}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-10.759623608071863`, 
            1.767249371950954}, {-10.759623608071863`, -1.767249371950954}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 
                 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, {-1., \
-0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-10.759623608071863`, 
            1.767249371950954}, {-8.899186938124423, -4.996174644486022}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-10.759623608071863`, -1.767249371950954}, {
            10.049000034068609`, 3.4572614661443013`}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-10.759623608071863`, -1.767249371950954}, {
            7.360436669947441, -6.316731016557851}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-8.899186938124423, -4.996174644486022}, {
            10.049000034068609`, 3.4572614661443013`}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 
                 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, {-1., \
-0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-8.899186938124423, -4.996174644486022}, {-5.5, \
-7.361215932167728}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-5.5, -7.361215932167728}, {3.399186938124422, 
            8.083980388508804}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-5.5, -7.361215932167728}, {-1.1498130959441881`, \
-8.453436110630323}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-1.1498130959441881`, -8.453436110630323}, \
{-1.1498130959441881`, 8.453436110630323}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-1.1498130959441881`, -8.453436110630323}, {
            3.399186938124422, -8.083980388508804}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{
            3.399186938124422, -8.083980388508804}, {-8.899186938124423, 
            4.996174644486022}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{3.399186938124422, -8.083980388508804}, {
            7.360436669947441, -6.316731016557851}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{7.360436669947441, -6.316731016557851}, {
            7.360436669947441, 6.316731016557851}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{
            7.360436669947441, -6.316731016557851}, {-10.759623608071863`, 
            1.767249371950954}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{10.049000034068609`, -3.4572614661443013`}, {-5.5, 
            7.361215932167728}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{
            10.049000034068609`, -3.4572614661443013`}, {-5.5, \
-7.361215932167728}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{11., 0.}, {-10.759623608071863`, -1.767249371950954}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{11., 0.}, {3.399186938124422, -8.083980388508804}}]}}, 
         {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
          0.7]}], {
           DiskBox[{10.049000034068609, 3.4572614661443013}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 0\\nPayoff: 154\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {10.049000034068609, 3.4572614661443013},
            BaseStyle->"Graphics"]}, {
           DiskBox[{7.360436669947441, 6.316731016557851}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 5\\nPayoff: 36\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {7.360436669947441, 6.316731016557851},
            BaseStyle->"Graphics"]}, {
           DiskBox[{3.399186938124422, 8.083980388508804}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 8\\nPayoff: 68\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {3.399186938124422, 8.083980388508804},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-1.1498130959441881, 8.453436110630323}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 1\\nPayoff: 68\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-1.1498130959441881, 8.453436110630323},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-5.5, 7.361215932167728}, 0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 6\\nPayoff: 196\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-5.5, 7.361215932167728},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-8.899186938124423, 4.996174644486022}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 9\\nPayoff: 75\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-8.899186938124423, 4.996174644486022},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-10.759623608071863, 1.767249371950954}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 2\\nPayoff: 136\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-10.759623608071863, 1.767249371950954},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-10.759623608071863, -1.767249371950954}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 7\\nPayoff: 112\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-10.759623608071863, -1.767249371950954},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-8.899186938124423, -4.996174644486022}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 10\\nPayoff: 4\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-8.899186938124423, -4.996174644486022},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-5.5, -7.361215932167728}, 0.09359782207206707], 
           InsetBox[
            PanelBox["\<\"Number: 3\\nPayoff: 94\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-5.5, -7.361215932167728},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-1.1498130959441881, -8.453436110630323}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 11\\nPayoff: 172\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-1.1498130959441881, -8.453436110630323},
            BaseStyle->"Graphics"]}, {
           DiskBox[{3.399186938124422, -8.083980388508804}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 4\\nPayoff: 73\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {3.399186938124422, -8.083980388508804},
            BaseStyle->"Graphics"]}, {
           DiskBox[{7.360436669947441, -6.316731016557851}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 12\\nPayoff: 68\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {7.360436669947441, -6.316731016557851},
            BaseStyle->"Graphics"]}, {
           DiskBox[{10.049000034068609, -3.4572614661443013}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 13\\nPayoff: 52\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {10.049000034068609, -3.4572614661443013},
            BaseStyle->"Graphics"]}, {DiskBox[{11., 0.}, 0.09359782207206707],
            InsetBox[
            PanelBox["\<\"Number: 14\\nPayoff: 113\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {11., 0.},
            BaseStyle->"Graphics"]}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None,
    ImageSize->Large], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{0, 3, 7, 1, 4, 8, 2, 5, 9, 6, 10, 11, 12, 13, 
        14}, {{{1, 2}, {1, 3}, {4, 5}, {4, 6}, {7, 8}, {7, 9}, {2, 10}, {2, 
         11}, {5, 3}, {5, 12}, {8, 6}, {8, 13}, {10, 9}, {10, 14}, {3, 11}, {
         3, 15}, {6, 1}, {6, 12}, {9, 4}, {9, 13}, {11, 7}, {11, 14}, {12, 
         2}, {12, 15}, {13, 1}, {13, 5}, {14, 4}, {14, 8}, {15, 7}, {15, 10}},
          Null}, {EdgeShapeFunction -> {
           GraphElementData["UnfilledArrow", "ArrowSize" -> 0.03]}, ImageSize -> 
         Large, VertexCoordinates -> {{
           11 Cos[Rational[2, 15] Pi], 3.4572614661443013`}, {
           11 Sin[Rational[7, 30] Pi], 6.316731016557851}, {
           Rational[11, 4] (-1 + 5^Rational[1, 2]), 
            8.083980388508804}, {(-11) Sin[Rational[1, 30] Pi], 
            8.453436110630323}, {
            Rational[-11, 2], 7.361215932167728}, {
           Rational[11, 4] (-1 - 5^Rational[1, 2]), 
            4.996174644486022}, {(-11) Cos[Rational[1, 15] Pi], 
            1.767249371950954}, {(-11) 
            Cos[Rational[1, 15] Pi], -1.767249371950954}, {
           Rational[11, 4] (-1 - 5^Rational[1, 2]), -4.996174644486022}, {
            Rational[-11, 2], -7.361215932167728}, {(-11) 
            Sin[Rational[1, 30] Pi], -8.453436110630323}, {
           Rational[11, 4] (-1 + 5^Rational[1, 2]), -8.083980388508804}, {
           11 Sin[Rational[7, 30] Pi], -6.316731016557851}, {
           11 Cos[Rational[2, 15] Pi], -3.4572614661443013`}, {11, 0.}}, 
         VertexLabels -> {
          6 -> Placed[
            "Number: 6\nPayoff: 196", Center, $CellContext`panelLabel], 3 -> 
           Placed["Number: 3\nPayoff: 94", Center, $CellContext`panelLabel], 
           11 -> Placed[
            "Number: 11\nPayoff: 172", Center, $CellContext`panelLabel], 5 -> 
           Placed["Number: 5\nPayoff: 36", Center, $CellContext`panelLabel], 
           8 -> Placed[
            "Number: 8\nPayoff: 68", Center, $CellContext`panelLabel], 7 -> 
           Placed["Number: 7\nPayoff: 112", Center, $CellContext`panelLabel], 
           14 -> Placed[
            "Number: 14\nPayoff: 113", Center, $CellContext`panelLabel], 10 -> 
           Placed["Number: 10\nPayoff: 4", Center, $CellContext`panelLabel], 
           9 -> Placed[
            "Number: 9\nPayoff: 75", Center, $CellContext`panelLabel], 4 -> 
           Placed["Number: 4\nPayoff: 73", Center, $CellContext`panelLabel], 
           12 -> Placed[
            "Number: 12\nPayoff: 68", Center, $CellContext`panelLabel], 13 -> 
           Placed["Number: 13\nPayoff: 52", Center, $CellContext`panelLabel], 
           2 -> Placed[
            "Number: 2\nPayoff: 136", Center, $CellContext`panelLabel], 1 -> 
           Placed["Number: 1\nPayoff: 68", Center, $CellContext`panelLabel], 
           0 -> Placed[
            "Number: 0\nPayoff: 154", Center, $CellContext`panelLabel]}}]]}, 
      TagBox[GraphicsGroupBox[{
         {Hue[0.6, 0.7, 0.5], Opacity[0.7], 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{10.049000034068609`, 3.4572614661443013`}, {
            7.360436669947441, 6.316731016557851}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{10.049000034068609`, 3.4572614661443013`}, {
            3.399186938124422, 8.083980388508804}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{7.360436669947441, 
            6.316731016557851}, {-5.5, -7.361215932167728}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{7.360436669947441, 
            6.316731016557851}, {-1.1498130959441881`, -8.453436110630323}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{3.399186938124422, 
            8.083980388508804}, {-1.1498130959441881`, -8.453436110630323}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{3.399186938124422, 8.083980388508804}, {11., 0.}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-1.1498130959441881`, 8.453436110630323}, {-5.5, 
            7.361215932167728}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-1.1498130959441881`, 
            8.453436110630323}, {-8.899186938124423, 4.996174644486022}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 
                 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, {-1., \
-0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-5.5, 7.361215932167728}, {3.399186938124422, 
            8.083980388508804}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-5.5, 7.361215932167728}, {
            3.399186938124422, -8.083980388508804}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-8.899186938124423, 4.996174644486022}, {
            10.049000034068609`, 3.4572614661443013`}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-8.899186938124423, 4.996174644486022}, {
            3.399186938124422, -8.083980388508804}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-10.759623608071863`, 
            1.767249371950954}, {-10.759623608071863`, -1.767249371950954}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-10.759623608071863`, 
            1.767249371950954}, {-8.899186938124423, -4.996174644486022}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-10.759623608071863`, -1.767249371950954}, \
{-8.899186938124423, 4.996174644486022}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-10.759623608071863`, -1.767249371950954}, {
            7.360436669947441, -6.316731016557851}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-8.899186938124423, -4.996174644486022}, \
{-1.1498130959441881`, 8.453436110630323}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-8.899186938124423, -4.996174644486022}, {
            7.360436669947441, -6.316731016557851}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-5.5, -7.361215932167728}, {-8.899186938124423, \
-4.996174644486022}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-5.5, -7.361215932167728}, {
            10.049000034068609`, -3.4572614661443013`}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-1.1498130959441881`, -8.453436110630323}, \
{-10.759623608071863`, 1.767249371950954}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-1.1498130959441881`, -8.453436110630323}, {
            10.049000034068609`, -3.4572614661443013`}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{3.399186938124422, -8.083980388508804}, {
            7.360436669947441, 6.316731016557851}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{3.399186938124422, -8.083980388508804}, {11., 0.}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{7.360436669947441, -6.316731016557851}, {
            10.049000034068609`, 3.4572614661443013`}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{7.360436669947441, -6.316731016557851}, {-5.5, 
            7.361215932167728}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{
            10.049000034068609`, -3.4572614661443013`}, {-1.1498130959441881`,
             8.453436110630323}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{
            10.049000034068609`, -3.4572614661443013`}, \
{-10.759623608071863`, -1.767249371950954}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{11., 0.}, {-10.759623608071863`, 
            1.767249371950954}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{11., 0.}, {-5.5, -7.361215932167728}}]}}, 
         {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
          0.7]}], {
           DiskBox[{10.049000034068609, 3.4572614661443013}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 0\\nPayoff: 154\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {10.049000034068609, 3.4572614661443013},
            BaseStyle->"Graphics"]}, {
           DiskBox[{7.360436669947441, 6.316731016557851}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 3\\nPayoff: 94\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {7.360436669947441, 6.316731016557851},
            BaseStyle->"Graphics"]}, {
           DiskBox[{3.399186938124422, 8.083980388508804}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 7\\nPayoff: 112\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {3.399186938124422, 8.083980388508804},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-1.1498130959441881, 8.453436110630323}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 1\\nPayoff: 68\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-1.1498130959441881, 8.453436110630323},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-5.5, 7.361215932167728}, 0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 4\\nPayoff: 73\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-5.5, 7.361215932167728},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-8.899186938124423, 4.996174644486022}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 8\\nPayoff: 68\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-8.899186938124423, 4.996174644486022},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-10.759623608071863, 1.767249371950954}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 2\\nPayoff: 136\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-10.759623608071863, 1.767249371950954},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-10.759623608071863, -1.767249371950954}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 5\\nPayoff: 36\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-10.759623608071863, -1.767249371950954},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-8.899186938124423, -4.996174644486022}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 9\\nPayoff: 75\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-8.899186938124423, -4.996174644486022},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-5.5, -7.361215932167728}, 0.09359782207206707], 
           InsetBox[
            PanelBox["\<\"Number: 6\\nPayoff: 196\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-5.5, -7.361215932167728},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-1.1498130959441881, -8.453436110630323}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 10\\nPayoff: 4\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-1.1498130959441881, -8.453436110630323},
            BaseStyle->"Graphics"]}, {
           DiskBox[{3.399186938124422, -8.083980388508804}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 11\\nPayoff: 172\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {3.399186938124422, -8.083980388508804},
            BaseStyle->"Graphics"]}, {
           DiskBox[{7.360436669947441, -6.316731016557851}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 12\\nPayoff: 68\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {7.360436669947441, -6.316731016557851},
            BaseStyle->"Graphics"]}, {
           DiskBox[{10.049000034068609, -3.4572614661443013}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 13\\nPayoff: 52\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {10.049000034068609, -3.4572614661443013},
            BaseStyle->"Graphics"]}, {DiskBox[{11., 0.}, 0.09359782207206707],
            InsetBox[
            PanelBox["\<\"Number: 14\\nPayoff: 113\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {11., 0.},
            BaseStyle->"Graphics"]}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None,
    ImageSize->Large], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 
        14}, {{{1, 2}, {2, 3}, {3, 4}, {4, 5}, {5, 6}, {6, 7}, {7, 8}, {8, 
         9}, {9, 10}, {10, 11}, {11, 12}, {12, 13}, {13, 14}, {14, 15}, {15, 
         1}}, Null}, {EdgeShapeFunction -> {
           GraphElementData["UnfilledArrow", "ArrowSize" -> 0.03]}, ImageSize -> 
         Large, VertexCoordinates -> {{
           11 Cos[Rational[2, 15] Pi], 3.4572614661443013`}, {
           11 Sin[Rational[7, 30] Pi], 6.316731016557851}, {
           Rational[11, 4] (-1 + 5^Rational[1, 2]), 
            8.083980388508804}, {(-11) Sin[Rational[1, 30] Pi], 
            8.453436110630323}, {
            Rational[-11, 2], 7.361215932167728}, {
           Rational[11, 4] (-1 - 5^Rational[1, 2]), 
            4.996174644486022}, {(-11) Cos[Rational[1, 15] Pi], 
            1.767249371950954}, {(-11) 
            Cos[Rational[1, 15] Pi], -1.767249371950954}, {
           Rational[11, 4] (-1 - 5^Rational[1, 2]), -4.996174644486022}, {
            Rational[-11, 2], -7.361215932167728}, {(-11) 
            Sin[Rational[1, 30] Pi], -8.453436110630323}, {
           Rational[11, 4] (-1 + 5^Rational[1, 2]), -8.083980388508804}, {
           11 Sin[Rational[7, 30] Pi], -6.316731016557851}, {
           11 Cos[Rational[2, 15] Pi], -3.4572614661443013`}, {11, 0.}}, 
         VertexLabels -> {
          6 -> Placed[
            "Number: 6\nPayoff: 196", Center, $CellContext`panelLabel], 3 -> 
           Placed["Number: 3\nPayoff: 94", Center, $CellContext`panelLabel], 
           11 -> Placed[
            "Number: 11\nPayoff: 172", Center, $CellContext`panelLabel], 5 -> 
           Placed["Number: 5\nPayoff: 36", Center, $CellContext`panelLabel], 
           8 -> Placed[
            "Number: 8\nPayoff: 68", Center, $CellContext`panelLabel], 7 -> 
           Placed["Number: 7\nPayoff: 112", Center, $CellContext`panelLabel], 
           14 -> Placed[
            "Number: 14\nPayoff: 113", Center, $CellContext`panelLabel], 10 -> 
           Placed["Number: 10\nPayoff: 4", Center, $CellContext`panelLabel], 
           9 -> Placed[
            "Number: 9\nPayoff: 75", Center, $CellContext`panelLabel], 4 -> 
           Placed["Number: 4\nPayoff: 73", Center, $CellContext`panelLabel], 
           12 -> Placed[
            "Number: 12\nPayoff: 68", Center, $CellContext`panelLabel], 13 -> 
           Placed["Number: 13\nPayoff: 52", Center, $CellContext`panelLabel], 
           2 -> Placed[
            "Number: 2\nPayoff: 136", Center, $CellContext`panelLabel], 1 -> 
           Placed["Number: 1\nPayoff: 68", Center, $CellContext`panelLabel], 
           0 -> 
           Placed["Number: 0\nPayoff: 154", 
             Center, $CellContext`panelLabel]}}]]}, 
      TagBox[GraphicsGroupBox[{
         {Hue[0.6, 0.7, 0.5], Opacity[0.7], 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{10.049000034068609`, 3.4572614661443013`}, {
            7.360436669947441, 6.316731016557851}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{7.360436669947441, 6.316731016557851}, {
            3.399186938124422, 8.083980388508804}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{3.399186938124422, 
            8.083980388508804}, {-1.1498130959441881`, 
            8.453436110630323}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-1.1498130959441881`, 8.453436110630323}, {-5.5, 
            7.361215932167728}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-5.5, 7.361215932167728}, {-8.899186938124423, 
            4.996174644486022}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-8.899186938124423, 
            4.996174644486022}, {-10.759623608071863`, 
            1.767249371950954}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-10.759623608071863`, 
            1.767249371950954}, {-10.759623608071863`, -1.767249371950954}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           
           ArrowBox[{{-10.759623608071863`, -1.767249371950954}, \
{-8.899186938124423, -4.996174644486022}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-8.899186938124423, -4.996174644486022}, {-5.5, \
-7.361215932167728}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-5.5, -7.361215932167728}, {-1.1498130959441881`, \
-8.453436110630323}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-1.1498130959441881`, -8.453436110630323}, {
            3.399186938124422, -8.083980388508804}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{3.399186938124422, -8.083980388508804}, {
            7.360436669947441, -6.316731016557851}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{7.360436669947441, -6.316731016557851}, {
            10.049000034068609`, -3.4572614661443013`}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{10.049000034068609`, -3.4572614661443013`}, {11., 
            0.}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{11., 0.}, {10.049000034068609`, 
            3.4572614661443013`}}]}}, 
         {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
          0.7]}], {
           DiskBox[{10.049000034068609, 3.4572614661443013}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 0\\nPayoff: 154\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {10.049000034068609, 3.4572614661443013},
            BaseStyle->"Graphics"]}, {
           DiskBox[{7.360436669947441, 6.316731016557851}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 1\\nPayoff: 68\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {7.360436669947441, 6.316731016557851},
            BaseStyle->"Graphics"]}, {
           DiskBox[{3.399186938124422, 8.083980388508804}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 2\\nPayoff: 136\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {3.399186938124422, 8.083980388508804},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-1.1498130959441881, 8.453436110630323}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 3\\nPayoff: 94\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-1.1498130959441881, 8.453436110630323},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-5.5, 7.361215932167728}, 0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 4\\nPayoff: 73\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-5.5, 7.361215932167728},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-8.899186938124423, 4.996174644486022}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 5\\nPayoff: 36\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-8.899186938124423, 4.996174644486022},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-10.759623608071863, 1.767249371950954}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 6\\nPayoff: 196\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-10.759623608071863, 1.767249371950954},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-10.759623608071863, -1.767249371950954}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 7\\nPayoff: 112\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-10.759623608071863, -1.767249371950954},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-8.899186938124423, -4.996174644486022}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 8\\nPayoff: 68\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-8.899186938124423, -4.996174644486022},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-5.5, -7.361215932167728}, 0.09359782207206707], 
           InsetBox[
            PanelBox["\<\"Number: 9\\nPayoff: 75\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-5.5, -7.361215932167728},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-1.1498130959441881, -8.453436110630323}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 10\\nPayoff: 4\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-1.1498130959441881, -8.453436110630323},
            BaseStyle->"Graphics"]}, {
           DiskBox[{3.399186938124422, -8.083980388508804}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 11\\nPayoff: 172\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {3.399186938124422, -8.083980388508804},
            BaseStyle->"Graphics"]}, {
           DiskBox[{7.360436669947441, -6.316731016557851}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 12\\nPayoff: 68\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {7.360436669947441, -6.316731016557851},
            BaseStyle->"Graphics"]}, {
           DiskBox[{10.049000034068609, -3.4572614661443013}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 13\\nPayoff: 52\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {10.049000034068609, -3.4572614661443013},
            BaseStyle->"Graphics"]}, {DiskBox[{11., 0.}, 0.09359782207206707],
            InsetBox[
            PanelBox["\<\"Number: 14\\nPayoff: 113\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {11., 0.},
            BaseStyle->"Graphics"]}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None,
    ImageSize->Large], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{0, 3, 9, 1, 4, 10, 2, 5, 11, 6, 12, 7, 13, 8, 
        14}, {{{1, 2}, {1, 3}, {4, 5}, {4, 6}, {7, 8}, {7, 9}, {2, 10}, {2, 
         11}, {5, 12}, {5, 13}, {8, 14}, {8, 15}, {10, 1}, {10, 3}, {12, 4}, {
         12, 6}, {14, 7}, {14, 9}, {3, 2}, {3, 11}, {6, 5}, {6, 13}, {9, 8}, {
         9, 15}, {11, 1}, {11, 10}, {13, 4}, {13, 12}, {15, 7}, {15, 14}}, 
         Null}, {EdgeShapeFunction -> {
           GraphElementData["UnfilledArrow", "ArrowSize" -> 0.03]}, ImageSize -> 
         Large, VertexCoordinates -> {{
           11 Cos[Rational[2, 15] Pi], 3.4572614661443013`}, {
           11 Sin[Rational[7, 30] Pi], 6.316731016557851}, {
           Rational[11, 4] (-1 + 5^Rational[1, 2]), 
            8.083980388508804}, {(-11) Sin[Rational[1, 30] Pi], 
            8.453436110630323}, {
            Rational[-11, 2], 7.361215932167728}, {
           Rational[11, 4] (-1 - 5^Rational[1, 2]), 
            4.996174644486022}, {(-11) Cos[Rational[1, 15] Pi], 
            1.767249371950954}, {(-11) 
            Cos[Rational[1, 15] Pi], -1.767249371950954}, {
           Rational[11, 4] (-1 - 5^Rational[1, 2]), -4.996174644486022}, {
            Rational[-11, 2], -7.361215932167728}, {(-11) 
            Sin[Rational[1, 30] Pi], -8.453436110630323}, {
           Rational[11, 4] (-1 + 5^Rational[1, 2]), -8.083980388508804}, {
           11 Sin[Rational[7, 30] Pi], -6.316731016557851}, {
           11 Cos[Rational[2, 15] Pi], -3.4572614661443013`}, {11, 0.}}, 
         VertexLabels -> {
          6 -> Placed[
            "Number: 6\nPayoff: 196", Center, $CellContext`panelLabel], 3 -> 
           Placed["Number: 3\nPayoff: 94", Center, $CellContext`panelLabel], 
           11 -> Placed[
            "Number: 11\nPayoff: 172", Center, $CellContext`panelLabel], 5 -> 
           Placed["Number: 5\nPayoff: 36", Center, $CellContext`panelLabel], 
           8 -> Placed[
            "Number: 8\nPayoff: 68", Center, $CellContext`panelLabel], 7 -> 
           Placed["Number: 7\nPayoff: 112", Center, $CellContext`panelLabel], 
           14 -> Placed[
            "Number: 14\nPayoff: 113", Center, $CellContext`panelLabel], 10 -> 
           Placed["Number: 10\nPayoff: 4", Center, $CellContext`panelLabel], 
           9 -> Placed[
            "Number: 9\nPayoff: 75", Center, $CellContext`panelLabel], 4 -> 
           Placed["Number: 4\nPayoff: 73", Center, $CellContext`panelLabel], 
           12 -> Placed[
            "Number: 12\nPayoff: 68", Center, $CellContext`panelLabel], 13 -> 
           Placed["Number: 13\nPayoff: 52", Center, $CellContext`panelLabel], 
           2 -> Placed[
            "Number: 2\nPayoff: 136", Center, $CellContext`panelLabel], 1 -> 
           Placed["Number: 1\nPayoff: 68", Center, $CellContext`panelLabel], 
           0 -> Placed[
            "Number: 0\nPayoff: 154", Center, $CellContext`panelLabel]}}]]}, 
      TagBox[GraphicsGroupBox[{
         {Hue[0.6, 0.7, 0.5], Opacity[0.7], 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{10.049000034068609`, 3.4572614661443013`}, {
            7.360436669947441, 6.316731016557851}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{10.049000034068609`, 3.4572614661443013`}, {
            3.399186938124422, 8.083980388508804}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{7.360436669947441, 
            6.316731016557851}, {-5.5, -7.361215932167728}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{7.360436669947441, 
            6.316731016557851}, {-1.1498130959441881`, -8.453436110630323}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{3.399186938124422, 8.083980388508804}, {
            7.360436669947441, 6.316731016557851}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{3.399186938124422, 
            8.083980388508804}, {-1.1498130959441881`, -8.453436110630323}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-1.1498130959441881`, 8.453436110630323}, {-5.5, 
            7.361215932167728}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-1.1498130959441881`, 
            8.453436110630323}, {-8.899186938124423, 4.996174644486022}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-5.5, 7.361215932167728}, {
            3.399186938124422, -8.083980388508804}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-5.5, 7.361215932167728}, {
            7.360436669947441, -6.316731016557851}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-8.899186938124423, 4.996174644486022}, {-5.5, 
            7.361215932167728}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-8.899186938124423, 4.996174644486022}, {
            7.360436669947441, -6.316731016557851}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-10.759623608071863`, 
            1.767249371950954}, {-10.759623608071863`, -1.767249371950954}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-10.759623608071863`, 
            1.767249371950954}, {-8.899186938124423, -4.996174644486022}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-10.759623608071863`, -1.767249371950954}, {
            10.049000034068609`, -3.4572614661443013`}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-10.759623608071863`, -1.767249371950954}, {11., 0.}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-8.899186938124423, -4.996174644486022}, \
{-10.759623608071863`, -1.767249371950954}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-8.899186938124423, -4.996174644486022}, {11., 0.}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-5.5, -7.361215932167728}, {10.049000034068609`, 
            3.4572614661443013`}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-5.5, -7.361215932167728}, {3.399186938124422, 
            8.083980388508804}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-1.1498130959441881`, -8.453436110630323}, {
            10.049000034068609`, 3.4572614661443013`}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-1.1498130959441881`, -8.453436110630323}, {-5.5, \
-7.361215932167728}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{
            3.399186938124422, -8.083980388508804}, {-1.1498130959441881`, 
            8.453436110630323}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{
            3.399186938124422, -8.083980388508804}, {-8.899186938124423, 
            4.996174644486022}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{
            7.360436669947441, -6.316731016557851}, {-1.1498130959441881`, 
            8.453436110630323}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{7.360436669947441, -6.316731016557851}, {
            3.399186938124422, -8.083980388508804}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{
            10.049000034068609`, -3.4572614661443013`}, {-10.759623608071863`,
             1.767249371950954}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{
            10.049000034068609`, -3.4572614661443013`}, {-8.899186938124423, \
-4.996174644486022}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{11., 0.}, {-10.759623608071863`, 
            1.767249371950954}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{11., 0.}, {
            10.049000034068609`, -3.4572614661443013`}}]}}, 
         {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
          0.7]}], {
           DiskBox[{10.049000034068609, 3.4572614661443013}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 0\\nPayoff: 154\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {10.049000034068609, 3.4572614661443013},
            BaseStyle->"Graphics"]}, {
           DiskBox[{7.360436669947441, 6.316731016557851}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 3\\nPayoff: 94\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {7.360436669947441, 6.316731016557851},
            BaseStyle->"Graphics"]}, {
           DiskBox[{3.399186938124422, 8.083980388508804}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 9\\nPayoff: 75\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {3.399186938124422, 8.083980388508804},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-1.1498130959441881, 8.453436110630323}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 1\\nPayoff: 68\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-1.1498130959441881, 8.453436110630323},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-5.5, 7.361215932167728}, 0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 4\\nPayoff: 73\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-5.5, 7.361215932167728},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-8.899186938124423, 4.996174644486022}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 10\\nPayoff: 4\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-8.899186938124423, 4.996174644486022},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-10.759623608071863, 1.767249371950954}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 2\\nPayoff: 136\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-10.759623608071863, 1.767249371950954},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-10.759623608071863, -1.767249371950954}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 5\\nPayoff: 36\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-10.759623608071863, -1.767249371950954},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-8.899186938124423, -4.996174644486022}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 11\\nPayoff: 172\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-8.899186938124423, -4.996174644486022},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-5.5, -7.361215932167728}, 0.09359782207206707], 
           InsetBox[
            PanelBox["\<\"Number: 6\\nPayoff: 196\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-5.5, -7.361215932167728},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-1.1498130959441881, -8.453436110630323}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 12\\nPayoff: 68\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-1.1498130959441881, -8.453436110630323},
            BaseStyle->"Graphics"]}, {
           DiskBox[{3.399186938124422, -8.083980388508804}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 7\\nPayoff: 112\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {3.399186938124422, -8.083980388508804},
            BaseStyle->"Graphics"]}, {
           DiskBox[{7.360436669947441, -6.316731016557851}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 13\\nPayoff: 52\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {7.360436669947441, -6.316731016557851},
            BaseStyle->"Graphics"]}, {
           DiskBox[{10.049000034068609, -3.4572614661443013}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 8\\nPayoff: 68\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {10.049000034068609, -3.4572614661443013},
            BaseStyle->"Graphics"]}, {DiskBox[{11., 0.}, 0.09359782207206707],
            InsetBox[
            PanelBox["\<\"Number: 14\\nPayoff: 113\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {11., 0.},
            BaseStyle->"Graphics"]}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None,
    ImageSize->Large], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{0, 7, 9, 1, 8, 10, 2, 11, 3, 12, 4, 13, 5, 14, 
        6}, {{{1, 2}, {1, 3}, {4, 5}, {4, 6}, {7, 3}, {7, 8}, {9, 6}, {9, 
         10}, {11, 8}, {11, 12}, {13, 10}, {13, 14}, {15, 1}, {15, 12}, {2, 
         4}, {2, 14}, {5, 1}, {5, 7}, {3, 4}, {3, 9}, {6, 7}, {6, 11}, {8, 
         9}, {8, 13}, {10, 11}, {10, 15}, {12, 13}, {12, 2}, {14, 15}, {14, 
         5}}, Null}, {EdgeShapeFunction -> {
           GraphElementData["UnfilledArrow", "ArrowSize" -> 0.03]}, ImageSize -> 
         Large, VertexCoordinates -> {{
           11 Cos[Rational[2, 15] Pi], 3.4572614661443013`}, {
           11 Sin[Rational[7, 30] Pi], 6.316731016557851}, {
           Rational[11, 4] (-1 + 5^Rational[1, 2]), 
            8.083980388508804}, {(-11) Sin[Rational[1, 30] Pi], 
            8.453436110630323}, {
            Rational[-11, 2], 7.361215932167728}, {
           Rational[11, 4] (-1 - 5^Rational[1, 2]), 
            4.996174644486022}, {(-11) Cos[Rational[1, 15] Pi], 
            1.767249371950954}, {(-11) 
            Cos[Rational[1, 15] Pi], -1.767249371950954}, {
           Rational[11, 4] (-1 - 5^Rational[1, 2]), -4.996174644486022}, {
            Rational[-11, 2], -7.361215932167728}, {(-11) 
            Sin[Rational[1, 30] Pi], -8.453436110630323}, {
           Rational[11, 4] (-1 + 5^Rational[1, 2]), -8.083980388508804}, {
           11 Sin[Rational[7, 30] Pi], -6.316731016557851}, {
           11 Cos[Rational[2, 15] Pi], -3.4572614661443013`}, {11, 0.}}, 
         VertexLabels -> {
          6 -> Placed[
            "Number: 6\nPayoff: 196", Center, $CellContext`panelLabel], 3 -> 
           Placed["Number: 3\nPayoff: 94", Center, $CellContext`panelLabel], 
           11 -> Placed[
            "Number: 11\nPayoff: 172", Center, $CellContext`panelLabel], 5 -> 
           Placed["Number: 5\nPayoff: 36", Center, $CellContext`panelLabel], 
           8 -> Placed[
            "Number: 8\nPayoff: 68", Center, $CellContext`panelLabel], 7 -> 
           Placed["Number: 7\nPayoff: 112", Center, $CellContext`panelLabel], 
           14 -> Placed[
            "Number: 14\nPayoff: 113", Center, $CellContext`panelLabel], 10 -> 
           Placed["Number: 10\nPayoff: 4", Center, $CellContext`panelLabel], 
           9 -> Placed[
            "Number: 9\nPayoff: 75", Center, $CellContext`panelLabel], 4 -> 
           Placed["Number: 4\nPayoff: 73", Center, $CellContext`panelLabel], 
           12 -> Placed[
            "Number: 12\nPayoff: 68", Center, $CellContext`panelLabel], 13 -> 
           Placed["Number: 13\nPayoff: 52", Center, $CellContext`panelLabel], 
           2 -> Placed[
            "Number: 2\nPayoff: 136", Center, $CellContext`panelLabel], 1 -> 
           Placed["Number: 1\nPayoff: 68", Center, $CellContext`panelLabel], 
           0 -> Placed[
            "Number: 0\nPayoff: 154", Center, $CellContext`panelLabel]}}]]}, 
      TagBox[GraphicsGroupBox[{
         {Hue[0.6, 0.7, 0.5], Opacity[0.7], 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{10.049000034068609`, 3.4572614661443013`}, {
            7.360436669947441, 6.316731016557851}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{10.049000034068609`, 3.4572614661443013`}, {
            3.399186938124422, 8.083980388508804}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{7.360436669947441, 
            6.316731016557851}, {-1.1498130959441881`, 
            8.453436110630323}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{7.360436669947441, 6.316731016557851}, {
            10.049000034068609`, -3.4572614661443013`}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{3.399186938124422, 
            8.083980388508804}, {-1.1498130959441881`, 
            8.453436110630323}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{3.399186938124422, 
            8.083980388508804}, {-8.899186938124423, -4.996174644486022}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-1.1498130959441881`, 8.453436110630323}, {-5.5, 
            7.361215932167728}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-1.1498130959441881`, 
            8.453436110630323}, {-8.899186938124423, 4.996174644486022}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-5.5, 7.361215932167728}, {10.049000034068609`, 
            3.4572614661443013`}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-5.5, 7.361215932167728}, {-10.759623608071863`, 
            1.767249371950954}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-8.899186938124423, 
            4.996174644486022}, {-10.759623608071863`, 
            1.767249371950954}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-8.899186938124423, 
            4.996174644486022}, {-1.1498130959441881`, -8.453436110630323}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-10.759623608071863`, 1.767249371950954}, {
            3.399186938124422, 8.083980388508804}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-10.759623608071863`, 
            1.767249371950954}, {-10.759623608071863`, -1.767249371950954}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-10.759623608071863`, -1.767249371950954}, \
{-8.899186938124423, -4.996174644486022}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-10.759623608071863`, -1.767249371950954}, {
            7.360436669947441, -6.316731016557851}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-8.899186938124423, -4.996174644486022}, \
{-8.899186938124423, 4.996174644486022}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-8.899186938124423, -4.996174644486022}, {-5.5, \
-7.361215932167728}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-5.5, -7.361215932167728}, {-1.1498130959441881`, \
-8.453436110630323}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-5.5, -7.361215932167728}, {11., 0.}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-1.1498130959441881`, -8.453436110630323}, \
{-10.759623608071863`, -1.767249371950954}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-1.1498130959441881`, -8.453436110630323}, {
            3.399186938124422, -8.083980388508804}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{3.399186938124422, -8.083980388508804}, {
            7.360436669947441, 6.316731016557851}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{3.399186938124422, -8.083980388508804}, {
            7.360436669947441, -6.316731016557851}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{
            7.360436669947441, -6.316731016557851}, {-5.5, \
-7.361215932167728}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 
                 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, {-1., \
-0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{7.360436669947441, -6.316731016557851}, {
            10.049000034068609`, -3.4572614661443013`}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{10.049000034068609`, -3.4572614661443013`}, {-5.5, 
            7.361215932167728}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{10.049000034068609`, -3.4572614661443013`}, {11., 
            0.}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{11., 0.}, {10.049000034068609`, 3.4572614661443013`}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{11., 0.}, {3.399186938124422, -8.083980388508804}}]}}, 
         {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
          0.7]}], {
           DiskBox[{10.049000034068609, 3.4572614661443013}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 0\\nPayoff: 154\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {10.049000034068609, 3.4572614661443013},
            BaseStyle->"Graphics"]}, {
           DiskBox[{7.360436669947441, 6.316731016557851}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 7\\nPayoff: 112\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {7.360436669947441, 6.316731016557851},
            BaseStyle->"Graphics"]}, {
           DiskBox[{3.399186938124422, 8.083980388508804}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 9\\nPayoff: 75\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {3.399186938124422, 8.083980388508804},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-1.1498130959441881, 8.453436110630323}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 1\\nPayoff: 68\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-1.1498130959441881, 8.453436110630323},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-5.5, 7.361215932167728}, 0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 8\\nPayoff: 68\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-5.5, 7.361215932167728},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-8.899186938124423, 4.996174644486022}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 10\\nPayoff: 4\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-8.899186938124423, 4.996174644486022},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-10.759623608071863, 1.767249371950954}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 2\\nPayoff: 136\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-10.759623608071863, 1.767249371950954},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-10.759623608071863, -1.767249371950954}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 11\\nPayoff: 172\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-10.759623608071863, -1.767249371950954},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-8.899186938124423, -4.996174644486022}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 3\\nPayoff: 94\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-8.899186938124423, -4.996174644486022},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-5.5, -7.361215932167728}, 0.09359782207206707], 
           InsetBox[
            PanelBox["\<\"Number: 12\\nPayoff: 68\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-5.5, -7.361215932167728},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-1.1498130959441881, -8.453436110630323}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 4\\nPayoff: 73\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-1.1498130959441881, -8.453436110630323},
            BaseStyle->"Graphics"]}, {
           DiskBox[{3.399186938124422, -8.083980388508804}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 13\\nPayoff: 52\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {3.399186938124422, -8.083980388508804},
            BaseStyle->"Graphics"]}, {
           DiskBox[{7.360436669947441, -6.316731016557851}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 5\\nPayoff: 36\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {7.360436669947441, -6.316731016557851},
            BaseStyle->"Graphics"]}, {
           DiskBox[{10.049000034068609, -3.4572614661443013}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 14\\nPayoff: 113\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {10.049000034068609, -3.4572614661443013},
            BaseStyle->"Graphics"]}, {DiskBox[{11., 0.}, 0.09359782207206707],
            InsetBox[
            PanelBox["\<\"Number: 6\\nPayoff: 196\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {11., 0.},
            BaseStyle->"Graphics"]}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None,
    ImageSize->Large], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{0, 4, 8, 1, 5, 9, 2, 6, 10, 3, 7, 11, 12, 13, 
        14}, {{{1, 2}, {1, 3}, {4, 5}, {4, 6}, {7, 8}, {7, 9}, {10, 11}, {10, 
         12}, {2, 3}, {2, 13}, {5, 6}, {5, 14}, {8, 9}, {8, 15}, {11, 1}, {11,
          12}, {3, 4}, {3, 13}, {6, 7}, {6, 14}, {9, 10}, {9, 15}, {12, 1}, {
         12, 2}, {13, 4}, {13, 5}, {14, 7}, {14, 8}, {15, 10}, {15, 11}}, 
         Null}, {EdgeShapeFunction -> {
           GraphElementData["UnfilledArrow", "ArrowSize" -> 0.03]}, ImageSize -> 
         Large, VertexCoordinates -> {{
           11 Cos[Rational[2, 15] Pi], 3.4572614661443013`}, {
           11 Sin[Rational[7, 30] Pi], 6.316731016557851}, {
           Rational[11, 4] (-1 + 5^Rational[1, 2]), 
            8.083980388508804}, {(-11) Sin[Rational[1, 30] Pi], 
            8.453436110630323}, {
            Rational[-11, 2], 7.361215932167728}, {
           Rational[11, 4] (-1 - 5^Rational[1, 2]), 
            4.996174644486022}, {(-11) Cos[Rational[1, 15] Pi], 
            1.767249371950954}, {(-11) 
            Cos[Rational[1, 15] Pi], -1.767249371950954}, {
           Rational[11, 4] (-1 - 5^Rational[1, 2]), -4.996174644486022}, {
            Rational[-11, 2], -7.361215932167728}, {(-11) 
            Sin[Rational[1, 30] Pi], -8.453436110630323}, {
           Rational[11, 4] (-1 + 5^Rational[1, 2]), -8.083980388508804}, {
           11 Sin[Rational[7, 30] Pi], -6.316731016557851}, {
           11 Cos[Rational[2, 15] Pi], -3.4572614661443013`}, {11, 0.}}, 
         VertexLabels -> {
          6 -> Placed[
            "Number: 6\nPayoff: 196", Center, $CellContext`panelLabel], 3 -> 
           Placed["Number: 3\nPayoff: 94", Center, $CellContext`panelLabel], 
           11 -> Placed[
            "Number: 11\nPayoff: 172", Center, $CellContext`panelLabel], 5 -> 
           Placed["Number: 5\nPayoff: 36", Center, $CellContext`panelLabel], 
           8 -> Placed[
            "Number: 8\nPayoff: 68", Center, $CellContext`panelLabel], 7 -> 
           Placed["Number: 7\nPayoff: 112", Center, $CellContext`panelLabel], 
           14 -> Placed[
            "Number: 14\nPayoff: 113", Center, $CellContext`panelLabel], 10 -> 
           Placed["Number: 10\nPayoff: 4", Center, $CellContext`panelLabel], 
           9 -> Placed[
            "Number: 9\nPayoff: 75", Center, $CellContext`panelLabel], 4 -> 
           Placed["Number: 4\nPayoff: 73", Center, $CellContext`panelLabel], 
           12 -> Placed[
            "Number: 12\nPayoff: 68", Center, $CellContext`panelLabel], 13 -> 
           Placed["Number: 13\nPayoff: 52", Center, $CellContext`panelLabel], 
           2 -> Placed[
            "Number: 2\nPayoff: 136", Center, $CellContext`panelLabel], 1 -> 
           Placed["Number: 1\nPayoff: 68", Center, $CellContext`panelLabel], 
           0 -> Placed[
            "Number: 0\nPayoff: 154", Center, $CellContext`panelLabel]}}]]}, 
      TagBox[GraphicsGroupBox[{
         {Hue[0.6, 0.7, 0.5], Opacity[0.7], 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{10.049000034068609`, 3.4572614661443013`}, {
            7.360436669947441, 6.316731016557851}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{10.049000034068609`, 3.4572614661443013`}, {
            3.399186938124422, 8.083980388508804}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{7.360436669947441, 6.316731016557851}, {
            3.399186938124422, 8.083980388508804}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{7.360436669947441, 6.316731016557851}, {
            7.360436669947441, -6.316731016557851}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{3.399186938124422, 
            8.083980388508804}, {-1.1498130959441881`, 
            8.453436110630323}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{3.399186938124422, 8.083980388508804}, {
            7.360436669947441, -6.316731016557851}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-1.1498130959441881`, 8.453436110630323}, {-5.5, 
            7.361215932167728}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-1.1498130959441881`, 
            8.453436110630323}, {-8.899186938124423, 4.996174644486022}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-5.5, 7.361215932167728}, {-8.899186938124423, 
            4.996174644486022}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-5.5, 7.361215932167728}, {
            10.049000034068609`, -3.4572614661443013`}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-8.899186938124423, 
            4.996174644486022}, {-10.759623608071863`, 
            1.767249371950954}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-8.899186938124423, 4.996174644486022}, {
            10.049000034068609`, -3.4572614661443013`}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 
                 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, {-1., \
-0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-10.759623608071863`, 
            1.767249371950954}, {-10.759623608071863`, -1.767249371950954}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-10.759623608071863`, 
            1.767249371950954}, {-8.899186938124423, -4.996174644486022}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-10.759623608071863`, -1.767249371950954}, \
{-8.899186938124423, -4.996174644486022}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-10.759623608071863`, -1.767249371950954}, {11., 0.}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-8.899186938124423, -4.996174644486022}, {-5.5, \
-7.361215932167728}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-8.899186938124423, -4.996174644486022}, {11., 0.}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-5.5, -7.361215932167728}, {-1.1498130959441881`, \
-8.453436110630323}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-5.5, -7.361215932167728}, {
            3.399186938124422, -8.083980388508804}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-1.1498130959441881`, -8.453436110630323}, {
            10.049000034068609`, 3.4572614661443013`}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-1.1498130959441881`, -8.453436110630323}, {
            3.399186938124422, -8.083980388508804}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{3.399186938124422, -8.083980388508804}, {
            10.049000034068609`, 3.4572614661443013`}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{3.399186938124422, -8.083980388508804}, {
            7.360436669947441, 6.316731016557851}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{
            7.360436669947441, -6.316731016557851}, {-1.1498130959441881`, 
            8.453436110630323}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{7.360436669947441, -6.316731016557851}, {-5.5, 
            7.361215932167728}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{
            10.049000034068609`, -3.4572614661443013`}, {-10.759623608071863`,
             1.767249371950954}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{
            10.049000034068609`, -3.4572614661443013`}, \
{-10.759623608071863`, -1.767249371950954}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{11., 0.}, {-5.5, -7.361215932167728}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{11., 
            0.}, {-1.1498130959441881`, -8.453436110630323}}]}}, 
         {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
          0.7]}], {
           DiskBox[{10.049000034068609, 3.4572614661443013}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 0\\nPayoff: 154\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {10.049000034068609, 3.4572614661443013},
            BaseStyle->"Graphics"]}, {
           DiskBox[{7.360436669947441, 6.316731016557851}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 4\\nPayoff: 73\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {7.360436669947441, 6.316731016557851},
            BaseStyle->"Graphics"]}, {
           DiskBox[{3.399186938124422, 8.083980388508804}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 8\\nPayoff: 68\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {3.399186938124422, 8.083980388508804},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-1.1498130959441881, 8.453436110630323}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 1\\nPayoff: 68\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-1.1498130959441881, 8.453436110630323},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-5.5, 7.361215932167728}, 0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 5\\nPayoff: 36\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-5.5, 7.361215932167728},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-8.899186938124423, 4.996174644486022}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 9\\nPayoff: 75\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-8.899186938124423, 4.996174644486022},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-10.759623608071863, 1.767249371950954}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 2\\nPayoff: 136\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-10.759623608071863, 1.767249371950954},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-10.759623608071863, -1.767249371950954}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 6\\nPayoff: 196\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-10.759623608071863, -1.767249371950954},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-8.899186938124423, -4.996174644486022}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 10\\nPayoff: 4\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-8.899186938124423, -4.996174644486022},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-5.5, -7.361215932167728}, 0.09359782207206707], 
           InsetBox[
            PanelBox["\<\"Number: 3\\nPayoff: 94\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-5.5, -7.361215932167728},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-1.1498130959441881, -8.453436110630323}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 7\\nPayoff: 112\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-1.1498130959441881, -8.453436110630323},
            BaseStyle->"Graphics"]}, {
           DiskBox[{3.399186938124422, -8.083980388508804}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 11\\nPayoff: 172\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {3.399186938124422, -8.083980388508804},
            BaseStyle->"Graphics"]}, {
           DiskBox[{7.360436669947441, -6.316731016557851}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 12\\nPayoff: 68\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {7.360436669947441, -6.316731016557851},
            BaseStyle->"Graphics"]}, {
           DiskBox[{10.049000034068609, -3.4572614661443013}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 13\\nPayoff: 52\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {10.049000034068609, -3.4572614661443013},
            BaseStyle->"Graphics"]}, {DiskBox[{11., 0.}, 0.09359782207206707],
            InsetBox[
            PanelBox["\<\"Number: 14\\nPayoff: 113\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {11., 0.},
            BaseStyle->"Graphics"]}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None,
    ImageSize->Large], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{0, 3, 4, 1, 5, 2, 6, 7, 8, 9, 10, 11, 12, 13, 
        14}, {{{1, 2}, {1, 3}, {4, 3}, {4, 5}, {6, 5}, {6, 7}, {2, 7}, {2, 
         8}, {3, 8}, {3, 9}, {5, 9}, {5, 10}, {7, 10}, {7, 11}, {8, 11}, {8, 
         12}, {9, 12}, {9, 13}, {10, 13}, {10, 14}, {11, 14}, {11, 15}, {12, 
         1}, {12, 15}, {13, 1}, {13, 4}, {14, 4}, {14, 6}, {15, 6}, {15, 2}}, 
         Null}, {EdgeShapeFunction -> {
           GraphElementData["UnfilledArrow", "ArrowSize" -> 0.03]}, ImageSize -> 
         Large, VertexCoordinates -> {{
           11 Cos[Rational[2, 15] Pi], 3.4572614661443013`}, {
           11 Sin[Rational[7, 30] Pi], 6.316731016557851}, {
           Rational[11, 4] (-1 + 5^Rational[1, 2]), 
            8.083980388508804}, {(-11) Sin[Rational[1, 30] Pi], 
            8.453436110630323}, {
            Rational[-11, 2], 7.361215932167728}, {
           Rational[11, 4] (-1 - 5^Rational[1, 2]), 
            4.996174644486022}, {(-11) Cos[Rational[1, 15] Pi], 
            1.767249371950954}, {(-11) 
            Cos[Rational[1, 15] Pi], -1.767249371950954}, {
           Rational[11, 4] (-1 - 5^Rational[1, 2]), -4.996174644486022}, {
            Rational[-11, 2], -7.361215932167728}, {(-11) 
            Sin[Rational[1, 30] Pi], -8.453436110630323}, {
           Rational[11, 4] (-1 + 5^Rational[1, 2]), -8.083980388508804}, {
           11 Sin[Rational[7, 30] Pi], -6.316731016557851}, {
           11 Cos[Rational[2, 15] Pi], -3.4572614661443013`}, {11, 0.}}, 
         VertexLabels -> {
          6 -> Placed[
            "Number: 6\nPayoff: 196", Center, $CellContext`panelLabel], 3 -> 
           Placed["Number: 3\nPayoff: 94", Center, $CellContext`panelLabel], 
           11 -> Placed[
            "Number: 11\nPayoff: 172", Center, $CellContext`panelLabel], 5 -> 
           Placed["Number: 5\nPayoff: 36", Center, $CellContext`panelLabel], 
           8 -> Placed[
            "Number: 8\nPayoff: 68", Center, $CellContext`panelLabel], 7 -> 
           Placed["Number: 7\nPayoff: 112", Center, $CellContext`panelLabel], 
           14 -> Placed[
            "Number: 14\nPayoff: 113", Center, $CellContext`panelLabel], 10 -> 
           Placed["Number: 10\nPayoff: 4", Center, $CellContext`panelLabel], 
           9 -> Placed[
            "Number: 9\nPayoff: 75", Center, $CellContext`panelLabel], 4 -> 
           Placed["Number: 4\nPayoff: 73", Center, $CellContext`panelLabel], 
           12 -> Placed[
            "Number: 12\nPayoff: 68", Center, $CellContext`panelLabel], 13 -> 
           Placed["Number: 13\nPayoff: 52", Center, $CellContext`panelLabel], 
           2 -> 
           Placed["Number: 2\nPayoff: 136", Center, $CellContext`panelLabel], 
           1 -> Placed[
            "Number: 1\nPayoff: 68", Center, $CellContext`panelLabel], 0 -> 
           Placed["Number: 0\nPayoff: 154", 
             Center, $CellContext`panelLabel]}}]]}, 
      TagBox[GraphicsGroupBox[{
         {Hue[0.6, 0.7, 0.5], Opacity[0.7], 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{10.049000034068609`, 3.4572614661443013`}, {
            7.360436669947441, 6.316731016557851}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{10.049000034068609`, 3.4572614661443013`}, {
            3.399186938124422, 8.083980388508804}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{7.360436669947441, 
            6.316731016557851}, {-10.759623608071863`, 
            1.767249371950954}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{7.360436669947441, 
            6.316731016557851}, {-10.759623608071863`, -1.767249371950954}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{3.399186938124422, 
            8.083980388508804}, {-10.759623608071863`, -1.767249371950954}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{3.399186938124422, 
            8.083980388508804}, {-8.899186938124423, -4.996174644486022}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-1.1498130959441881`, 8.453436110630323}, {
            3.399186938124422, 8.083980388508804}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-1.1498130959441881`, 8.453436110630323}, {-5.5, 
            7.361215932167728}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-5.5, 
            7.361215932167728}, {-8.899186938124423, -4.996174644486022}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-5.5, 7.361215932167728}, {-5.5, -7.361215932167728}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-8.899186938124423, 4.996174644486022}, {-5.5, 
            7.361215932167728}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-8.899186938124423, 
            4.996174644486022}, {-10.759623608071863`, 
            1.767249371950954}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-10.759623608071863`, 
            1.767249371950954}, {-5.5, -7.361215932167728}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-10.759623608071863`, 
            1.767249371950954}, {-1.1498130959441881`, -8.453436110630323}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-10.759623608071863`, -1.767249371950954}, \
{-1.1498130959441881`, -8.453436110630323}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-10.759623608071863`, -1.767249371950954}, {
            3.399186938124422, -8.083980388508804}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-8.899186938124423, -4.996174644486022}, {
            3.399186938124422, -8.083980388508804}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-8.899186938124423, -4.996174644486022}, {
            7.360436669947441, -6.316731016557851}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-5.5, -7.361215932167728}, {
            7.360436669947441, -6.316731016557851}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-5.5, -7.361215932167728}, {
            10.049000034068609`, -3.4572614661443013`}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-1.1498130959441881`, -8.453436110630323}, {
            10.049000034068609`, -3.4572614661443013`}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-1.1498130959441881`, -8.453436110630323}, {11., 0.}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{3.399186938124422, -8.083980388508804}, {
            10.049000034068609`, 3.4572614661443013`}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{3.399186938124422, -8.083980388508804}, {11., 0.}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{7.360436669947441, -6.316731016557851}, {
            10.049000034068609`, 3.4572614661443013`}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{
            7.360436669947441, -6.316731016557851}, {-1.1498130959441881`, 
            8.453436110630323}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{
            10.049000034068609`, -3.4572614661443013`}, {-1.1498130959441881`,
             8.453436110630323}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{
            10.049000034068609`, -3.4572614661443013`}, {-8.899186938124423, 
            4.996174644486022}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{11., 0.}, {7.360436669947441, 6.316731016557851}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{11., 0.}, {-8.899186938124423, 4.996174644486022}}]}}, 
         {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
          0.7]}], {
           DiskBox[{10.049000034068609, 3.4572614661443013}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 0\\nPayoff: 154\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {10.049000034068609, 3.4572614661443013},
            BaseStyle->"Graphics"]}, {
           DiskBox[{7.360436669947441, 6.316731016557851}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 3\\nPayoff: 94\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {7.360436669947441, 6.316731016557851},
            BaseStyle->"Graphics"]}, {
           DiskBox[{3.399186938124422, 8.083980388508804}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 4\\nPayoff: 73\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {3.399186938124422, 8.083980388508804},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-1.1498130959441881, 8.453436110630323}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 1\\nPayoff: 68\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-1.1498130959441881, 8.453436110630323},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-5.5, 7.361215932167728}, 0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 5\\nPayoff: 36\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-5.5, 7.361215932167728},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-8.899186938124423, 4.996174644486022}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 2\\nPayoff: 136\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-8.899186938124423, 4.996174644486022},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-10.759623608071863, 1.767249371950954}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 6\\nPayoff: 196\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-10.759623608071863, 1.767249371950954},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-10.759623608071863, -1.767249371950954}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 7\\nPayoff: 112\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-10.759623608071863, -1.767249371950954},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-8.899186938124423, -4.996174644486022}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 8\\nPayoff: 68\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-8.899186938124423, -4.996174644486022},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-5.5, -7.361215932167728}, 0.09359782207206707], 
           InsetBox[
            PanelBox["\<\"Number: 9\\nPayoff: 75\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-5.5, -7.361215932167728},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-1.1498130959441881, -8.453436110630323}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 10\\nPayoff: 4\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-1.1498130959441881, -8.453436110630323},
            BaseStyle->"Graphics"]}, {
           DiskBox[{3.399186938124422, -8.083980388508804}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 11\\nPayoff: 172\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {3.399186938124422, -8.083980388508804},
            BaseStyle->"Graphics"]}, {
           DiskBox[{7.360436669947441, -6.316731016557851}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 12\\nPayoff: 68\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {7.360436669947441, -6.316731016557851},
            BaseStyle->"Graphics"]}, {
           DiskBox[{10.049000034068609, -3.4572614661443013}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 13\\nPayoff: 52\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {10.049000034068609, -3.4572614661443013},
            BaseStyle->"Graphics"]}, {DiskBox[{11., 0.}, 0.09359782207206707],
            InsetBox[
            PanelBox["\<\"Number: 14\\nPayoff: 113\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {11., 0.},
            BaseStyle->"Graphics"]}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None,
    ImageSize->Large], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{0, 1, 7, 2, 8, 3, 9, 4, 10, 5, 11, 6, 12, 13, 
        14}, {{{1, 2}, {1, 3}, {2, 4}, {2, 5}, {4, 6}, {4, 7}, {6, 8}, {6, 
         9}, {8, 10}, {8, 11}, {10, 12}, {10, 13}, {12, 3}, {12, 14}, {3, 
         5}, {3, 15}, {5, 1}, {5, 7}, {7, 2}, {7, 9}, {9, 4}, {9, 11}, {11, 
         6}, {11, 13}, {13, 8}, {13, 14}, {14, 10}, {14, 15}, {15, 1}, {15, 
         12}}, Null}, {EdgeShapeFunction -> {
           GraphElementData["UnfilledArrow", "ArrowSize" -> 0.03]}, ImageSize -> 
         Large, VertexCoordinates -> {{
           11 Cos[Rational[2, 15] Pi], 3.4572614661443013`}, {
           11 Sin[Rational[7, 30] Pi], 6.316731016557851}, {
           Rational[11, 4] (-1 + 5^Rational[1, 2]), 
            8.083980388508804}, {(-11) Sin[Rational[1, 30] Pi], 
            8.453436110630323}, {
            Rational[-11, 2], 7.361215932167728}, {
           Rational[11, 4] (-1 - 5^Rational[1, 2]), 
            4.996174644486022}, {(-11) Cos[Rational[1, 15] Pi], 
            1.767249371950954}, {(-11) 
            Cos[Rational[1, 15] Pi], -1.767249371950954}, {
           Rational[11, 4] (-1 - 5^Rational[1, 2]), -4.996174644486022}, {
            Rational[-11, 2], -7.361215932167728}, {(-11) 
            Sin[Rational[1, 30] Pi], -8.453436110630323}, {
           Rational[11, 4] (-1 + 5^Rational[1, 2]), -8.083980388508804}, {
           11 Sin[Rational[7, 30] Pi], -6.316731016557851}, {
           11 Cos[Rational[2, 15] Pi], -3.4572614661443013`}, {11, 0.}}, 
         VertexLabels -> {
          6 -> Placed[
            "Number: 6\nPayoff: 196", Center, $CellContext`panelLabel], 3 -> 
           Placed["Number: 3\nPayoff: 94", Center, $CellContext`panelLabel], 
           11 -> Placed[
            "Number: 11\nPayoff: 172", Center, $CellContext`panelLabel], 5 -> 
           Placed["Number: 5\nPayoff: 36", Center, $CellContext`panelLabel], 
           8 -> Placed[
            "Number: 8\nPayoff: 68", Center, $CellContext`panelLabel], 7 -> 
           Placed["Number: 7\nPayoff: 112", Center, $CellContext`panelLabel], 
           14 -> Placed[
            "Number: 14\nPayoff: 113", Center, $CellContext`panelLabel], 10 -> 
           Placed["Number: 10\nPayoff: 4", Center, $CellContext`panelLabel], 
           9 -> Placed[
            "Number: 9\nPayoff: 75", Center, $CellContext`panelLabel], 4 -> 
           Placed["Number: 4\nPayoff: 73", Center, $CellContext`panelLabel], 
           12 -> Placed[
            "Number: 12\nPayoff: 68", Center, $CellContext`panelLabel], 13 -> 
           Placed["Number: 13\nPayoff: 52", Center, $CellContext`panelLabel], 
           2 -> Placed[
            "Number: 2\nPayoff: 136", Center, $CellContext`panelLabel], 1 -> 
           Placed["Number: 1\nPayoff: 68", Center, $CellContext`panelLabel], 
           0 -> Placed[
            "Number: 0\nPayoff: 154", Center, $CellContext`panelLabel]}}]]}, 
      TagBox[GraphicsGroupBox[{
         {Hue[0.6, 0.7, 0.5], Opacity[0.7], 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{10.049000034068609`, 3.4572614661443013`}, {
            7.360436669947441, 6.316731016557851}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{10.049000034068609`, 3.4572614661443013`}, {
            3.399186938124422, 8.083980388508804}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{7.360436669947441, 
            6.316731016557851}, {-1.1498130959441881`, 
            8.453436110630323}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{7.360436669947441, 6.316731016557851}, {-5.5, 
            7.361215932167728}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{3.399186938124422, 8.083980388508804}, {-5.5, 
            7.361215932167728}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{3.399186938124422, 8.083980388508804}, {11., 0.}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-1.1498130959441881`, 
            8.453436110630323}, {-8.899186938124423, 4.996174644486022}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-1.1498130959441881`, 
            8.453436110630323}, {-10.759623608071863`, 
            1.767249371950954}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-5.5, 7.361215932167728}, {10.049000034068609`, 
            3.4572614661443013`}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-5.5, 7.361215932167728}, {-10.759623608071863`, 
            1.767249371950954}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-8.899186938124423, 
            4.996174644486022}, {-10.759623608071863`, -1.767249371950954}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-8.899186938124423, 
            4.996174644486022}, {-8.899186938124423, -4.996174644486022}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-10.759623608071863`, 1.767249371950954}, {
            7.360436669947441, 6.316731016557851}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-10.759623608071863`, 
            1.767249371950954}, {-8.899186938124423, -4.996174644486022}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           
           ArrowBox[{{-10.759623608071863`, -1.767249371950954}, {-5.5, \
-7.361215932167728}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-10.759623608071863`, -1.767249371950954}, \
{-1.1498130959441881`, -8.453436110630323}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-8.899186938124423, -4.996174644486022}, \
{-1.1498130959441881`, 8.453436110630323}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-8.899186938124423, -4.996174644486022}, \
{-1.1498130959441881`, -8.453436110630323}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-5.5, -7.361215932167728}, {
            3.399186938124422, -8.083980388508804}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-5.5, -7.361215932167728}, {
            7.360436669947441, -6.316731016557851}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-1.1498130959441881`, -8.453436110630323}, \
{-8.899186938124423, 4.996174644486022}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-1.1498130959441881`, -8.453436110630323}, {
            7.360436669947441, -6.316731016557851}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{3.399186938124422, -8.083980388508804}, {
            3.399186938124422, 8.083980388508804}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{3.399186938124422, -8.083980388508804}, {
            10.049000034068609`, -3.4572614661443013`}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{
            7.360436669947441, -6.316731016557851}, {-10.759623608071863`, \
-1.767249371950954}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{7.360436669947441, -6.316731016557851}, {
            10.049000034068609`, -3.4572614661443013`}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{
            10.049000034068609`, -3.4572614661443013`}, {-5.5, \
-7.361215932167728}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{10.049000034068609`, -3.4572614661443013`}, {11., 
            0.}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{11., 0.}, {10.049000034068609`, 3.4572614661443013`}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{11., 0.}, {3.399186938124422, -8.083980388508804}}]}}, 
         {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
          0.7]}], {
           DiskBox[{10.049000034068609, 3.4572614661443013}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 0\\nPayoff: 154\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {10.049000034068609, 3.4572614661443013},
            BaseStyle->"Graphics"]}, {
           DiskBox[{7.360436669947441, 6.316731016557851}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 1\\nPayoff: 68\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {7.360436669947441, 6.316731016557851},
            BaseStyle->"Graphics"]}, {
           DiskBox[{3.399186938124422, 8.083980388508804}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 7\\nPayoff: 112\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {3.399186938124422, 8.083980388508804},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-1.1498130959441881, 8.453436110630323}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 2\\nPayoff: 136\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-1.1498130959441881, 8.453436110630323},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-5.5, 7.361215932167728}, 0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 8\\nPayoff: 68\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-5.5, 7.361215932167728},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-8.899186938124423, 4.996174644486022}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 3\\nPayoff: 94\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-8.899186938124423, 4.996174644486022},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-10.759623608071863, 1.767249371950954}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 9\\nPayoff: 75\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-10.759623608071863, 1.767249371950954},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-10.759623608071863, -1.767249371950954}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 4\\nPayoff: 73\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-10.759623608071863, -1.767249371950954},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-8.899186938124423, -4.996174644486022}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 10\\nPayoff: 4\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-8.899186938124423, -4.996174644486022},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-5.5, -7.361215932167728}, 0.09359782207206707], 
           InsetBox[
            PanelBox["\<\"Number: 5\\nPayoff: 36\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-5.5, -7.361215932167728},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-1.1498130959441881, -8.453436110630323}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 11\\nPayoff: 172\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-1.1498130959441881, -8.453436110630323},
            BaseStyle->"Graphics"]}, {
           DiskBox[{3.399186938124422, -8.083980388508804}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 6\\nPayoff: 196\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {3.399186938124422, -8.083980388508804},
            BaseStyle->"Graphics"]}, {
           DiskBox[{7.360436669947441, -6.316731016557851}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 12\\nPayoff: 68\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {7.360436669947441, -6.316731016557851},
            BaseStyle->"Graphics"]}, {
           DiskBox[{10.049000034068609, -3.4572614661443013}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 13\\nPayoff: 52\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {10.049000034068609, -3.4572614661443013},
            BaseStyle->"Graphics"]}, {DiskBox[{11., 0.}, 0.09359782207206707],
            InsetBox[
            PanelBox["\<\"Number: 14\\nPayoff: 113\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {11., 0.},
            BaseStyle->"Graphics"]}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None,
    ImageSize->Large], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{0, 5, 8, 1, 6, 9, 2, 7, 10, 3, 11, 4, 12, 13, 
        14}, {{{1, 2}, {1, 3}, {4, 5}, {4, 6}, {7, 8}, {7, 9}, {10, 3}, {10, 
         11}, {12, 6}, {12, 13}, {2, 9}, {2, 14}, {5, 11}, {5, 15}, {8, 1}, {
         8, 13}, {3, 4}, {3, 14}, {6, 7}, {6, 15}, {9, 1}, {9, 10}, {11, 4}, {
         11, 12}, {13, 7}, {13, 2}, {14, 10}, {14, 5}, {15, 12}, {15, 8}}, 
         Null}, {EdgeShapeFunction -> {
           GraphElementData["UnfilledArrow", "ArrowSize" -> 0.03]}, ImageSize -> 
         Large, VertexCoordinates -> {{
           11 Cos[Rational[2, 15] Pi], 3.4572614661443013`}, {
           11 Sin[Rational[7, 30] Pi], 6.316731016557851}, {
           Rational[11, 4] (-1 + 5^Rational[1, 2]), 
            8.083980388508804}, {(-11) Sin[Rational[1, 30] Pi], 
            8.453436110630323}, {
            Rational[-11, 2], 7.361215932167728}, {
           Rational[11, 4] (-1 - 5^Rational[1, 2]), 
            4.996174644486022}, {(-11) Cos[Rational[1, 15] Pi], 
            1.767249371950954}, {(-11) 
            Cos[Rational[1, 15] Pi], -1.767249371950954}, {
           Rational[11, 4] (-1 - 5^Rational[1, 2]), -4.996174644486022}, {
            Rational[-11, 2], -7.361215932167728}, {(-11) 
            Sin[Rational[1, 30] Pi], -8.453436110630323}, {
           Rational[11, 4] (-1 + 5^Rational[1, 2]), -8.083980388508804}, {
           11 Sin[Rational[7, 30] Pi], -6.316731016557851}, {
           11 Cos[Rational[2, 15] Pi], -3.4572614661443013`}, {11, 0.}}, 
         VertexLabels -> {
          6 -> Placed[
            "Number: 6\nPayoff: 196", Center, $CellContext`panelLabel], 3 -> 
           Placed["Number: 3\nPayoff: 94", Center, $CellContext`panelLabel], 
           11 -> 
           Placed["Number: 11\nPayoff: 172", Center, $CellContext`panelLabel],
            5 -> Placed[
            "Number: 5\nPayoff: 36", Center, $CellContext`panelLabel], 8 -> 
           Placed["Number: 8\nPayoff: 68", Center, $CellContext`panelLabel], 
           7 -> Placed[
            "Number: 7\nPayoff: 112", Center, $CellContext`panelLabel], 14 -> 
           Placed["Number: 14\nPayoff: 113", Center, $CellContext`panelLabel],
            10 -> Placed[
            "Number: 10\nPayoff: 4", Center, $CellContext`panelLabel], 9 -> 
           Placed["Number: 9\nPayoff: 75", Center, $CellContext`panelLabel], 
           4 -> Placed[
            "Number: 4\nPayoff: 73", Center, $CellContext`panelLabel], 12 -> 
           Placed["Number: 12\nPayoff: 68", Center, $CellContext`panelLabel], 
           13 -> Placed[
            "Number: 13\nPayoff: 52", Center, $CellContext`panelLabel], 2 -> 
           Placed["Number: 2\nPayoff: 136", Center, $CellContext`panelLabel], 
           1 -> Placed[
            "Number: 1\nPayoff: 68", Center, $CellContext`panelLabel], 0 -> 
           Placed["Number: 0\nPayoff: 154", 
             Center, $CellContext`panelLabel]}}]]}, 
      TagBox[GraphicsGroupBox[{
         {Hue[0.6, 0.7, 0.5], Opacity[0.7], 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{10.049000034068609`, 3.4572614661443013`}, {
            7.360436669947441, 6.316731016557851}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{10.049000034068609`, 3.4572614661443013`}, {
            3.399186938124422, 8.083980388508804}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{7.360436669947441, 
            6.316731016557851}, {-8.899186938124423, -4.996174644486022}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{7.360436669947441, 6.316731016557851}, {
            10.049000034068609`, -3.4572614661443013`}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{3.399186938124422, 
            8.083980388508804}, {-1.1498130959441881`, 
            8.453436110630323}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{3.399186938124422, 8.083980388508804}, {
            10.049000034068609`, -3.4572614661443013`}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-1.1498130959441881`, 8.453436110630323}, {-5.5, 
            7.361215932167728}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-1.1498130959441881`, 
            8.453436110630323}, {-8.899186938124423, 4.996174644486022}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-5.5, 
            7.361215932167728}, {-1.1498130959441881`, -8.453436110630323}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-5.5, 7.361215932167728}, {11., 0.}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-8.899186938124423, 
            4.996174644486022}, {-10.759623608071863`, 
            1.767249371950954}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-8.899186938124423, 4.996174644486022}, {11., 0.}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-10.759623608071863`, 
            1.767249371950954}, {-10.759623608071863`, -1.767249371950954}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-10.759623608071863`, 
            1.767249371950954}, {-8.899186938124423, -4.996174644486022}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-10.759623608071863`, -1.767249371950954}, {
            10.049000034068609`, 3.4572614661443013`}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-10.759623608071863`, -1.767249371950954}, {
            7.360436669947441, -6.316731016557851}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-8.899186938124423, -4.996174644486022}, {
            10.049000034068609`, 3.4572614661443013`}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-8.899186938124423, -4.996174644486022}, {-5.5, \
-7.361215932167728}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-5.5, -7.361215932167728}, {3.399186938124422, 
            8.083980388508804}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-5.5, -7.361215932167728}, {-1.1498130959441881`, \
-8.453436110630323}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-1.1498130959441881`, -8.453436110630323}, \
{-1.1498130959441881`, 8.453436110630323}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-1.1498130959441881`, -8.453436110630323}, {
            3.399186938124422, -8.083980388508804}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{
            3.399186938124422, -8.083980388508804}, {-8.899186938124423, 
            4.996174644486022}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{3.399186938124422, -8.083980388508804}, {
            7.360436669947441, -6.316731016557851}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{7.360436669947441, -6.316731016557851}, {
            7.360436669947441, 6.316731016557851}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{
            7.360436669947441, -6.316731016557851}, {-10.759623608071863`, 
            1.767249371950954}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{10.049000034068609`, -3.4572614661443013`}, {-5.5, 
            7.361215932167728}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{
            10.049000034068609`, -3.4572614661443013`}, {-5.5, \
-7.361215932167728}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{11., 0.}, {-10.759623608071863`, -1.767249371950954}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{11., 0.}, {3.399186938124422, -8.083980388508804}}]}}, 
         {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
          0.7]}], {
           DiskBox[{10.049000034068609, 3.4572614661443013}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 0\\nPayoff: 154\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {10.049000034068609, 3.4572614661443013},
            BaseStyle->"Graphics"]}, {
           DiskBox[{7.360436669947441, 6.316731016557851}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 5\\nPayoff: 36\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {7.360436669947441, 6.316731016557851},
            BaseStyle->"Graphics"]}, {
           DiskBox[{3.399186938124422, 8.083980388508804}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 8\\nPayoff: 68\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {3.399186938124422, 8.083980388508804},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-1.1498130959441881, 8.453436110630323}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 1\\nPayoff: 68\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-1.1498130959441881, 8.453436110630323},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-5.5, 7.361215932167728}, 0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 6\\nPayoff: 196\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-5.5, 7.361215932167728},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-8.899186938124423, 4.996174644486022}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 9\\nPayoff: 75\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-8.899186938124423, 4.996174644486022},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-10.759623608071863, 1.767249371950954}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 2\\nPayoff: 136\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-10.759623608071863, 1.767249371950954},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-10.759623608071863, -1.767249371950954}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 7\\nPayoff: 112\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-10.759623608071863, -1.767249371950954},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-8.899186938124423, -4.996174644486022}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 10\\nPayoff: 4\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-8.899186938124423, -4.996174644486022},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-5.5, -7.361215932167728}, 0.09359782207206707], 
           InsetBox[
            PanelBox["\<\"Number: 3\\nPayoff: 94\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-5.5, -7.361215932167728},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-1.1498130959441881, -8.453436110630323}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 11\\nPayoff: 172\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-1.1498130959441881, -8.453436110630323},
            BaseStyle->"Graphics"]}, {
           DiskBox[{3.399186938124422, -8.083980388508804}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 4\\nPayoff: 73\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {3.399186938124422, -8.083980388508804},
            BaseStyle->"Graphics"]}, {
           DiskBox[{7.360436669947441, -6.316731016557851}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 12\\nPayoff: 68\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {7.360436669947441, -6.316731016557851},
            BaseStyle->"Graphics"]}, {
           DiskBox[{10.049000034068609, -3.4572614661443013}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 13\\nPayoff: 52\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {10.049000034068609, -3.4572614661443013},
            BaseStyle->"Graphics"]}, {DiskBox[{11., 0.}, 0.09359782207206707],
            InsetBox[
            PanelBox["\<\"Number: 14\\nPayoff: 113\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {11., 0.},
            BaseStyle->"Graphics"]}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None,
    ImageSize->Large], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{0, 1, 5, 2, 6, 3, 7, 4, 8, 9, 10, 11, 12, 13, 
        14}, {{{1, 2}, {1, 3}, {2, 4}, {2, 5}, {4, 6}, {4, 7}, {6, 8}, {6, 
         9}, {8, 3}, {8, 10}, {3, 5}, {3, 11}, {5, 7}, {5, 12}, {7, 9}, {7, 
         13}, {9, 10}, {9, 14}, {10, 11}, {10, 15}, {11, 1}, {11, 12}, {12, 
         2}, {12, 13}, {13, 4}, {13, 14}, {14, 6}, {14, 15}, {15, 1}, {15, 
         8}}, Null}, {EdgeShapeFunction -> {
           GraphElementData["UnfilledArrow", "ArrowSize" -> 0.03]}, ImageSize -> 
         Large, VertexCoordinates -> {{
           11 Cos[Rational[2, 15] Pi], 3.4572614661443013`}, {
           11 Sin[Rational[7, 30] Pi], 6.316731016557851}, {
           Rational[11, 4] (-1 + 5^Rational[1, 2]), 
            8.083980388508804}, {(-11) Sin[Rational[1, 30] Pi], 
            8.453436110630323}, {
            Rational[-11, 2], 7.361215932167728}, {
           Rational[11, 4] (-1 - 5^Rational[1, 2]), 
            4.996174644486022}, {(-11) Cos[Rational[1, 15] Pi], 
            1.767249371950954}, {(-11) 
            Cos[Rational[1, 15] Pi], -1.767249371950954}, {
           Rational[11, 4] (-1 - 5^Rational[1, 2]), -4.996174644486022}, {
            Rational[-11, 2], -7.361215932167728}, {(-11) 
            Sin[Rational[1, 30] Pi], -8.453436110630323}, {
           Rational[11, 4] (-1 + 5^Rational[1, 2]), -8.083980388508804}, {
           11 Sin[Rational[7, 30] Pi], -6.316731016557851}, {
           11 Cos[Rational[2, 15] Pi], -3.4572614661443013`}, {11, 0.}}, 
         VertexLabels -> {
          6 -> Placed[
            "Number: 6\nPayoff: 196", Center, $CellContext`panelLabel], 3 -> 
           Placed["Number: 3\nPayoff: 94", Center, $CellContext`panelLabel], 
           11 -> Placed[
            "Number: 11\nPayoff: 172", Center, $CellContext`panelLabel], 5 -> 
           Placed["Number: 5\nPayoff: 36", Center, $CellContext`panelLabel], 
           8 -> Placed[
            "Number: 8\nPayoff: 68", Center, $CellContext`panelLabel], 7 -> 
           Placed["Number: 7\nPayoff: 112", Center, $CellContext`panelLabel], 
           14 -> Placed[
            "Number: 14\nPayoff: 113", Center, $CellContext`panelLabel], 10 -> 
           Placed["Number: 10\nPayoff: 4", Center, $CellContext`panelLabel], 
           9 -> Placed[
            "Number: 9\nPayoff: 75", Center, $CellContext`panelLabel], 4 -> 
           Placed["Number: 4\nPayoff: 73", Center, $CellContext`panelLabel], 
           12 -> Placed[
            "Number: 12\nPayoff: 68", Center, $CellContext`panelLabel], 13 -> 
           Placed["Number: 13\nPayoff: 52", Center, $CellContext`panelLabel], 
           2 -> Placed[
            "Number: 2\nPayoff: 136", Center, $CellContext`panelLabel], 1 -> 
           Placed["Number: 1\nPayoff: 68", Center, $CellContext`panelLabel], 
           0 -> Placed[
            "Number: 0\nPayoff: 154", Center, $CellContext`panelLabel]}}]]}, 
      TagBox[GraphicsGroupBox[{
         {Hue[0.6, 0.7, 0.5], Opacity[0.7], 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{10.049000034068609`, 3.4572614661443013`}, {
            7.360436669947441, 6.316731016557851}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{10.049000034068609`, 3.4572614661443013`}, {
            3.399186938124422, 8.083980388508804}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{7.360436669947441, 
            6.316731016557851}, {-1.1498130959441881`, 
            8.453436110630323}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{7.360436669947441, 6.316731016557851}, {-5.5, 
            7.361215932167728}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{3.399186938124422, 8.083980388508804}, {-5.5, 
            7.361215932167728}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{3.399186938124422, 
            8.083980388508804}, {-1.1498130959441881`, -8.453436110630323}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-1.1498130959441881`, 
            8.453436110630323}, {-8.899186938124423, 4.996174644486022}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-1.1498130959441881`, 
            8.453436110630323}, {-10.759623608071863`, 
            1.767249371950954}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-5.5, 7.361215932167728}, {-10.759623608071863`, 
            1.767249371950954}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-5.5, 7.361215932167728}, {
            3.399186938124422, -8.083980388508804}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-8.899186938124423, 
            4.996174644486022}, {-10.759623608071863`, -1.767249371950954}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-8.899186938124423, 
            4.996174644486022}, {-8.899186938124423, -4.996174644486022}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-10.759623608071863`, 
            1.767249371950954}, {-8.899186938124423, -4.996174644486022}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-10.759623608071863`, 1.767249371950954}, {
            7.360436669947441, -6.316731016557851}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-10.759623608071863`, -1.767249371950954}, {
            3.399186938124422, 8.083980388508804}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-10.759623608071863`, -1.767249371950954}, {-5.5, \
-7.361215932167728}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-8.899186938124423, -4.996174644486022}, {-5.5, \
-7.361215932167728}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-8.899186938124423, -4.996174644486022}, {
            10.049000034068609`, -3.4572614661443013`}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-5.5, -7.361215932167728}, {-1.1498130959441881`, \
-8.453436110630323}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-5.5, -7.361215932167728}, {11., 0.}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-1.1498130959441881`, -8.453436110630323}, {
            10.049000034068609`, 3.4572614661443013`}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 
                 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, {-1., \
-0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-1.1498130959441881`, -8.453436110630323}, {
            3.399186938124422, -8.083980388508804}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{3.399186938124422, -8.083980388508804}, {
            7.360436669947441, 6.316731016557851}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{3.399186938124422, -8.083980388508804}, {
            7.360436669947441, -6.316731016557851}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{
            7.360436669947441, -6.316731016557851}, {-1.1498130959441881`, 
            8.453436110630323}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 
                 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, {-1., \
-0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{7.360436669947441, -6.316731016557851}, {
            10.049000034068609`, -3.4572614661443013`}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{
            10.049000034068609`, -3.4572614661443013`}, {-8.899186938124423, 
            4.996174644486022}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{10.049000034068609`, -3.4572614661443013`}, {11., 
            0.}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{11., 0.}, {10.049000034068609`, 3.4572614661443013`}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{11., 
            0.}, {-10.759623608071863`, -1.767249371950954}}]}}, 
         {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
          0.7]}], {
           DiskBox[{10.049000034068609, 3.4572614661443013}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 0\\nPayoff: 154\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {10.049000034068609, 3.4572614661443013},
            BaseStyle->"Graphics"]}, {
           DiskBox[{7.360436669947441, 6.316731016557851}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 1\\nPayoff: 68\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {7.360436669947441, 6.316731016557851},
            BaseStyle->"Graphics"]}, {
           DiskBox[{3.399186938124422, 8.083980388508804}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 5\\nPayoff: 36\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {3.399186938124422, 8.083980388508804},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-1.1498130959441881, 8.453436110630323}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 2\\nPayoff: 136\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-1.1498130959441881, 8.453436110630323},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-5.5, 7.361215932167728}, 0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 6\\nPayoff: 196\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-5.5, 7.361215932167728},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-8.899186938124423, 4.996174644486022}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 3\\nPayoff: 94\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-8.899186938124423, 4.996174644486022},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-10.759623608071863, 1.767249371950954}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 7\\nPayoff: 112\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-10.759623608071863, 1.767249371950954},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-10.759623608071863, -1.767249371950954}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 4\\nPayoff: 73\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-10.759623608071863, -1.767249371950954},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-8.899186938124423, -4.996174644486022}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 8\\nPayoff: 68\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-8.899186938124423, -4.996174644486022},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-5.5, -7.361215932167728}, 0.09359782207206707], 
           InsetBox[
            PanelBox["\<\"Number: 9\\nPayoff: 75\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-5.5, -7.361215932167728},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-1.1498130959441881, -8.453436110630323}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 10\\nPayoff: 4\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-1.1498130959441881, -8.453436110630323},
            BaseStyle->"Graphics"]}, {
           DiskBox[{3.399186938124422, -8.083980388508804}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 11\\nPayoff: 172\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {3.399186938124422, -8.083980388508804},
            BaseStyle->"Graphics"]}, {
           DiskBox[{7.360436669947441, -6.316731016557851}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 12\\nPayoff: 68\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {7.360436669947441, -6.316731016557851},
            BaseStyle->"Graphics"]}, {
           DiskBox[{10.049000034068609, -3.4572614661443013}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 13\\nPayoff: 52\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {10.049000034068609, -3.4572614661443013},
            BaseStyle->"Graphics"]}, {DiskBox[{11., 0.}, 0.09359782207206707],
            InsetBox[
            PanelBox["\<\"Number: 14\\nPayoff: 113\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {11., 0.},
            BaseStyle->"Graphics"]}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None,
    ImageSize->Large], ",", 
   GraphicsBox[
    NamespaceBox["NetworkGraphics",
     DynamicModuleBox[{Typeset`graph = HoldComplete[
       Graph[{0, 3, 8, 1, 4, 9, 2, 5, 10, 6, 11, 7, 12, 13, 
        14}, {{{1, 2}, {1, 3}, {4, 5}, {4, 6}, {7, 8}, {7, 9}, {2, 10}, {2, 
         11}, {5, 12}, {5, 13}, {8, 3}, {8, 14}, {10, 6}, {10, 15}, {12, 1}, {
         12, 9}, {3, 4}, {3, 11}, {6, 7}, {6, 13}, {9, 2}, {9, 14}, {11, 5}, {
         11, 15}, {13, 1}, {13, 8}, {14, 4}, {14, 10}, {15, 7}, {15, 12}}, 
         Null}, {EdgeShapeFunction -> {
           GraphElementData["UnfilledArrow", "ArrowSize" -> 0.03]}, ImageSize -> 
         Large, VertexCoordinates -> {{
           11 Cos[Rational[2, 15] Pi], 3.4572614661443013`}, {
           11 Sin[Rational[7, 30] Pi], 6.316731016557851}, {
           Rational[11, 4] (-1 + 5^Rational[1, 2]), 
            8.083980388508804}, {(-11) Sin[Rational[1, 30] Pi], 
            8.453436110630323}, {
            Rational[-11, 2], 7.361215932167728}, {
           Rational[11, 4] (-1 - 5^Rational[1, 2]), 
            4.996174644486022}, {(-11) Cos[Rational[1, 15] Pi], 
            1.767249371950954}, {(-11) 
            Cos[Rational[1, 15] Pi], -1.767249371950954}, {
           Rational[11, 4] (-1 - 5^Rational[1, 2]), -4.996174644486022}, {
            Rational[-11, 2], -7.361215932167728}, {(-11) 
            Sin[Rational[1, 30] Pi], -8.453436110630323}, {
           Rational[11, 4] (-1 + 5^Rational[1, 2]), -8.083980388508804}, {
           11 Sin[Rational[7, 30] Pi], -6.316731016557851}, {
           11 Cos[Rational[2, 15] Pi], -3.4572614661443013`}, {11, 0.}}, 
         VertexLabels -> {
          6 -> Placed[
            "Number: 6\nPayoff: 196", Center, $CellContext`panelLabel], 3 -> 
           Placed["Number: 3\nPayoff: 94", Center, $CellContext`panelLabel], 
           11 -> Placed[
            "Number: 11\nPayoff: 172", Center, $CellContext`panelLabel], 5 -> 
           Placed["Number: 5\nPayoff: 36", Center, $CellContext`panelLabel], 
           8 -> Placed[
            "Number: 8\nPayoff: 68", Center, $CellContext`panelLabel], 7 -> 
           Placed["Number: 7\nPayoff: 112", Center, $CellContext`panelLabel], 
           14 -> Placed[
            "Number: 14\nPayoff: 113", Center, $CellContext`panelLabel], 10 -> 
           Placed["Number: 10\nPayoff: 4", Center, $CellContext`panelLabel], 
           9 -> Placed[
            "Number: 9\nPayoff: 75", Center, $CellContext`panelLabel], 4 -> 
           Placed["Number: 4\nPayoff: 73", Center, $CellContext`panelLabel], 
           12 -> Placed[
            "Number: 12\nPayoff: 68", Center, $CellContext`panelLabel], 13 -> 
           Placed["Number: 13\nPayoff: 52", Center, $CellContext`panelLabel], 
           2 -> Placed[
            "Number: 2\nPayoff: 136", Center, $CellContext`panelLabel], 1 -> 
           Placed["Number: 1\nPayoff: 68", Center, $CellContext`panelLabel], 
           0 -> Placed[
            "Number: 0\nPayoff: 154", Center, $CellContext`panelLabel]}}]]}, 
      TagBox[GraphicsGroupBox[{
         {Hue[0.6, 0.7, 0.5], Opacity[0.7], 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{10.049000034068609`, 3.4572614661443013`}, {
            7.360436669947441, 6.316731016557851}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{10.049000034068609`, 3.4572614661443013`}, {
            3.399186938124422, 8.083980388508804}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{7.360436669947441, 
            6.316731016557851}, {-5.5, -7.361215932167728}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{7.360436669947441, 
            6.316731016557851}, {-1.1498130959441881`, -8.453436110630323}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{3.399186938124422, 
            8.083980388508804}, {-1.1498130959441881`, 
            8.453436110630323}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{3.399186938124422, 
            8.083980388508804}, {-1.1498130959441881`, -8.453436110630323}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-1.1498130959441881`, 8.453436110630323}, {-5.5, 
            7.361215932167728}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-1.1498130959441881`, 
            8.453436110630323}, {-8.899186938124423, 4.996174644486022}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-5.5, 7.361215932167728}, {
            3.399186938124422, -8.083980388508804}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-5.5, 7.361215932167728}, {
            7.360436669947441, -6.316731016557851}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-8.899186938124423, 
            4.996174644486022}, {-10.759623608071863`, 
            1.767249371950954}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-8.899186938124423, 4.996174644486022}, {
            7.360436669947441, -6.316731016557851}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-10.759623608071863`, 
            1.767249371950954}, {-10.759623608071863`, -1.767249371950954}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-10.759623608071863`, 
            1.767249371950954}, {-8.899186938124423, -4.996174644486022}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-10.759623608071863`, -1.767249371950954}, {
            3.399186938124422, 8.083980388508804}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-10.759623608071863`, -1.767249371950954}, {
            10.049000034068609`, -3.4572614661443013`}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-8.899186938124423, -4.996174644486022}, {
            7.360436669947441, 6.316731016557851}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-8.899186938124423, -4.996174644486022}, {
            10.049000034068609`, -3.4572614661443013`}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-5.5, -7.361215932167728}, {-8.899186938124423, 
            4.996174644486022}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-5.5, -7.361215932167728}, {11., 0.}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 
                 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, {-1., \
-0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-1.1498130959441881`, -8.453436110630323}, {-5.5, 
            7.361215932167728}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{-1.1498130959441881`, -8.453436110630323}, {11., 0.}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{3.399186938124422, -8.083980388508804}, {
            10.049000034068609`, 3.4572614661443013`}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{
            3.399186938124422, -8.083980388508804}, {-8.899186938124423, \
-4.996174644486022}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{7.360436669947441, -6.316731016557851}, {
            10.049000034068609`, 3.4572614661443013`}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{
            7.360436669947441, -6.316731016557851}, {-10.759623608071863`, \
-1.767249371950954}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{
            10.049000034068609`, -3.4572614661443013`}, {-1.1498130959441881`,
             8.453436110630323}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{
            10.049000034068609`, -3.4572614661443013`}, {-5.5, \
-7.361215932167728}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{11., 0.}, {-10.759623608071863`, 
            1.767249371950954}}]}, 
          {Arrowheads[{{0.03, 0.8, {
               GraphicsBox[
                
                FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {
                 0, 1, 0}}}, {{{-0.9696460829962081, -0.3030048596799224}, \
{-1., -0.2058621479276388}, {-0.34122077195125033`, 0.}, {-1., 
                 0.2058621479276388}, {-0.9696460829962081, 
                 0.3030048596799233}, {0., 0.}}}]], 0.34122077195125033`}}}], 
           ArrowBox[{{11., 0.}, {3.399186938124422, -8.083980388508804}}]}}, 
         {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
          0.7]}], {
           DiskBox[{10.049000034068609, 3.4572614661443013}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 0\\nPayoff: 154\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {10.049000034068609, 3.4572614661443013},
            BaseStyle->"Graphics"]}, {
           DiskBox[{7.360436669947441, 6.316731016557851}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 3\\nPayoff: 94\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {7.360436669947441, 6.316731016557851},
            BaseStyle->"Graphics"]}, {
           DiskBox[{3.399186938124422, 8.083980388508804}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 8\\nPayoff: 68\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {3.399186938124422, 8.083980388508804},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-1.1498130959441881, 8.453436110630323}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 1\\nPayoff: 68\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-1.1498130959441881, 8.453436110630323},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-5.5, 7.361215932167728}, 0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 4\\nPayoff: 73\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-5.5, 7.361215932167728},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-8.899186938124423, 4.996174644486022}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 9\\nPayoff: 75\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-8.899186938124423, 4.996174644486022},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-10.759623608071863, 1.767249371950954}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 2\\nPayoff: 136\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-10.759623608071863, 1.767249371950954},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-10.759623608071863, -1.767249371950954}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 5\\nPayoff: 36\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-10.759623608071863, -1.767249371950954},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-8.899186938124423, -4.996174644486022}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 10\\nPayoff: 4\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-8.899186938124423, -4.996174644486022},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-5.5, -7.361215932167728}, 0.09359782207206707], 
           InsetBox[
            PanelBox["\<\"Number: 6\\nPayoff: 196\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-5.5, -7.361215932167728},
            BaseStyle->"Graphics"]}, {
           DiskBox[{-1.1498130959441881, -8.453436110630323}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 11\\nPayoff: 172\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {-1.1498130959441881, -8.453436110630323},
            BaseStyle->"Graphics"]}, {
           DiskBox[{3.399186938124422, -8.083980388508804}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 7\\nPayoff: 112\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {3.399186938124422, -8.083980388508804},
            BaseStyle->"Graphics"]}, {
           DiskBox[{7.360436669947441, -6.316731016557851}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 12\\nPayoff: 68\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {7.360436669947441, -6.316731016557851},
            BaseStyle->"Graphics"]}, {
           DiskBox[{10.049000034068609, -3.4572614661443013}, 
            0.09359782207206707], InsetBox[
            PanelBox["\<\"Number: 13\\nPayoff: 52\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {10.049000034068609, -3.4572614661443013},
            BaseStyle->"Graphics"]}, {DiskBox[{11., 0.}, 0.09359782207206707],
            InsetBox[
            PanelBox["\<\"Number: 14\\nPayoff: 113\"\>",
             Background->RGBColor[0.85, 0.85, 0.85],
             FrameMargins->0], {11., 0.},
            BaseStyle->"Graphics"]}}}],
       MouseAppearanceTag["NetworkGraphics"]],
      AllowKernelInitialization->False]],
    DefaultBaseStyle->{
     "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
    
    FormatType->TraditionalForm,
    FrameTicks->None,
    ImageSize->Large]}], "}"}]], "Output",
 CellChangeTimes->{{3.706030529550098*^9, 3.706030553587837*^9}, 
   3.706095131196332*^9, 3.706095271082951*^9, {3.706097377119796*^9, 
   3.706097395960184*^9}, 3.7060974632554407`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{"Export", "[", 
    RowBox[{
     RowBox[{"\"\</home/kzollman/tmp/Graph\>\"", "<>", 
      RowBox[{"ToString", "[", "i", "]"}], "<>", "\"\<.pdf\>\""}], ",", " ", 
     RowBox[{"graphs", "[", 
      RowBox[{"[", "i", "]"}], "]"}]}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"i", ",", "1", ",", "players"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.706030676241605*^9, 3.706030747191926*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"/home/kzollman/tmp/Graph1.pdf\"\>", 
   ",", "\<\"/home/kzollman/tmp/Graph2.pdf\"\>", 
   ",", "\<\"/home/kzollman/tmp/Graph3.pdf\"\>", 
   ",", "\<\"/home/kzollman/tmp/Graph4.pdf\"\>", 
   ",", "\<\"/home/kzollman/tmp/Graph5.pdf\"\>", 
   ",", "\<\"/home/kzollman/tmp/Graph6.pdf\"\>", 
   ",", "\<\"/home/kzollman/tmp/Graph7.pdf\"\>", 
   ",", "\<\"/home/kzollman/tmp/Graph8.pdf\"\>", 
   ",", "\<\"/home/kzollman/tmp/Graph9.pdf\"\>", 
   ",", "\<\"/home/kzollman/tmp/Graph10.pdf\"\>", 
   ",", "\<\"/home/kzollman/tmp/Graph11.pdf\"\>", 
   ",", "\<\"/home/kzollman/tmp/Graph12.pdf\"\>", 
   ",", "\<\"/home/kzollman/tmp/Graph13.pdf\"\>", 
   ",", "\<\"/home/kzollman/tmp/Graph14.pdf\"\>", 
   ",", "\<\"/home/kzollman/tmp/Graph15.pdf\"\>", 
   ",", "\<\"/home/kzollman/tmp/Graph16.pdf\"\>", 
   ",", "\<\"/home/kzollman/tmp/Graph17.pdf\"\>", 
   ",", "\<\"/home/kzollman/tmp/Graph18.pdf\"\>", 
   ",", "\<\"/home/kzollman/tmp/Graph19.pdf\"\>", 
   ",", "\<\"/home/kzollman/tmp/Graph20.pdf\"\>", 
   ",", "\<\"/home/kzollman/tmp/Graph21.pdf\"\>", 
   ",", "\<\"/home/kzollman/tmp/Graph22.pdf\"\>", 
   ",", "\<\"/home/kzollman/tmp/Graph23.pdf\"\>", 
   ",", "\<\"/home/kzollman/tmp/Graph24.pdf\"\>", 
   ",", "\<\"/home/kzollman/tmp/Graph25.pdf\"\>", 
   ",", "\<\"/home/kzollman/tmp/Graph26.pdf\"\>", 
   ",", "\<\"/home/kzollman/tmp/Graph27.pdf\"\>", 
   ",", "\<\"/home/kzollman/tmp/Graph28.pdf\"\>", 
   ",", "\<\"/home/kzollman/tmp/Graph29.pdf\"\>", 
   ",", "\<\"/home/kzollman/tmp/Graph30.pdf\"\>"}], "}"}]], "Output",
 CellChangeTimes->{3.706030758108424*^9, 3.7060951569990473`*^9, 
  3.7060953518112297`*^9, 3.706097478758315*^9}]
}, Open  ]]
},
WindowSize->{1920, 1056},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
Magnification:>3. Inherited,
FrontEndVersion->"11.0 for Linux x86 (64-bit) (July 28, 2016)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[558, 20, 860, 22, 304, "Input"],
Cell[CellGroupData[{
Cell[1443, 46, 6460, 142, 1534, "Input"],
Cell[7906, 190, 730817, 13316, 2802, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[738760, 13511, 458, 11, 209, "Input"],
Cell[739221, 13524, 1685, 33, 978, "Output"]
}, Open  ]]
}
]
*)

